@@ -32,14 +32,20 @@ from resource_management.core.logger import Logger
 __all__ = ["upload_configuration_to_zk", "create_collection", "setup_kerberos", "set_cluster_prop",
            "setup_kerberos_plugin", "create_znode", "check_znode", "secure_solr_znode", "secure_znode"]
 
-def __create_solr_cloud_cli_prefix(zookeeper_quorum, solr_znode, java64_home, separated_znode=False):
+def __create_solr_cloud_cli_prefix(zookeeper_quorum, solr_znode, java64_home, java_opts=None, jaas_file=None, separated_znode=False):
   sudo = AMBARI_SUDO_BINARY
-  solr_cli_prefix = format('{sudo} JAVA_HOME={java64_home} /usr/lib/ambari-infra-solr-client/solrCloudCli.sh ' \
+
+  infra_solr_cli_opts= format(' INFRA_SOLR_CLI_OPTS="{java_opts}"') if java_opts is not None else ''
+  solr_cli_prefix = format('{sudo} JAVA_HOME={java64_home}{infra_solr_cli_opts} /usr/lib/ambari-infra-solr-client/solrCloudCli.sh ' \
                            '--zookeeper-connect-string {zookeeper_quorum}')
   if separated_znode:
     solr_cli_prefix+=format(' --znode {solr_znode}')
   else:
     solr_cli_prefix+=format('{solr_znode}')
+
+  if jaas_file:
+    solr_cli_prefix+=format(' --jaas-file {jaas_file}')
+
   return solr_cli_prefix
 
 def __append_flags_if_exists(command, flagsDict):
@@ -49,7 +55,7 @@ def __append_flags_if_exists(command, flagsDict):
   return command
 
 def upload_configuration_to_zk(zookeeper_quorum, solr_znode, config_set, config_set_dir, tmp_dir,
-                         java64_home, retry = 5, interval = 10, solrconfig_content = None, jaas_file=None):
+                         java64_home, retry = 5, interval = 10, solrconfig_content = None, jaas_file=None, java_opts=None):
   """
   Upload configuration set to zookeeper with solrCloudCli.sh
   At first, it tries to download configuration set if exists into a temporary location, then upload that one to
@@ -57,11 +63,9 @@ def upload_configuration_to_zk(zookeeper_quorum, solr_znode, config_set, config_
   """
   random_num = random.random()
   tmp_config_set_dir = format('{tmp_dir}/solr_config_{config_set}_{random_num}')
-  solr_cli_prefix = __create_solr_cloud_cli_prefix(zookeeper_quorum, solr_znode, java64_home)
+  solr_cli_prefix = __create_solr_cloud_cli_prefix(zookeeper_quorum, solr_znode, java64_home, java_opts, jaas_file)
   Execute(format('{solr_cli_prefix} --download-config --config-dir {tmp_config_set_dir} --config-set {config_set} --retry {retry} --interval {interval}'),
           only_if=format("{solr_cli_prefix} --check-config --config-set {config_set} --retry {retry} --interval {interval}"))
-  appendableDict = {}
-  appendableDict["--jaas-file"] = jaas_file
 
   if solrconfig_content is not None:
       File(format("{tmp_config_set_dir}/solrconfig.xml"),
@@ -69,12 +73,10 @@ def upload_configuration_to_zk(zookeeper_quorum, solr_znode, config_set, config_
        only_if=format("test -d {tmp_config_set_dir}")
       )
       upload_tmp_config_cmd = format('{solr_cli_prefix} --upload-config --config-dir {tmp_config_set_dir} --config-set {config_set} --retry {retry} --interval {interval}')
-      upload_tmp_config_cmd = __append_flags_if_exists(upload_tmp_config_cmd, appendableDict)
       Execute(upload_tmp_config_cmd,
         only_if=format("test -d {tmp_config_set_dir}")
       )
   upload_config_cmd = format('{solr_cli_prefix} --upload-config --config-dir {config_set_dir} --config-set {config_set} --retry {retry} --interval {interval}')
-  upload_config_cmd = __append_flags_if_exists(upload_config_cmd, appendableDict)
   Execute(upload_config_cmd,
     not_if=format("test -d {tmp_config_set_dir}")
   )
@@ -85,10 +87,10 @@ def upload_configuration_to_zk(zookeeper_quorum, solr_znode, config_set, config_
             )
 
 def create_collection(zookeeper_quorum, solr_znode, collection, config_set, java64_home,
-                      shards = 1, replication_factor = 1, max_shards = 1, retry = 5, interval = 10,
+                      shards = 1, replication_factor = 1, max_shards = 1, retry = 5, interval = 10, implicitRouting = False,
                       router_name = None, router_field = None, jaas_file = None, key_store_location = None,
                       key_store_password = None, key_store_type = None, trust_store_location = None,
-                      trust_store_password = None, trust_store_type = None):
+                      trust_store_password = None, trust_store_type = None, java_opts=None):
   """
   Create Solr collection based on a configuration set in zookeeper.
   If this method called again the with higher shard number (or max_shard number), then it will indicate
@@ -98,18 +100,19 @@ def create_collection(zookeeper_quorum, solr_znode, collection, config_set, java
   If you would like to add shards later to a collection, then use implicit routing, e.g.:
   router_name = "implicit", router_field = "_router_field_"
   """
-  solr_cli_prefix = __create_solr_cloud_cli_prefix(zookeeper_quorum, solr_znode, java64_home)
+  solr_cli_prefix = __create_solr_cloud_cli_prefix(zookeeper_quorum, solr_znode, java64_home, java_opts, jaas_file)
 
   if max_shards == 1: # if max shards is not specified use this strategy
-    max_shards = replication_factor * shards
+    max_shards = int(replication_factor) * int(shards)
 
   create_collection_cmd = format('{solr_cli_prefix} --create-collection --collection {collection} --config-set {config_set} '\
                                  '--shards {shards} --replication {replication_factor} --max-shards {max_shards} --retry {retry} '\
-                                 '--interval {interval} --no-sharding')
+                                 '--interval {interval}')
+
+  create_collection_cmd = create_collection_cmd + ' --implicit-routing' if implicitRouting else create_collection_cmd
   appendableDict = {}
   appendableDict["--router-name"] = router_name
   appendableDict["--router-field"] = router_field
-  appendableDict["--jaas-file"] = jaas_file
   appendableDict["--key-store-location"] = key_store_location
   appendableDict["--key-store-password"] = None if key_store_password is None else '{key_store_password_param!p}'
   appendableDict["--key-store-type"] = key_store_type
@@ -121,75 +124,96 @@ def create_collection(zookeeper_quorum, solr_znode, collection, config_set, java
 
   Execute(create_collection_cmd)
 
-def setup_kerberos(zookeeper_quorum, solr_znode, copy_from_znode, java64_home, secure=False, jaas_file=None):
+def setup_kerberos(zookeeper_quorum, solr_znode, copy_from_znode, java64_home, secure=False, jaas_file=None, java_opts=None):
   """
   Copy all unsecured (or secured) Znode content to a secured (or unsecured) Znode,
   and restrict the world permissions there.
   """
-  solr_cli_prefix = __create_solr_cloud_cli_prefix(zookeeper_quorum, solr_znode, java64_home, True)
+  solr_cli_prefix = __create_solr_cloud_cli_prefix(zookeeper_quorum, solr_znode, java64_home, java_opts, jaas_file, True)
   setup_kerberos_cmd = format('{solr_cli_prefix} --setup-kerberos --copy-from-znode {copy_from_znode}')
   if secure and jaas_file is not None:
     setup_kerberos_cmd+=format(' --secure --jaas-file {jaas_file}')
   Execute(setup_kerberos_cmd)
 
-def check_znode(zookeeper_quorum, solr_znode, java64_home, retry = 5, interval = 10):
+def check_znode(zookeeper_quorum, solr_znode, java64_home, retry = 5, interval = 10, java_opts=None, jaas_file=None):
   """
   Check znode exists or not, throws exception if does not accessible.
   """
-  solr_cli_prefix = __create_solr_cloud_cli_prefix(zookeeper_quorum, solr_znode, java64_home, True)
+  solr_cli_prefix = __create_solr_cloud_cli_prefix(zookeeper_quorum, solr_znode, java64_home, java_opts, jaas_file, True)
   check_znode_cmd = format('{solr_cli_prefix} --check-znode --retry {retry} --interval {interval}')
   Execute(check_znode_cmd)
 
-def create_znode(zookeeper_quorum, solr_znode, java64_home, retry = 5 , interval = 10):
+def create_znode(zookeeper_quorum, solr_znode, java64_home, retry = 5 , interval = 10, java_opts=None, jaas_file=None):
   """
   Create znode if does not exists, throws exception if zookeeper is not accessible.
   """
-  solr_cli_prefix = __create_solr_cloud_cli_prefix(zookeeper_quorum, solr_znode, java64_home, True)
+  solr_cli_prefix = __create_solr_cloud_cli_prefix(zookeeper_quorum, solr_znode, java64_home, java_opts, jaas_file, True)
   create_znode_cmd = format('{solr_cli_prefix} --create-znode --retry {retry} --interval {interval}')
   Execute(create_znode_cmd)
 
-def setup_kerberos_plugin(zookeeper_quorum, solr_znode, java64_home, secure=False, security_json_location = None, jaas_file = None):
+def setup_kerberos_plugin(zookeeper_quorum, solr_znode, java64_home, secure=False, security_json_location = None, jaas_file = None, java_opts=None):
   """
   Set Kerberos plugin on the Solr znode in security.json, if secure is False, then clear the security.json
   """
-  solr_cli_prefix = __create_solr_cloud_cli_prefix(zookeeper_quorum, solr_znode, java64_home, True)
+  solr_cli_prefix = __create_solr_cloud_cli_prefix(zookeeper_quorum, solr_znode, java64_home, java_opts, jaas_file, True)
   setup_kerberos_plugin_cmd = format('{solr_cli_prefix} --setup-kerberos-plugin')
   if secure and jaas_file is not None and security_json_location is not None:
     setup_kerberos_plugin_cmd+=format(' --jaas-file {jaas_file} --secure --security-json-location {security_json_location}')
   Execute(setup_kerberos_plugin_cmd)
 
-def set_cluster_prop(zookeeper_quorum, solr_znode, prop_name, prop_value, java64_home, jaas_file = None):
+def set_cluster_prop(zookeeper_quorum, solr_znode, prop_name, prop_value, java64_home, jaas_file = None, java_opts=None):
   """
   Set a cluster property on the Solr znode in clusterprops.json
   """
-  solr_cli_prefix = __create_solr_cloud_cli_prefix(zookeeper_quorum, solr_znode, java64_home)
+  solr_cli_prefix = __create_solr_cloud_cli_prefix(zookeeper_quorum, solr_znode, java64_home, java_opts, jaas_file)
   set_cluster_prop_cmd = format('{solr_cli_prefix} --cluster-prop --property-name {prop_name} --property-value {prop_value}')
-  if jaas_file is not None:
-    set_cluster_prop_cmd+=format(' --jaas-file {jaas_file}')
   Execute(set_cluster_prop_cmd)
 
-def secure_znode(config, zookeeper_quorum, solr_znode, jaas_file, java64_home, sasl_users=[], retry = 5 , interval = 10):
+def secure_znode(config, zookeeper_quorum, solr_znode, jaas_file, java64_home, sasl_users=[], retry = 5 , interval = 10, java_opts=None):
   """
   Secure znode, set a list of sasl users acl to 'cdrwa', and set acl to 'r' only for the world.
   Add infra-solr user by default if its available.
   """
-  solr_cli_prefix = __create_solr_cloud_cli_prefix(zookeeper_quorum, solr_znode, java64_home, True)
+  solr_cli_prefix = __create_solr_cloud_cli_prefix(zookeeper_quorum, solr_znode, java64_home, java_opts, jaas_file, True)
   if "infra-solr-env" in config['configurations']:
     sasl_users.append(__get_name_from_principal(config['configurations']['infra-solr-env']['infra_solr_kerberos_principal']))
   sasl_users_str = ",".join(str(__get_name_from_principal(x)) for x in sasl_users)
-  secure_znode_cmd = format('{solr_cli_prefix} --secure-znode --jaas-file {jaas_file} --sasl-users {sasl_users_str} --retry {retry} --interval {interval}')
+  secure_znode_cmd = format('{solr_cli_prefix} --secure-znode --sasl-users {sasl_users_str} --retry {retry} --interval {interval}')
   Execute(secure_znode_cmd)
 
 
-def secure_solr_znode(zookeeper_quorum, solr_znode, jaas_file, java64_home, sasl_users_str=''):
+def secure_solr_znode(zookeeper_quorum, solr_znode, jaas_file, java64_home, sasl_users_str='', java_opts=None):
   """
   Secure solr znode - setup acls to 'cdrwa' for solr user, set 'r' only for the world, skipping /znode/configs and znode/collections (set those to 'cr' for the world)
   sasl_users_str: comma separated sasl users
   """
-  solr_cli_prefix = __create_solr_cloud_cli_prefix(zookeeper_quorum, solr_znode, java64_home, True)
-  secure_solr_znode_cmd = format('{solr_cli_prefix} --secure-solr-znode --jaas-file {jaas_file} --sasl-users {sasl_users_str}')
+  solr_cli_prefix = __create_solr_cloud_cli_prefix(zookeeper_quorum, solr_znode, java64_home, java_opts, jaas_file, True)
+  secure_solr_znode_cmd = format('{solr_cli_prefix} --secure-solr-znode --sasl-users {sasl_users_str}')
   Execute(secure_solr_znode_cmd)
 
+def remove_admin_handlers(zookeeper_quorum, solr_znode, java64_home, collection, jaas_file, retry = 5, interval = 10, java_opts=None):
+  """
+  Remove "solr.admin.AdminHandlers" request handler from collection config. Required for migrating to Solr 6 from Solr 5.
+  """
+  solr_cli_prefix = __create_solr_cloud_cli_prefix(zookeeper_quorum, solr_znode, java64_home, java_opts, jaas_file)
+  remove_admin_handlers_cmd = format('{solr_cli_prefix} --remove-admin-handlers --collection {collection} --retry {retry} --interval {interval}')
+  Execute(remove_admin_handlers_cmd)
+
+def copy_solr_znode(zookeeper_quorum, solr_znode, java64_home, jaas_file, src_znode, target_znode, retry = 5, interval = 10, java_opts=None):
+  solr_cli_prefix = __create_solr_cloud_cli_prefix(zookeeper_quorum, solr_znode, java64_home, java_opts, jaas_file)
+  copy_znode_cmd = format("{solr_cli_prefix} --transfer-znode --copy-src {src_znode} --copy-dest {target_znode} --retry {retry} --interval {interval}")
+  Execute(copy_znode_cmd)
+
+def copy_solr_znode_to_locat(zookeeper_quorum, solr_znode, java64_home, jaas_file, src_znode, target, retry = 5, interval = 10, java_opts=None):
+  solr_cli_prefix = __create_solr_cloud_cli_prefix(zookeeper_quorum, solr_znode, java64_home, java_opts, jaas_file)
+  copy_znode_cmd = format("{solr_cli_prefix} --transfer-znode --transfer-mode copyToLocal --copy-src {src_znode} --copy-dest {target} --retry {retry} --interval {interval}")
+  Execute(copy_znode_cmd)
+
+def copy_solr_znode_from_local(zookeeper_quorum, solr_znode, java64_home, jaas_file, src, target_znode, retry = 5, interval = 10, java_opts=None):
+  solr_cli_prefix = __create_solr_cloud_cli_prefix(zookeeper_quorum, solr_znode, java64_home, java_opts, jaas_file)
+  copy_znode_cmd = format("{solr_cli_prefix} --transfer-znode --transfer-mode copyFromLocal --copy-src {src} --copy-dest {target_znode} --retry {retry} --interval {interval}")
+  Execute(copy_znode_cmd)
+
 def default_config(config, name, default_value):
   subdicts = filter(None, name.split('/'))
   if not config:
@@ -300,19 +324,22 @@ def add_solr_roles(config, roles = [], new_service_principals = [], tries = 30,
   solr_port = default_config(config, 'configurations/infra-solr-env/infra_solr_port', '8886')
   kinit_path_local = get_kinit_path(default_config(config, '/configurations/kerberos-env/executable_search_paths', None))
   infra_solr_custom_security_json_content = None
-
+  infra_solr_security_manually_managed = False
   if 'infra-solr-security-json' in config['configurations']:
     infra_solr_custom_security_json_content = config['configurations']['infra-solr-security-json']['content']
+    infra_solr_security_manually_managed = config['configurations']['infra-solr-security-json']['infra_solr_security_manually_managed']
 
   Logger.info(format("Adding {roles} roles to {new_service_principals} if infra-solr is installed."))
-  if infra_solr_custom_security_json_content and str(infra_solr_custom_security_json_content).strip():
+  if infra_solr_security_manually_managed:
+    Logger.info("security.json file is manually managed, skip adding roles...")
+  elif infra_solr_custom_security_json_content and str(infra_solr_custom_security_json_content).strip():
     Logger.info("Custom security.json is not empty for infra-solr, skip adding roles...")
   elif security_enabled \
     and "infra-solr-env" in config['configurations'] \
     and solr_hosts is not None \
     and len(solr_hosts) > 0:
     solr_protocol = "https" if solr_ssl_enabled else "http"
-    hostname = config['hostname'].lower()
+    hostname = config['agentLevelParams']['hostname'].lower()
     solr_host = __get_random_solr_host(hostname, solr_hosts)
     solr_url = format("{solr_protocol}://{solr_host}:{solr_port}/solr/admin/authorization")
     solr_user = config['configurations']['infra-solr-env']['infra_solr_user']
