@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -26,5 +26,5 @@ public interface ResourcePredicateEvaluator {
    *
    * @return true if the predicate evaluates to true for the resource
    */
-  public boolean evaluate(Predicate predicate, Resource resource);
+  boolean evaluate(Predicate predicate, Resource resource);
 }
