@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -44,11 +44,9 @@ import org.codehaus.jackson.type.TypeReference;
  */
 public class PropertyHelper {
 
-  private static final String PROPERTIES_FILE = "properties.json";
   private static final String GANGLIA_PROPERTIES_FILE = "ganglia_properties.json";
   private static final String SQLSERVER_PROPERTIES_FILE = "sqlserver_properties.json";
   private static final String JMX_PROPERTIES_FILE = "jmx_properties.json";
-  private static final String KEY_PROPERTIES_FILE = "key_properties.json";
   public static final char EXTERNAL_PATH_SEP = '/';
 
   /**
@@ -60,11 +58,11 @@ public class PropertyHelper {
   private static final List<Resource.InternalType> REPORT_METRIC_RESOURCES =
     Arrays.asList(Resource.InternalType.Cluster, Resource.InternalType.Host);
 
-  private static final Map<Resource.InternalType, Set<String>> PROPERTY_IDS = readPropertyIds(PROPERTIES_FILE);
+  private static final Map<Resource.InternalType, Set<String>> PROPERTY_IDS = new HashMap<>();
   private static final Map<Resource.InternalType, Map<String, Map<String, PropertyInfo>>> JMX_PROPERTY_IDS = readPropertyProviderIds(JMX_PROPERTIES_FILE);
   private static final Map<Resource.InternalType, Map<String, Map<String, PropertyInfo>>> GANGLIA_PROPERTY_IDS = readPropertyProviderIds(GANGLIA_PROPERTIES_FILE);
   private static final Map<Resource.InternalType, Map<String, Map<String, PropertyInfo>>> SQLSERVER_PROPERTY_IDS = readPropertyProviderIds(SQLSERVER_PROPERTIES_FILE);
-  private static final Map<Resource.InternalType, Map<Resource.Type, String>> KEY_PROPERTY_IDS = readKeyPropertyIds(KEY_PROPERTIES_FILE);
+  private static final Map<Resource.InternalType, Map<Resource.Type, String>> KEY_PROPERTY_IDS = new HashMap<>();
 
   // Suffixes to add for Namenode rpc metrics prefixes
   private static final Map<String, List<String>> RPC_METRIC_SUFFIXES = new HashMap<>();
@@ -112,7 +110,7 @@ public class PropertyHelper {
 
   public static Set<String> getPropertyIds(Resource.Type resourceType) {
     Set<String> propertyIds = PROPERTY_IDS.get(resourceType.getInternalType());
-    return propertyIds == null ? Collections.<String>emptySet() : propertyIds;
+    return propertyIds == null ? Collections.emptySet() : propertyIds;
   }
 
   public static void setPropertyIds(Resource.Type resourceType, Set<String> propertyIds) {
@@ -150,7 +148,7 @@ public class PropertyHelper {
   public static Map<Resource.Type, String> getKeyPropertyIds(Resource.Type resourceType) {
     return KEY_PROPERTY_IDS.get(resourceType.getInternalType());
   }
-  
+
   public static void setKeyPropertyIds(Resource.Type resourceType, Map<Resource.Type, String> keyPropertyKeys) {
     KEY_PROPERTY_IDS.put(resourceType.getInternalType(), keyPropertyKeys);
   }
@@ -422,7 +420,7 @@ public class PropertyHelper {
    */
   public static Request getReadRequest(String ... propertyIds) {
     return PropertyHelper.getReadRequest(new HashSet<>(
-        Arrays.asList(propertyIds)));
+      Arrays.asList(propertyIds)));
   }
 
   /**
@@ -446,7 +444,7 @@ public class PropertyHelper {
               new TypeReference<Map<Resource.InternalType, Map<String, Map<String, Metric>>>>() {});
 
       Map<Resource.InternalType, Map<String, Map<String, PropertyInfo>>> resourceMetrics =
-          new HashMap<>();
+        new HashMap<>();
 
       for (Map.Entry<Resource.InternalType, Map<String, Map<String, Metric>>> resourceEntry : resourceMetricMap.entrySet()) {
         Map<String, Map<String, PropertyInfo>> componentMetrics = new HashMap<>();
@@ -497,7 +495,7 @@ public class PropertyHelper {
               new TypeReference<Map<Resource.InternalType, Map<Resource.InternalType, String>>>() {});
 
       Map<Resource.InternalType, Map<Resource.Type, String>> returnMap =
-          new HashMap<>();
+        new HashMap<>();
 
       // convert inner maps from InternalType to Type
       for (Map.Entry<Resource.InternalType, Map<Resource.InternalType, String>> entry : map.entrySet()) {
