@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -18,8 +18,6 @@
 
 package org.apache.ambari.server.hooks.users;
 
-import javax.inject.Inject;
-
 import org.apache.ambari.server.events.AmbariEvent;
 import org.apache.ambari.server.hooks.HookContext;
 
