@@ -18,31 +18,34 @@
 
 package org.apache.ambari.server.serveraction.kerberos;
 
-import com.google.inject.Inject;
+import java.io.File;
+import java.io.IOException;
+import java.util.HashSet;
+import java.util.Map;
+import java.util.Set;
+import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.ConcurrentMap;
+import java.util.concurrent.locks.Lock;
+
 import org.apache.ambari.server.AmbariException;
 import org.apache.ambari.server.actionmanager.HostRoleStatus;
 import org.apache.ambari.server.agent.CommandReport;
 import org.apache.ambari.server.audit.event.kerberos.CreateKeyTabKerberosAuditEvent;
 import org.apache.ambari.server.configuration.Configuration;
 import org.apache.ambari.server.controller.KerberosHelper;
-import org.apache.ambari.server.orm.dao.HostDAO;
 import org.apache.ambari.server.orm.dao.KerberosPrincipalDAO;
-import org.apache.ambari.server.orm.dao.KerberosPrincipalHostDAO;
-import org.apache.ambari.server.orm.entities.HostEntity;
 import org.apache.ambari.server.orm.entities.KerberosPrincipalEntity;
 import org.apache.ambari.server.serveraction.ActionLog;
+import org.apache.ambari.server.serveraction.kerberos.stageutils.KerberosKeytabController;
+import org.apache.ambari.server.serveraction.kerberos.stageutils.ResolvedKerberosKeytab;
+import org.apache.ambari.server.serveraction.kerberos.stageutils.ResolvedKerberosPrincipal;
 import org.apache.commons.codec.digest.DigestUtils;
 import org.apache.directory.server.kerberos.shared.keytab.Keytab;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import java.io.File;
-import java.io.IOException;
-import java.util.HashMap;
-import java.util.HashSet;
-import java.util.Map;
-import java.util.Set;
-import java.util.concurrent.ConcurrentMap;
+import com.google.common.util.concurrent.Striped;
+import com.google.inject.Inject;
 
 /**
  * CreateKeytabFilesServerAction is a ServerAction implementation that creates keytab files as
@@ -51,9 +54,10 @@ import java.util.concurrent.ConcurrentMap;
  * This class mainly relies on the KerberosServerAction to iterate through metadata identifying
  * the Kerberos keytab files that need to be created. For each identity in the metadata, this
  * implementation's
- * {@link KerberosServerAction#processIdentity(Map, String, KerberosOperationHandler, Map, Map)}
+ * {@link KerberosServerAction#processIdentity(ResolvedKerberosPrincipal, KerberosOperationHandler, Map, boolean, Map)}
  * is invoked attempting the creation of the relevant keytab file.
  */
+@SuppressWarnings("UnstableApiUsage")
 public class CreateKeytabFilesServerAction extends KerberosServerAction {
   private final static Logger LOG = LoggerFactory.getLogger(CreateKeytabFilesServerAction.class);
 
@@ -63,29 +67,25 @@ public class CreateKeytabFilesServerAction extends KerberosServerAction {
   @Inject
   private KerberosPrincipalDAO kerberosPrincipalDAO;
 
-  /**
-   * KerberosPrincipalHostDAO used to get Kerberos principal details
-   */
-  @Inject
-  private KerberosPrincipalHostDAO kerberosPrincipalHostDAO;
-
   /**
    * Configuration used to get the configured properties such as the keytab file cache directory
    */
   @Inject
   private Configuration configuration;
 
-  /**
-   * HostDAO used to retrieveHost Entity object
-   */
   @Inject
-  private HostDAO hostDAO;
+  private KerberosKeytabController kerberosKeytabController;
+
+  /**
+   * Used to prevent multiple threads from working with the same keytab.
+   */
+  private Striped<Lock> m_locksByKeytab = Striped.lazyWeakLock(25);
 
   /**
    * A map of data used to track what has been processed in order to optimize the creation of keytabs
    * such as knowing when to create a cached keytab file or use a cached keytab file.
    */
-  Map<String, Set<String>> visitedIdentities = new HashMap<String, Set<String>>();
+  Map<String, Set<String>> visitedIdentities = new ConcurrentHashMap<>();
 
   /**
    * Called to execute this action.  Upon invocation, calls
@@ -117,10 +117,7 @@ public class CreateKeytabFilesServerAction extends KerberosServerAction {
    * If a password exists for the current evaluatedPrincipal, use a
    * {@link org.apache.ambari.server.serveraction.kerberos.KerberosOperationHandler} to generate
    * the keytab file. To help avoid filename collisions and to build a structure that is easy to
-   * discover, each keytab file is stored in host-specific
-   * ({@link org.apache.ambari.server.serveraction.kerberos.KerberosIdentityDataFileReader#HOSTNAME})
-   * directory using the SHA1 hash of its destination file path
-   * ({@link org.apache.ambari.server.serveraction.kerberos.KerberosIdentityDataFileReader#KEYTAB_FILE_PATH})
+   * discover, each keytab file is stored in host-specific directory using the SHA1 hash of its destination file path.
    * <p/>
    * <pre>
    *   data_directory
@@ -132,21 +129,23 @@ public class CreateKeytabFilesServerAction extends KerberosServerAction {
    *   |  |- ...
    * </pre>
    *
-   * @param identityRecord           a Map containing the data for the current identity record
-   * @param evaluatedPrincipal       a String indicating the relevant principal
+   * @param resolvedPrincipal        a ResolvedKerberosPrincipal object to process
    * @param operationHandler         a KerberosOperationHandler used to perform Kerberos-related
    *                                 tasks for specific Kerberos implementations
    *                                 (MIT, Active Directory, etc...)
    * @param kerberosConfiguration    a Map of configuration properties from kerberos-env
+   * @param includedInFilter         a Boolean value indicating whather the principal is included in
+   *                                 the current filter or not
    * @param requestSharedDataContext a Map to be used a shared data among all ServerActions related
    *                                 to a given request  @return a CommandReport, indicating an error
    *                                 condition; or null, indicating a success condition
    * @throws AmbariException if an error occurs while processing the identity record
    */
   @Override
-  protected CommandReport processIdentity(Map<String, String> identityRecord, String evaluatedPrincipal,
+  protected CommandReport processIdentity(ResolvedKerberosPrincipal resolvedPrincipal,
                                           KerberosOperationHandler operationHandler,
                                           Map<String, String> kerberosConfiguration,
+                                          boolean includedInFilter,
                                           Map<String, Object> requestSharedDataContext)
       throws AmbariException {
 
@@ -159,148 +158,150 @@ public class CreateKeytabFilesServerAction extends KerberosServerAction {
 
     CommandReport commandReport = null;
     String message = null;
+
+    Set<ResolvedKerberosKeytab> keytabsToCreate = kerberosKeytabController.getFromPrincipalExceptServiceMapping(resolvedPrincipal);
+    KerberosPrincipalEntity principalEntity = kerberosPrincipalDAO.find(resolvedPrincipal.getPrincipal());
+
     try {
-      if (identityRecord != null) {
-        String dataDirectory = getDataDirectoryPath();
+      String dataDirectory = getDataDirectoryPath();
 
-        if (operationHandler == null) {
-          message = String.format("Failed to create keytab file for %s, missing KerberosOperationHandler", evaluatedPrincipal);
-          actionLog.writeStdErr(message);
-          LOG.error(message);
-          commandReport = createCommandReport(1, HostRoleStatus.FAILED, "{}", actionLog.getStdOut(), actionLog.getStdErr());
-        } else if (dataDirectory == null) {
-          message = "The data directory has not been set. Generated keytab files can not be stored.";
-          LOG.error(message);
-          commandReport = createCommandReport(1, HostRoleStatus.FAILED, "{}", actionLog.getStdOut(), actionLog.getStdErr());
-        } else {
-          Map<String, String> principalPasswordMap = getPrincipalPasswordMap(requestSharedDataContext);
-          Map<String, Integer> principalKeyNumberMap = getPrincipalKeyNumberMap(requestSharedDataContext);
+      if (operationHandler == null) {
+        message = String.format("Failed to create keytab file for %s, missing KerberosOperationHandler", resolvedPrincipal.getPrincipal());
+        actionLog.writeStdErr(message);
+        LOG.error(message);
+        commandReport = createCommandReport(1, HostRoleStatus.FAILED, "{}", actionLog.getStdOut(), actionLog.getStdErr());
+      } else if (dataDirectory == null) {
+        message = "The data directory has not been set. Generated keytab files can not be stored.";
+        LOG.error(message);
+        commandReport = createCommandReport(1, HostRoleStatus.FAILED, "{}", actionLog.getStdOut(), actionLog.getStdErr());
+      } else {
+        Map<String, String> principalPasswordMap = getPrincipalPasswordMap(requestSharedDataContext);
+        Map<String, Integer> principalKeyNumberMap = getPrincipalKeyNumberMap(requestSharedDataContext);
 
-          String hostName = identityRecord.get(KerberosIdentityDataFileReader.HOSTNAME);
-          String keytabFilePath = identityRecord.get(KerberosIdentityDataFileReader.KEYTAB_FILE_PATH);
+        for (ResolvedKerberosKeytab rkk : keytabsToCreate) {
+          String hostName = resolvedPrincipal.getHostName();
+          String keytabFilePath = rkk.getFile();
 
-          if ((hostName != null) && !hostName.isEmpty() && (keytabFilePath != null) && !keytabFilePath.isEmpty()) {
-            Set<String> visitedPrincipalKeys = visitedIdentities.get(evaluatedPrincipal);
-            String visitationKey = String.format("%s|%s", hostName, keytabFilePath);
+          if (hostName != null && !hostName.isEmpty() && keytabFilePath != null && !keytabFilePath.isEmpty()) {
+            Lock lock = m_locksByKeytab.get(keytabFilePath);
+            lock.lock();
 
-            if ((visitedPrincipalKeys == null) || !visitedPrincipalKeys.contains(visitationKey)) {
-              // Look up the current evaluatedPrincipal's password.
-              // If found create the keytab file, else try to find it in the cache.
-              String password = principalPasswordMap.get(evaluatedPrincipal);
-              Integer keyNumber = principalKeyNumberMap.get(evaluatedPrincipal);
+            try {
+              Set<String> visitedPrincipalKeys = visitedIdentities.get(resolvedPrincipal.getPrincipal());
+              String visitationKey = String.format("%s|%s", hostName, keytabFilePath);
 
-              message = String.format("Creating keytab file for %s on host %s", evaluatedPrincipal, hostName);
-              LOG.info(message);
-              actionLog.writeStdOut(message);
-              auditEventBuilder.withPrincipal(evaluatedPrincipal).withHostName(hostName).withKeyTabFilePath(keytabFilePath);
+              if ((visitedPrincipalKeys == null) || !visitedPrincipalKeys.contains(visitationKey)) {
+                // Look up the current evaluatedPrincipal's password.
+                // If found create the keytab file, else try to find it in the cache.
+                String password = principalPasswordMap.get(resolvedPrincipal.getPrincipal());
+                Integer keyNumber = principalKeyNumberMap.get(resolvedPrincipal.getPrincipal());
 
-              // Determine where to store the keytab file.  It should go into a host-specific
-              // directory under the previously determined data directory.
-              File hostDirectory = new File(dataDirectory, hostName);
+                message = String.format("Creating keytab file for %s on host %s", resolvedPrincipal.getPrincipal(), hostName);
+                LOG.info(message);
+                actionLog.writeStdOut(message);
+                auditEventBuilder.withPrincipal(resolvedPrincipal.getPrincipal()).withHostName(hostName).withKeyTabFilePath(keytabFilePath);
 
-              // Ensure the host directory exists...
-              if (!hostDirectory.exists() && hostDirectory.mkdirs()) {
-                // Make sure only Ambari has access to this directory.
-                ensureAmbariOnlyAccess(hostDirectory);
-              }
+                // Determine where to store the keytab file.  It should go into a host-specific
+                // directory under the previously determined data directory.
+                File hostDirectory = new File(dataDirectory, hostName);
 
-            if (hostDirectory.exists()) {
-              File destinationKeytabFile = new File(hostDirectory, DigestUtils.sha1Hex(keytabFilePath));
-              HostEntity hostEntity = hostDAO.findByName(hostName);
-              // in case of ambari-server identity there's no host entity for ambari_server host
-              if (hostEntity == null && !hostName.equalsIgnoreCase(KerberosHelper.AMBARI_SERVER_HOST_NAME)) {
-                message = "Failed to find HostEntity for hostname = " + hostName;
-                actionLog.writeStdErr(message);
-                LOG.error(message);
-                commandReport = createCommandReport(1, HostRoleStatus.FAILED, "{}", actionLog.getStdOut(), actionLog.getStdErr());
-                return commandReport;
-              }
+                // Ensure the host directory exists...
+                if (!hostDirectory.exists() && hostDirectory.mkdirs()) {
+                  // Make sure only Ambari has access to this directory.
+                  ensureAmbariOnlyAccess(hostDirectory);
+                }
 
-              boolean canCache = "true".equalsIgnoreCase(identityRecord.get(KerberosIdentityDataFileReader.KEYTAB_FILE_IS_CACHABLE));
-              boolean regenerateKeytabs = "true".equalsIgnoreCase(getCommandParameterValue(getCommandParameters(), REGENERATE_ALL));
-              boolean onlyKeytabWrite = "true".equalsIgnoreCase(identityRecord.get(KerberosIdentityDataFileReader.ONLY_KEYTAB_WRITE));
-              boolean grabKeytabFromCache = regenerateKeytabs && onlyKeytabWrite;
+                if (hostDirectory.exists()) {
+                  File destinationKeytabFile = new File(hostDirectory, DigestUtils.sha256Hex(keytabFilePath));
 
+                  boolean regenerateKeytabs = getOperationType(getCommandParameters()) == OperationType.RECREATE_ALL;
+
+                  if(!includedInFilter) {
+                    // If this principal is to be filtered out, skip... unless is has not yet been created...
+                    regenerateKeytabs = false;
+                  }
 
-              if (password == null) { // if canCache=true we will try to get keytab from cache and send to agent.
-                if (!grabKeytabFromCache && (hostName.equalsIgnoreCase(KerberosHelper.AMBARI_SERVER_HOST_NAME) || kerberosPrincipalHostDAO
-                  .exists(evaluatedPrincipal, hostEntity.getHostId()))) {
-                  // There is nothing to do for this since it must already exist and we don't want to
-                  // regenerate the keytab
-                  message = String.format("Skipping keytab file for %s, missing password indicates nothing to do", evaluatedPrincipal);
-                  LOG.debug(message);
-                } else {
-                  KerberosPrincipalEntity principalEntity = kerberosPrincipalDAO.find(evaluatedPrincipal);
                   String cachedKeytabPath = (principalEntity == null) ? null : principalEntity.getCachedKeytabPath();
 
-                    if (cachedKeytabPath == null) {
-                      message = String.format("Failed to create keytab for %s, missing cached file", evaluatedPrincipal);
-                      actionLog.writeStdErr(message);
-                      LOG.error(message);
-                      commandReport = createCommandReport(1, HostRoleStatus.FAILED, "{}", actionLog.getStdOut(), actionLog.getStdErr());
+                  if (password == null) {
+                    if (!regenerateKeytabs && hostName.equalsIgnoreCase(KerberosHelper.AMBARI_SERVER_HOST_NAME)) {
+                      // There is nothing to do for this since it must already exist and we don't want to
+                      // regenerate the keytab
+                      message = String.format("Skipping keytab file for %s, missing password indicates nothing to do", resolvedPrincipal.getPrincipal());
+                      LOG.info(message);
                     } else {
+                      if (cachedKeytabPath == null) {
+                        message = String.format("Failed to create keytab for %s, missing cached file", resolvedPrincipal.getPrincipal());
+                        actionLog.writeStdErr(message);
+                        LOG.error(message);
+                        commandReport = createCommandReport(1, HostRoleStatus.FAILED, "{}", actionLog.getStdOut(), actionLog.getStdErr());
+                      } else {
+                        try {
+                          operationHandler.createKeytabFile(new File(cachedKeytabPath), destinationKeytabFile);
+                        } catch (KerberosOperationException e) {
+                          message = String.format("Failed to create keytab file for %s - %s", resolvedPrincipal.getPrincipal(), e.getMessage());
+                          actionLog.writeStdErr(message);
+                          LOG.error(message, e);
+                          commandReport = createCommandReport(1, HostRoleStatus.FAILED, "{}", actionLog.getStdOut(), actionLog.getStdErr());
+                        }
+                      }
+                    }
+                  } else {
+                    Keytab keytab = createKeytab(resolvedPrincipal.getPrincipal(), principalEntity, password,
+                      keyNumber, operationHandler, visitedPrincipalKeys != null, true, actionLog);
+
+                    if (keytab != null) {
                       try {
-                        operationHandler.createKeytabFile(new File(cachedKeytabPath), destinationKeytabFile);
+                        if (operationHandler.createKeytabFile(keytab, destinationKeytabFile)) {
+                          ensureAmbariOnlyAccess(destinationKeytabFile);
+
+                          message = String.format("Successfully created keytab file for %s at %s", resolvedPrincipal.getPrincipal(), destinationKeytabFile.getAbsolutePath());
+                          LOG.info(message);
+                          auditEventBuilder.withPrincipal(resolvedPrincipal.getPrincipal()).withHostName(hostName).withKeyTabFilePath(destinationKeytabFile.getAbsolutePath());
+                        } else {
+                          message = String.format("Failed to create keytab file for %s at %s", resolvedPrincipal.getPrincipal(), destinationKeytabFile.getAbsolutePath());
+                          actionLog.writeStdErr(message);
+                          LOG.error(message);
+                          commandReport = createCommandReport(1, HostRoleStatus.FAILED, "{}", actionLog.getStdOut(), actionLog.getStdErr());
+                        }
                       } catch (KerberosOperationException e) {
-                        message = String.format("Failed to create keytab file for %s - %s", evaluatedPrincipal, e.getMessage());
+                        message = String.format("Failed to create keytab file for %s - %s", resolvedPrincipal.getPrincipal(), e.getMessage());
                         actionLog.writeStdErr(message);
                         LOG.error(message, e);
                         commandReport = createCommandReport(1, HostRoleStatus.FAILED, "{}", actionLog.getStdOut(), actionLog.getStdErr());
                       }
-                    }
-                  }
-                } else {
-                  Keytab keytab = createKeytab(evaluatedPrincipal, password, keyNumber, operationHandler, visitedPrincipalKeys != null, canCache, actionLog);
-
-                  if (keytab != null) {
-                    try {
-                      if (operationHandler.createKeytabFile(keytab, destinationKeytabFile)) {
-                        ensureAmbariOnlyAccess(destinationKeytabFile);
-
-                        message = String.format("Successfully created keytab file for %s at %s", evaluatedPrincipal, destinationKeytabFile.getAbsolutePath());
-                        LOG.debug(message);
-                        auditEventBuilder.withPrincipal(evaluatedPrincipal).withHostName(hostName).withKeyTabFilePath(destinationKeytabFile.getAbsolutePath());
-                      } else {
-                        message = String.format("Failed to create keytab file for %s at %s", evaluatedPrincipal, destinationKeytabFile.getAbsolutePath());
-                        actionLog.writeStdErr(message);
-                        LOG.error(message);
-                        commandReport = createCommandReport(1, HostRoleStatus.FAILED, "{}", actionLog.getStdOut(), actionLog.getStdErr());
-                      }
-                    } catch (KerberosOperationException e) {
-                      message = String.format("Failed to create keytab file for %s - %s", evaluatedPrincipal, e.getMessage());
-                      actionLog.writeStdErr(message);
-                      LOG.error(message, e);
+                    } else {
                       commandReport = createCommandReport(1, HostRoleStatus.FAILED, "{}", actionLog.getStdOut(), actionLog.getStdErr());
                     }
-                  } else {
-                    commandReport = createCommandReport(1, HostRoleStatus.FAILED, "{}", actionLog.getStdOut(), actionLog.getStdErr());
-                  }
 
-                  if (visitedPrincipalKeys == null) {
-                    visitedPrincipalKeys = new HashSet<String>();
-                    visitedIdentities.put(evaluatedPrincipal, visitedPrincipalKeys);
-                  }
+                    if (visitedPrincipalKeys == null) {
+                      visitedPrincipalKeys = new HashSet<>();
+                      visitedIdentities.put(resolvedPrincipal.getPrincipal(), visitedPrincipalKeys);
+                    }
 
-                  visitedPrincipalKeys.add(visitationKey);
+                    visitedPrincipalKeys.add(visitationKey);
+                  }
+                } else {
+                  message = String.format("Failed to create keytab file for %s, the container directory does not exist: %s",
+                      resolvedPrincipal.getPrincipal(), hostDirectory.getAbsolutePath());
+                  actionLog.writeStdErr(message);
+                  LOG.error(message);
+                  commandReport = createCommandReport(1, HostRoleStatus.FAILED, "{}", actionLog.getStdOut(), actionLog.getStdErr());
                 }
               } else {
-                message = String.format("Failed to create keytab file for %s, the container directory does not exist: %s",
-                  evaluatedPrincipal, hostDirectory.getAbsolutePath());
-                actionLog.writeStdErr(message);
-                LOG.error(message);
-                commandReport = createCommandReport(1, HostRoleStatus.FAILED, "{}", actionLog.getStdOut(), actionLog.getStdErr());
+                LOG.debug("Skipping previously processed keytab for {} on host {}", resolvedPrincipal.getPrincipal(), hostName);
               }
-            } else {
-              LOG.debug(String.format("Skipping previously processed keytab for %s on host %s", evaluatedPrincipal, hostName));
+            } finally {
+              lock.unlock();
             }
           }
         }
       }
     } finally {
-      if(commandReport != null && HostRoleStatus.FAILED.toString().equals(commandReport.getStatus())) {
+      if (commandReport != null && HostRoleStatus.FAILED.toString().equals(commandReport.getStatus())) {
         auditEventBuilder.withReasonOfFailure(message == null ? "Unknown error" : message);
       }
-      if(commandReport != null || auditEventBuilder.hasPrincipal()) {
+      if (commandReport != null || auditEventBuilder.hasPrincipal()) {
         auditLog(auditEventBuilder.build());
       }
     }
@@ -320,30 +321,23 @@ public class CreateKeytabFilesServerAction extends KerberosServerAction {
    * @return a Keytab
    * @throws AmbariException
    */
-  public Keytab createKeytab(String principal, String password, Integer keyNumber,
-                             KerberosOperationHandler operationHandler, boolean checkCache,
+  public Keytab createKeytab(String principal, KerberosPrincipalEntity principalEntity, String password,
+                             Integer keyNumber, KerberosOperationHandler operationHandler, boolean checkCache,
                              boolean canCache, ActionLog actionLog) throws AmbariException {
-    LOG.debug("Creating keytab for " + principal + " with kvno " + keyNumber);
+
+    LOG.debug("Creating keytab for {} with kvno {}", principal, keyNumber);
     Keytab keytab = null;
 
     // Possibly get the keytab from the cache
     if (checkCache) {
       // Attempt to pull the keytab from the cache...
-      KerberosPrincipalEntity principalEntity = kerberosPrincipalDAO.find(principal);
       String cachedKeytabPath = (principalEntity == null) ? null : principalEntity.getCachedKeytabPath();
 
       if (cachedKeytabPath != null) {
         try {
           keytab = Keytab.read(new File(cachedKeytabPath));
         } catch (IOException e) {
-          String message = String.format("Failed to read the cached keytab for %s, recreating if possible - %s",
-              principal, e.getMessage());
-
-          if (LOG.isDebugEnabled()) {
-            LOG.warn(message, e);
-          } else {
-            LOG.warn(message, e);
-          }
+          LOG.warn("Failed to read the cached keytab for {}, recreating if possible - {}", principal, e.getMessage());
         }
       }
     }
@@ -355,21 +349,20 @@ public class CreateKeytabFilesServerAction extends KerberosServerAction {
 
         // If the current identity does not represent a service, copy it to a secure location
         // and store that location so it can be reused rather than recreate it.
-        KerberosPrincipalEntity principalEntity = kerberosPrincipalDAO.find(principal);
         if (principalEntity != null) {
-          if (!principalEntity.isService() && canCache) {
+          if (canCache) {
             File cachedKeytabFile = cacheKeytab(principal, keytab);
             String previousCachedFilePath = principalEntity.getCachedKeytabPath();
-            String cachedKeytabFilePath = ((cachedKeytabFile == null) || !cachedKeytabFile.exists())
-                    ? null
-                    : cachedKeytabFile.getAbsolutePath();
+            String cachedKeytabFilePath = (cachedKeytabFile.exists()) ? cachedKeytabFile.getAbsolutePath() : null;
 
-            principalEntity.setCachedKeytabPath(cachedKeytabFilePath);
-            kerberosPrincipalDAO.merge(principalEntity);
+            if (previousCachedFilePath != null && !previousCachedFilePath.equals(cachedKeytabFilePath)) {
+              principalEntity.setCachedKeytabPath(cachedKeytabFilePath);
+              kerberosPrincipalDAO.merge(principalEntity);
+            }
 
             if (previousCachedFilePath != null) {
               if (!new File(previousCachedFilePath).delete()) {
-                LOG.debug(String.format("Failed to remove orphaned cache file %s", previousCachedFilePath));
+                LOG.debug("Failed to remove orphaned cache file {}", previousCachedFilePath);
               }
             }
           }
@@ -423,7 +416,7 @@ public class CreateKeytabFilesServerAction extends KerberosServerAction {
       }
     }
 
-    File cachedKeytabFile = new File(cacheDirectory, DigestUtils.sha1Hex(principal + String.valueOf(System.currentTimeMillis())));
+    File cachedKeytabFile = new File(cacheDirectory, DigestUtils.sha256Hex(principal + String.valueOf(System.currentTimeMillis())));
 
     try {
       keytab.write(cachedKeytabFile);
