@@ -38,8 +38,15 @@ import org.apache.ambari.server.actionmanager.HostRoleStatus;
 import org.apache.ambari.server.agent.CommandReport;
 import org.apache.ambari.server.controller.AmbariManagementController;
 import org.apache.ambari.server.controller.KerberosHelper;
+import org.apache.ambari.server.controller.RootComponent;
+import org.apache.ambari.server.controller.RootService;
+import org.apache.ambari.server.orm.dao.HostDAO;
+import org.apache.ambari.server.orm.dao.KerberosKeytabPrincipalDAO;
+import org.apache.ambari.server.orm.entities.HostEntity;
+import org.apache.ambari.server.orm.entities.KerberosKeytabPrincipalEntity;
 import org.apache.ambari.server.orm.entities.RepositoryVersionEntity;
 import org.apache.ambari.server.serveraction.kerberos.PreconfigureServiceType;
+import org.apache.ambari.server.serveraction.kerberos.stageutils.ResolvedKerberosKeytab;
 import org.apache.ambari.server.state.Cluster;
 import org.apache.ambari.server.state.ConfigHelper;
 import org.apache.ambari.server.state.Host;
@@ -56,6 +63,7 @@ import org.apache.ambari.server.state.kerberos.KerberosIdentityDescriptor;
 import org.apache.ambari.server.state.kerberos.KerberosServiceDescriptor;
 import org.apache.ambari.server.state.kerberos.VariableReplacementHelper;
 import org.apache.ambari.server.state.stack.upgrade.Direction;
+import org.apache.ambari.server.utils.StageUtils;
 import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.collections.MapUtils;
 import org.apache.commons.lang.StringUtils;
@@ -82,6 +90,12 @@ public class PreconfigureKerberosAction extends AbstractUpgradeServerAction {
   @Inject
   private VariableReplacementHelper variableReplacementHelper;
 
+  @Inject
+  private HostDAO hostDAO;
+
+  @Inject
+  private KerberosKeytabPrincipalDAO kerberosKeytabPrincipalDAO;
+
   @Override
   public CommandReport execute(ConcurrentMap<String, Object> requestSharedDataContext) throws AmbariException, InterruptedException {
     Map<String, String> commandParameters = getCommandParameters();
@@ -92,7 +106,7 @@ public class PreconfigureKerberosAction extends AbstractUpgradeServerAction {
 
     if (!isDowngrade()) {
       String clusterName = commandParameters.get("clusterName");
-      Cluster cluster = m_clusters.getCluster(clusterName);
+      Cluster cluster = getClusters().getCluster(clusterName);
 
       if (cluster.getSecurityType() == SecurityType.KERBEROS) {
         StackId stackId;
@@ -108,11 +122,11 @@ public class PreconfigureKerberosAction extends AbstractUpgradeServerAction {
               "The target stack Id was not specified.");
         }
 
-        KerberosDescriptor kerberosDescriptor = kerberosHelper.getKerberosDescriptor(KerberosHelper.KerberosDescriptorType.COMPOSITE, cluster, stackId, true);
+        KerberosDescriptor kerberosDescriptor = kerberosHelper.getKerberosDescriptor(KerberosHelper.KerberosDescriptorType.COMPOSITE, cluster, stackId, true, null);
 
         // Calculate the current host-specific configurations. These will be used to replace
         // variables within the Kerberos descriptor data
-        Map<String, Map<String, String>> configurations = kerberosHelper.calculateConfigurations(cluster, null, kerberosDescriptor, true, false);
+        Map<String, Map<String, String>> configurations = kerberosHelper.calculateConfigurations(cluster, null, kerberosDescriptor, true, false, null);
 
         PreconfigureServiceType preconfigureServiceType = getPreconfigureServiceType(configurations);
 
@@ -131,7 +145,7 @@ public class PreconfigureKerberosAction extends AbstractUpgradeServerAction {
             }
           }
 
-          processServiceComponentHosts(cluster, kerberosDescriptor, configurations, kerberosConfigurations, propertiesToIgnore);
+          processServiceComponentHosts(cluster, kerberosDescriptor, configurations, kerberosConfigurations, propertiesToIgnore, getDefaultRealm(configurations));
 
           // Calculate the set of configurations to update and replace any variables
           // using the previously calculated Map of configurations for the host.
@@ -280,7 +294,7 @@ public class PreconfigureKerberosAction extends AbstractUpgradeServerAction {
   private void processServiceComponentHosts(Cluster cluster, KerberosDescriptor kerberosDescriptor,
                                             Map<String, Map<String, String>> currentConfigurations,
                                             Map<String, Map<String, String>> kerberosConfigurations,
-                                            Map<String, Set<String>> propertiesToBeIgnored)
+                                            Map<String, Set<String>> propertiesToBeIgnored, String realm)
       throws AmbariException {
 
     Collection<Host> hosts = cluster.getHosts();
@@ -292,7 +306,7 @@ public class PreconfigureKerberosAction extends AbstractUpgradeServerAction {
 
       try {
         Map<String, Set<String>> propertiesToIgnore = null;
-
+        HashMap<String, ResolvedKerberosKeytab> resolvedKeytabs = new HashMap<>();
         for (Host host : hosts) {
           // Iterate over the components installed on the current host to get the service and
           // component-level Kerberos descriptors in order to determine which principals,
@@ -323,7 +337,8 @@ public class PreconfigureKerberosAction extends AbstractUpgradeServerAction {
 
               // Add service-level principals (and keytabs)
               kerberosHelper.addIdentities(null, serviceIdentities,
-                  null, hostName, serviceName, componentName, kerberosConfigurations, currentConfigurations, false);
+                  null, hostName, host.getHostId(), serviceName, componentName, kerberosConfigurations, currentConfigurations,
+                  resolvedKeytabs, realm);
               propertiesToIgnore = gatherPropertiesToIgnore(serviceIdentities, propertiesToIgnore);
 
               KerberosComponentDescriptor componentDescriptor = serviceDescriptor.getComponent(componentName);
@@ -338,7 +353,8 @@ public class PreconfigureKerberosAction extends AbstractUpgradeServerAction {
 
                 // Add component-level principals (and keytabs)
                 kerberosHelper.addIdentities(null, componentIdentities,
-                    null, hostName, serviceName, componentName, kerberosConfigurations, currentConfigurations, false);
+                    null, hostName, host.getHostId(), serviceName, componentName, kerberosConfigurations, currentConfigurations,
+                    resolvedKeytabs,realm);
                 propertiesToIgnore = gatherPropertiesToIgnore(componentIdentities, propertiesToIgnore);
               }
             }
@@ -355,11 +371,12 @@ public class PreconfigureKerberosAction extends AbstractUpgradeServerAction {
             // component.
             String componentName = KerberosHelper.AMBARI_SERVER_KERBEROS_IDENTITY_NAME.equals(identity.getName())
                 ? "AMBARI_SERVER_SELF"
-                : "AMBARI_SERVER";
+                : RootComponent.AMBARI_SERVER.name();
 
             List<KerberosIdentityDescriptor> componentIdentities = Collections.singletonList(identity);
             kerberosHelper.addIdentities(null, componentIdentities,
-                null, KerberosHelper.AMBARI_SERVER_HOST_NAME, "AMBARI", componentName, kerberosConfigurations, currentConfigurations, false);
+                null, KerberosHelper.AMBARI_SERVER_HOST_NAME, ambariServerHostID(), RootService.AMBARI.name(), componentName, kerberosConfigurations, currentConfigurations,
+                resolvedKeytabs, realm);
             propertiesToIgnore = gatherPropertiesToIgnore(componentIdentities, propertiesToIgnore);
           }
         }
@@ -367,6 +384,10 @@ public class PreconfigureKerberosAction extends AbstractUpgradeServerAction {
         if ((propertiesToBeIgnored != null) && (propertiesToIgnore != null)) {
           propertiesToBeIgnored.putAll(propertiesToIgnore);
         }
+
+        // create database records for keytab that must be presented on cluster
+        List<KerberosKeytabPrincipalEntity> keytabList = kerberosKeytabPrincipalDAO.findAll();
+        resolvedKeytabs.values().forEach(keytab -> kerberosHelper.createResolvedKeytab(keytab, keytabList));
       } catch (IOException e) {
         throw new AmbariException(e.getMessage(), e);
       }
@@ -582,5 +603,14 @@ public class PreconfigureKerberosAction extends AbstractUpgradeServerAction {
       }
     }
   }
+
+  protected Long ambariServerHostID(){
+    String ambariServerHostName = StageUtils.getHostName();
+    HostEntity ambariServerHostEntity = hostDAO.findByName(ambariServerHostName);
+    return (ambariServerHostEntity == null)
+        ? null
+        : ambariServerHostEntity.getHostId();
+  }
+
 }
 
