@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -18,17 +18,22 @@
 
 package org.apache.ambari.server.stack;
 
-import com.google.common.base.Function;
-import com.google.common.collect.ImmutableList;
-import com.google.common.collect.Iterables;
-import com.google.common.collect.Lists;
-import com.google.common.collect.Sets;
+import java.io.File;
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.Collections;
+import java.util.HashMap;
+import java.util.HashSet;
+import java.util.List;
+import java.util.Map;
+import java.util.Set;
+
+import javax.annotation.Nullable;
 
 import org.apache.ambari.server.AmbariException;
 import org.apache.ambari.server.api.services.AmbariMetaInfo;
 import org.apache.ambari.server.state.ComponentInfo;
 import org.apache.ambari.server.state.CustomCommandDefinition;
-import org.apache.ambari.server.state.PropertyInfo;
 import org.apache.ambari.server.state.QuickLinksConfigurationInfo;
 import org.apache.ambari.server.state.ServiceInfo;
 import org.apache.ambari.server.state.ServicePropertyInfo;
@@ -39,17 +44,11 @@ import org.apache.commons.lang.builder.ToStringStyle;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import javax.annotation.Nullable;
-
-import java.io.File;
-import java.util.ArrayList;
-import java.util.Collection;
-import java.util.Collections;
-import java.util.HashMap;
-import java.util.HashSet;
-import java.util.List;
-import java.util.Map;
-import java.util.Set;
+import com.google.common.base.Function;
+import com.google.common.collect.ImmutableList;
+import com.google.common.collect.Iterables;
+import com.google.common.collect.Lists;
+import com.google.common.collect.Sets;
 
 
 /**
@@ -71,23 +70,23 @@ public class ServiceModule extends BaseModule<ServiceModule, ServiceInfo> implem
    * Map of child configuration modules keyed by configuration type
    */
   private Map<String, ConfigurationModule> configurationModules =
-      new HashMap<String, ConfigurationModule>();
+    new HashMap<>();
 
   /**
    * Map of child component modules keyed by component name
    */
   private Map<String, ComponentModule> componentModules =
-      new HashMap<String, ComponentModule>();
+    new HashMap<>();
 
   /**
    * Map of themes, single value currently
    */
-  private Map<String, ThemeModule> themeModules = new HashMap<String, ThemeModule>();
+  private Map<String, ThemeModule> themeModules = new HashMap<>();
 
   /**
    * Map of quicklinks, single value currently
    */
-  private Map<String, QuickLinksConfigurationModule> quickLinksConfigurationModules = new HashMap<String, QuickLinksConfigurationModule>();
+  private Map<String, QuickLinksConfigurationModule> quickLinksConfigurationModules = new HashMap<>();
 
   /**
    * Encapsulates IO operations on service directory
@@ -109,6 +108,13 @@ public class ServiceModule extends BaseModule<ServiceModule, ServiceInfo> implem
    */
   private final static Logger LOG = LoggerFactory.getLogger(ServiceModule.class);
 
+  /**
+   * Most of the services contain at least one config type.
+   * However, there are special cases on third party stacks
+   * that certain services do not have any config types.
+   * */
+  private boolean hasConfigs = true;
+
   /**
    * Constructor.
    *
@@ -182,7 +188,7 @@ public class ServiceModule extends BaseModule<ServiceModule, ServiceInfo> implem
       return;
     }
 
-    LOG.info("Resolve service");
+    LOG.debug("Resolve service");
 
     // If resolving against parent stack service module (stack inheritance), do not merge if an
     // explicit parent is specified
@@ -195,10 +201,17 @@ public class ServiceModule extends BaseModule<ServiceModule, ServiceInfo> implem
     if (serviceInfo.getComment() == null) {
       serviceInfo.setComment(parent.getComment());
     }
-    LOG.info("Display name service/parent: " + serviceInfo.getDisplayName() + "/" + parent.getDisplayName());
+    LOG.info(String.format("Display name service/parent: %s/%s", serviceInfo.getDisplayName(), parent.getDisplayName()));
     if (serviceInfo.getDisplayName() == null) {
       serviceInfo.setDisplayName(parent.getDisplayName());
     }
+    if (serviceInfo.getServiceType() == null) {
+      serviceInfo.setServiceType(parent.getServiceType());
+    }
+    if (serviceInfo.getServiceAdvisorType() == null) {
+      ServiceInfo.ServiceAdvisorType serviceAdvisorType = parent.getServiceAdvisorType();
+      serviceInfo.setServiceAdvisorType(serviceAdvisorType == null ? ServiceInfo.ServiceAdvisorType.PYTHON : serviceAdvisorType);
+    }
     if (serviceInfo.getVersion() == null) {
       serviceInfo.setVersion(parent.getVersion());
     }
@@ -207,7 +220,7 @@ public class ServiceModule extends BaseModule<ServiceModule, ServiceInfo> implem
         || serviceInfo.getRequiredServices().size() == 0) {
       serviceInfo.setRequiredServices(parent.getRequiredServices() != null ?
           parent.getRequiredServices() :
-          Collections.<String>emptyList());
+          Collections.emptyList());
     }
 
     if (serviceInfo.isRestartRequiredAfterChange() == null) {
@@ -267,7 +280,7 @@ public class ServiceModule extends BaseModule<ServiceModule, ServiceInfo> implem
       serviceInfo.setServerActionsFolder(parent.getServerActionsFolder());
     }
 
-    /**
+    /*
      * If current stack version does not specify the credential store information
      * for the service, then use parent definition.
      */
@@ -275,10 +288,22 @@ public class ServiceModule extends BaseModule<ServiceModule, ServiceInfo> implem
       serviceInfo.setCredentialStoreInfo(parent.getCredentialStoreInfo());
     }
 
+    /*
+     * If current stack version does not specify the single sign-on support details for the service,
+     * then use parent definition.
+     */
+    if (serviceInfo.getSingleSignOnInfo() == null) {
+      serviceInfo.setSingleSignOnInfo(parent.getSingleSignOnInfo());
+    }
+
     if (serviceInfo.isSelectionEmpty()) {
       serviceInfo.setSelection(parent.getSelection());
     }
 
+    if(null == serviceInfo.getSupportDeleteViaUIField()){
+      serviceInfo.setSupportDeleteViaUI(parent.isSupportDeleteViaUI());
+    }
+
     mergeCustomCommands(parent.getCustomCommands(), serviceInfo.getCustomCommands());
     mergeConfigDependencies(parent);
     mergeComponents(parentModule, allStacks, commonServices, extensions);
@@ -419,7 +444,7 @@ public class ServiceModule extends BaseModule<ServiceModule, ServiceInfo> implem
       for (String excludedType : serviceInfo.getExcludedConfigTypes()) {
         if (! configurationModules.containsKey(excludedType)) {
           ConfigurationInfo configInfo = new ConfigurationInfo(
-              Collections.<PropertyInfo>emptyList(), Collections.<String, String>emptyMap());
+              Collections.emptyList(), Collections.emptyMap());
           ConfigurationModule config = new ConfigurationModule(excludedType, configInfo);
 
           config.setDeleted(true);
@@ -438,7 +463,7 @@ public class ServiceModule extends BaseModule<ServiceModule, ServiceInfo> implem
     String themesDir = serviceDirectory.getAbsolutePath() + File.separator + serviceInfo.getThemesDir();
 
     if (serviceInfo.getThemes() != null) {
-      List<ThemeInfo> themes = new ArrayList<ThemeInfo>(serviceInfo.getThemes().size());
+      List<ThemeInfo> themes = new ArrayList<>(serviceInfo.getThemes().size());
       for (ThemeInfo themeInfo : serviceInfo.getThemes()) {
         File themeFile = new File(themesDir + File.separator + themeInfo.getFileName());
         ThemeModule module = new ThemeModule(themeFile, themeInfo);
@@ -538,7 +563,7 @@ public class ServiceModule extends BaseModule<ServiceModule, ServiceInfo> implem
     //currently there is no way to remove an inherited config dependency
     List<String> configDependencies = serviceInfo.getConfigDependencies();
     List<String> parentConfigDependencies = parent.getConfigDependencies() != null ?
-        parent.getConfigDependencies() : Collections.<String>emptyList();
+        parent.getConfigDependencies() : Collections.emptyList();
 
     if (configDependencies == null) {
       serviceInfo.setConfigDependencies(parentConfigDependencies);
@@ -563,11 +588,10 @@ public class ServiceModule extends BaseModule<ServiceModule, ServiceInfo> implem
       ServiceModule parent, Map<String, StackModule> allStacks, Map<String, ServiceModule> commonServices, Map<String, ExtensionModule> extensions)
       throws AmbariException {
     serviceInfo.getProperties().clear();
-    serviceInfo.setAllConfigAttributes(new HashMap<String, Map<String, Map<String, String>>>());
+    serviceInfo.setAllConfigAttributes(new HashMap<>());
 
     Collection<ConfigurationModule> mergedModules = mergeChildModules(
         allStacks, commonServices, extensions, configurationModules, parent.configurationModules);
-
     for (ConfigurationModule module : mergedModules) {
       configurationModules.put(module.getId(), module);
       if(!module.isDeleted()) {
@@ -610,7 +634,7 @@ public class ServiceModule extends BaseModule<ServiceModule, ServiceInfo> implem
   private void mergeCustomCommands(Collection<CustomCommandDefinition> parentCmds,
                                    Collection<CustomCommandDefinition> childCmds) {
 
-    Collection<String> existingNames = new HashSet<String>();
+    Collection<String> existingNames = new HashSet<>();
 
     for (CustomCommandDefinition childCmd : childCmds) {
       existingNames.add(childCmd.getName());
@@ -627,6 +651,10 @@ public class ServiceModule extends BaseModule<ServiceModule, ServiceInfo> implem
    * Ensure that all default type attributes are set.
    */
   private void finalizeConfiguration() {
+    LOG.debug("Finalize config, number of configuration modules {}", configurationModules.size());
+    hasConfigs = !(configurationModules.isEmpty());
+    LOG.debug("Finalize config, hasConfigs {}", hasConfigs);
+
     for (ConfigurationModule config : configurationModules.values()) {
       ConfigurationInfo configInfo = config.getModuleInfo();
       configInfo.ensureDefaultAttributes();
@@ -644,7 +672,7 @@ public class ServiceModule extends BaseModule<ServiceModule, ServiceInfo> implem
     this.valid = valid;
   }
 
-  private Set<String> errorSet = new HashSet<String>();
+  private Set<String> errorSet = new HashSet<>();
 
   @Override
   public void addError(String error) {
@@ -676,6 +704,12 @@ public class ServiceModule extends BaseModule<ServiceModule, ServiceInfo> implem
     }
   }
 
+  /**
+   * Whether the service is a special case where it does not include any config types
+   * */
+  public boolean hasConfigs(){
+    return hasConfigs;
+  }
 
   @Override
   public String toString() {
