@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -17,10 +17,6 @@
  */
 package org.apache.ambari.server.utils;
 
-import org.apache.commons.lang.StringUtils;
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-
 import java.io.BufferedReader;
 import java.io.BufferedWriter;
 import java.io.IOException;
@@ -31,11 +27,16 @@ import java.util.ArrayList;
 import java.util.List;
 import java.util.Map;
 
+import org.apache.commons.lang.StringUtils;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
+
 /**
  * Logs OpenSsl command exit code with description
  */
 public class ShellCommandUtil {
-  private static final Log LOG = LogFactory.getLog(ShellCommandUtil.class);
+  private static final Logger LOG = LoggerFactory.getLogger(ShellCommandUtil.class);
   private static final Object WindowsProcessLaunchLock = new Object();
   private static final String PASS_TOKEN = "pass:";
   private static final String KEY_TOKEN = "-key ";
@@ -162,11 +163,9 @@ public class ShellCommandUtil {
     if (LINUX) {
       try {
         result = runCommand(new String[]{"stat", "-c", "%a", path}).getStdout();
-      } catch (IOException e) {
+      } catch (IOException | InterruptedException e) {
         // Improbable
         LOG.warn(String.format("Can not perform stat on %s", path), e);
-      } catch (InterruptedException e) {
-        LOG.warn(String.format("Can not perform stat on %s", path), e);
       }
     } else {
       LOG.debug(String.format("Not performing stat -s \"%%a\" command on file %s " +
@@ -186,11 +185,9 @@ public class ShellCommandUtil {
     if (LINUX) {
       try {
         runCommand(new String[]{"chmod", mode, path});
-      } catch (IOException e) {
+      } catch (IOException | InterruptedException e) {
         // Improbable
         LOG.warn(String.format("Can not perform chmod %s %s", mode, path), e);
-      } catch (InterruptedException e) {
-        LOG.warn(String.format("Can not perform chmod %s %s", mode, path), e);
       }
     } else {
       LOG.debug(String.format("Not performing chmod %s command for file %s " +
@@ -211,13 +208,10 @@ public class ShellCommandUtil {
       if (!StringUtils.isEmpty(ownerName)) {
         try {
           return runCommand(new String[]{"chown", ownerName, path}, null, null, true);
-        } catch (IOException e) {
+        } catch (IOException | InterruptedException e) {
           // Improbable
           LOG.warn(String.format("Can not perform chown %s %s", ownerName, path), e);
           return new Result(-1, "", "Cannot perform operation: " + e.getLocalizedMessage());
-        } catch (InterruptedException e) {
-          LOG.warn(String.format("Can not perform chown %s %s", ownerName, path), e);
-          return new Result(-1, "", "Cannot perform operation: " + e.getLocalizedMessage());
         }
       } else {
         return new Result(0, "", "");
@@ -242,13 +236,10 @@ public class ShellCommandUtil {
       if (!StringUtils.isEmpty(groupName)) {
         try {
           return runCommand(new String[]{"chgrp", groupName, path}, null, null, true);
-        } catch (IOException e) {
+        } catch (IOException | InterruptedException e) {
           // Improbable
           LOG.warn(String.format("Can not perform chgrp %s %s", groupName, path), e);
           return new Result(-1, "", "Cannot perform operation: " + e.getLocalizedMessage());
-        } catch (InterruptedException e) {
-          LOG.warn(String.format("Can not perform chgrp %s %s", groupName, path), e);
-          return new Result(-1, "", "Cannot perform operation: " + e.getLocalizedMessage());
         }
       } else {
         return new Result(0, "", "");
@@ -293,13 +284,10 @@ public class ShellCommandUtil {
 
       try {
         return runCommand(new String[]{"chmod", mode, path}, null, null, true);
-      } catch (IOException e) {
+      } catch (IOException | InterruptedException e) {
         // Improbable
         LOG.warn(String.format("Can not perform chmod %s %s", mode, path), e);
         return new Result(-1, "", "Cannot perform operation: " + e.getLocalizedMessage());
-      } catch (InterruptedException e) {
-        LOG.warn(String.format("Can not perform chmod %s %s", mode, path), e);
-        return new Result(-1, "", "Cannot perform operation: " + e.getLocalizedMessage());
       }
     } else {
       LOG.debug(String.format("Not performing chmod command for file %s " +
@@ -339,7 +327,7 @@ public class ShellCommandUtil {
     if (pathExists(directoryPath, sudo).isSuccessful()) {
       return new Result(0, "The directory already exists, skipping.", ""); // Success!
     } else {
-      ArrayList<String> command = new ArrayList<String>();
+      ArrayList<String> command = new ArrayList<>();
 
       command.add("/bin/mkdir");
 
@@ -364,7 +352,7 @@ public class ShellCommandUtil {
    * @return the shell command result
    */
   public static Result copyFile(String srcFile, String destFile, boolean force, boolean sudo) throws IOException, InterruptedException {
-    ArrayList<String> command = new ArrayList<String>();
+    ArrayList<String> command = new ArrayList<>();
 
     if (WINDOWS) {
       command.add("copy");
