@@ -29,7 +29,9 @@ from resource_management.libraries.functions import namenode_ha_utils
 from resource_management.libraries.functions.decorator import retry
 from resource_management.libraries.functions.format import format
 from resource_management.libraries.functions.check_process_status import check_process_status
+from resource_management.libraries.functions.namenode_ha_utils import get_name_service_by_hostname
 from resource_management.libraries.resources.execute_hadoop import ExecuteHadoop
+from resource_management.libraries.resources.execute_hdfs import ExecuteHDFS
 from resource_management.libraries.functions import Direction
 from ambari_commons import OSCheck, OSConst
 from ambari_commons.os_family_impl import OsFamilyImpl, OsFamilyFuncImpl
@@ -47,7 +49,7 @@ from setup_ranger_hdfs import setup_ranger_hdfs, create_ranger_audit_hdfs_direct
 
 import namenode_upgrade
 
-def wait_for_safemode_off(hdfs_binary, afterwait_sleep=0, execute_kinit=False):
+def wait_for_safemode_off(hdfs_binary, afterwait_sleep=0, execute_kinit=False, retries=115, sleep_seconds=10):
   """
   During NonRolling (aka Express Upgrade), after starting NameNode, which is still in safemode, and then starting
   all of the DataNodes, we need for NameNode to receive all of the block reports and leave safemode.
@@ -55,8 +57,6 @@ def wait_for_safemode_off(hdfs_binary, afterwait_sleep=0, execute_kinit=False):
   """
   import params
 
-  retries = 115
-  sleep_seconds = 10
   sleep_minutes = int(sleep_seconds * retries / 60)
 
   Logger.info("Waiting up to {0} minutes for the NameNode to leave Safemode...".format(sleep_minutes))
@@ -122,7 +122,6 @@ def namenode(action=None, hdfs_binary=None, do_format=True, upgrade_type=None,
       format_namenode()
       pass
 
-
     if params.dfs_ha_enabled and \
       params.dfs_ha_namenode_standby is not None and \
       (params.hostname == params.dfs_ha_namenode_standby or params.public_hostname == params.dfs_ha_namenode_standby):
@@ -179,6 +178,8 @@ def namenode(action=None, hdfs_binary=None, do_format=True, upgrade_type=None,
       Execute(format("{kinit_path_local} -kt {hdfs_user_keytab} {hdfs_principal_name}"),
               user = params.hdfs_user)
 
+    name_service = get_name_service_by_hostname(params.hdfs_site, params.hostname)
+
     # ___Scenario___________|_Expected safemode state__|_Wait for safemode OFF____|
     # no-HA                 | ON -> OFF                | Yes                      |
     # HA and active         | ON -> OFF                | Yes                      |
@@ -200,7 +201,7 @@ def namenode(action=None, hdfs_binary=None, do_format=True, upgrade_type=None,
     if params.dfs_ha_enabled:
       Logger.info("Waiting for the NameNode to broadcast whether it is Active or Standby...")
 
-      if is_this_namenode_active() is False:
+      if is_this_namenode_active(name_service) is False:
         # we are the STANDBY NN
         is_active_namenode = False
 
@@ -225,13 +226,17 @@ def namenode(action=None, hdfs_binary=None, do_format=True, upgrade_type=None,
 
     # wait for Safemode to end
     if ensure_safemode_off:
-      wait_for_safemode_off(hdfs_binary)
+      if params.rolling_restart and params.rolling_restart_safemode_exit_timeout:
+        calculated_retries = int(params.rolling_restart_safemode_exit_timeout) / 30
+        wait_for_safemode_off(hdfs_binary, afterwait_sleep=30, retries=calculated_retries, sleep_seconds=30)
+      else:
+        wait_for_safemode_off(hdfs_binary)
 
     # Always run this on the "Active" NN unless Safemode has been ignored
     # in the case where safemode was ignored (like during an express upgrade), then
     # NN will be in SafeMode and cannot have directories created
     if is_active_namenode and ensure_safemode_off:
-      create_hdfs_directories()
+      create_hdfs_directories(name_service)
       create_ranger_audit_hdfs_directories()
     else:
       Logger.info("Skipping creation of HDFS directories since this is either not the Active NameNode or we did not wait for Safemode to finish.")
@@ -291,20 +296,24 @@ def create_name_dirs(directories):
   )
 
 
-def create_hdfs_directories():
+def create_hdfs_directories(name_service):
   import params
 
+  name_services = None if name_service is None else [name_service]
+
   params.HdfsResource(params.hdfs_tmp_dir,
                        type="directory",
                        action="create_on_execute",
                        owner=params.hdfs_user,
                        mode=0777,
+                       nameservices=name_services,
   )
   params.HdfsResource(params.smoke_hdfs_user_dir,
                        type="directory",
                        action="create_on_execute",
                        owner=params.smoke_user,
                        mode=params.smoke_hdfs_user_mode,
+                       nameservices=name_services,
   )
   params.HdfsResource(None,
                       action="execute",
@@ -428,6 +437,28 @@ def is_namenode_formatted(params):
 
   return False
 
+
+@OsFamilyFuncImpl(os_family=OsFamilyImpl.DEFAULT)
+def refreshProxyUsers():
+  import params
+
+  if params.security_enabled:
+    Execute(params.nn_kinit_cmd,
+            user=params.hdfs_user
+            )
+
+  if params.dfs_ha_enabled:
+    # due to a bug in hdfs, refreshNodes will not run on both namenodes so we
+    # need to execute each command scoped to a particular namenode
+    nn_refresh_cmd = format('dfsadmin -fs hdfs://{namenode_rpc} -refreshSuperUserGroupsConfiguration')
+  else:
+    nn_refresh_cmd = format('dfsadmin -fs {namenode_address} -refreshSuperUserGroupsConfiguration')
+  ExecuteHDFS(nn_refresh_cmd,
+              user=params.hdfs_user,
+              conf_dir=params.hadoop_conf_dir,
+              bin_dir=params.hadoop_bin_dir)
+
+
 @OsFamilyFuncImpl(os_family=OsFamilyImpl.DEFAULT)
 def decommission():
   import params
@@ -462,10 +493,11 @@ def decommission():
       nn_refresh_cmd = format('dfsadmin -fs hdfs://{namenode_rpc} -refreshNodes')
     else:
       nn_refresh_cmd = format('dfsadmin -fs {namenode_address} -refreshNodes')
-    ExecuteHadoop(nn_refresh_cmd,
-                  user=hdfs_user,
-                  conf_dir=conf_dir,
-                  bin_dir=params.hadoop_bin_dir)
+    ExecuteHDFS(nn_refresh_cmd,
+                user=hdfs_user,
+                conf_dir=conf_dir,
+                bin_dir=params.hadoop_bin_dir)
+
 
 @OsFamilyFuncImpl(os_family=OSConst.WINSRV_FAMILY)
 def decommission():
@@ -481,17 +513,16 @@ def decommission():
   if params.hdfs_include_file:
     File(params.include_file_path,
          content=Template("include_hosts_list.j2"),
-         owner=params.hdfs_user,
-         group=params.user_group
+         owner=params.hdfs_user
          )
     pass
 
   if params.dfs_ha_enabled:
     # due to a bug in hdfs, refreshNodes will not run on both namenodes so we
     # need to execute each command scoped to a particular namenode
-    nn_refresh_cmd = format('cmd /c hadoop dfsadmin -fs hdfs://{namenode_rpc} -refreshNodes')
+    nn_refresh_cmd = format('cmd /c hdfs dfsadmin -fs hdfs://{namenode_rpc} -refreshNodes')
   else:
-    nn_refresh_cmd = format('cmd /c hadoop dfsadmin -fs {namenode_address} -refreshNodes')
+    nn_refresh_cmd = format('cmd /c hdfs dfsadmin -fs {namenode_address} -refreshNodes')
   Execute(nn_refresh_cmd, user=hdfs_user)
 
 
@@ -567,7 +598,7 @@ def find_timeout():
 
 
 @retry(sleep_time=5, backoff_factor=2, err_class=Fail, timeout_func=find_timeout)
-def is_this_namenode_active():
+def is_this_namenode_active(name_service):
   """
   Gets whether the current NameNode is Active. This function will wait until the NameNode is
   listed as being either Active or Standby before returning a value. This is to ensure that
@@ -586,7 +617,7 @@ def is_this_namenode_active():
   #          0                                              1                                             2
   #
   namenode_states = namenode_ha_utils.get_namenode_states(params.hdfs_site, params.security_enabled,
-    params.hdfs_user, times=5, sleep_time=5, backoff_factor=2)
+    params.hdfs_user, times=5, sleep_time=5, backoff_factor=2, name_service=name_service)
 
   # unwraps [('nn1', 'c6401.ambari.apache.org:50070')]
   active_namenodes = [] if len(namenode_states[0]) < 1 else namenode_states[0]
