@@ -27,7 +27,7 @@ tmp_dir = Script.get_tmp_dir()
 
 architecture = get_architecture()
 
-stack_name = default("/hostLevelParams/stack_name", None)
+stack_name = default("/clusterLevelParams/stack_name", None)
 
 # New Cluster Stack Version that is defined during the RESTART of a Stack Upgrade
 version = default("/commandParams/version", None)
\ No newline at end of file
