@@ -17,10 +17,31 @@
  */
 package org.apache.ambari.server.controller.internal;
 
-import com.google.inject.Binder;
-import com.google.inject.Guice;
-import com.google.inject.Module;
-import com.google.inject.util.Modules;
+import static junit.framework.Assert.assertEquals;
+import static junit.framework.Assert.assertNotNull;
+import static junit.framework.Assert.assertTrue;
+import static org.easymock.EasyMock.anyObject;
+import static org.easymock.EasyMock.anyString;
+import static org.easymock.EasyMock.capture;
+import static org.easymock.EasyMock.createMock;
+import static org.easymock.EasyMock.createNiceMock;
+import static org.easymock.EasyMock.createStrictMock;
+import static org.easymock.EasyMock.expect;
+import static org.easymock.EasyMock.newCapture;
+import static org.easymock.EasyMock.replay;
+import static org.easymock.EasyMock.verify;
+
+import java.lang.reflect.Field;
+import java.util.ArrayList;
+import java.util.Collections;
+import java.util.HashMap;
+import java.util.HashSet;
+import java.util.LinkedHashMap;
+import java.util.LinkedHashSet;
+import java.util.List;
+import java.util.Map;
+import java.util.Set;
+
 import org.apache.ambari.server.controller.AmbariManagementController;
 import org.apache.ambari.server.controller.ConfigGroupRequest;
 import org.apache.ambari.server.controller.ConfigGroupResponse;
@@ -47,6 +68,7 @@ import org.apache.ambari.server.state.Host;
 import org.apache.ambari.server.state.configgroup.ConfigGroup;
 import org.apache.ambari.server.state.configgroup.ConfigGroupFactory;
 import org.easymock.Capture;
+import org.easymock.EasyMock;
 import org.easymock.IAnswer;
 import org.junit.Assert;
 import org.junit.Before;
@@ -54,28 +76,11 @@ import org.junit.Test;
 import org.springframework.security.core.Authentication;
 import org.springframework.security.core.context.SecurityContextHolder;
 
-
-import java.util.ArrayList;
-import java.util.Collections;
-import java.util.HashMap;
-import java.util.HashSet;
-import java.util.LinkedHashMap;
-import java.util.LinkedHashSet;
-import java.util.List;
-import java.util.Map;
-import java.util.Set;
-
-import static junit.framework.Assert.*;
-import static org.easymock.EasyMock.anyObject;
-import static org.easymock.EasyMock.anyString;
-import static org.easymock.EasyMock.capture;
-import static org.easymock.EasyMock.createMock;
-import static org.easymock.EasyMock.createNiceMock;
-import static org.easymock.EasyMock.expect;
-import static org.easymock.EasyMock.newCapture;
-import static org.easymock.EasyMock.replay;
-import static org.easymock.EasyMock.verify;
-import static org.easymock.EasyMock.createStrictMock;
+import com.google.inject.Binder;
+import com.google.inject.Guice;
+import com.google.inject.Module;
+import com.google.inject.Provider;
+import com.google.inject.util.Modules;
 
 public class ConfigGroupResourceProviderTest {
 
@@ -94,14 +99,24 @@ public class ConfigGroupResourceProviderTest {
   }
 
   private ConfigGroupResourceProvider getConfigGroupResourceProvider
-      (AmbariManagementController managementController) {
+      (AmbariManagementController managementController) throws NoSuchFieldException, IllegalAccessException {
     Resource.Type type = Resource.Type.ConfigGroup;
 
-    return (ConfigGroupResourceProvider) AbstractControllerResourceProvider.getResourceProvider(
+    ConfigGroupResourceProvider configGroupResourceProvider =
+        (ConfigGroupResourceProvider) AbstractControllerResourceProvider.getResourceProvider(
         type,
-        PropertyHelper.getPropertyIds(type),
-        PropertyHelper.getKeyPropertyIds(type),
         managementController);
+
+    Provider<ConfigHelper> configHelperProvider = createNiceMock(Provider.class);
+    expect(configHelperProvider.get()).andReturn(createNiceMock(ConfigHelper.class));
+
+    replay(configHelperProvider);
+
+    Field m_configHelper = ConfigGroupResourceProvider.class.getDeclaredField("m_configHelper");
+    m_configHelper.setAccessible(true);
+    m_configHelper.set(configGroupResourceProvider, configHelperProvider);
+
+    return configGroupResourceProvider;
   }
 
 
@@ -168,16 +183,16 @@ public class ConfigGroupResourceProviderTest {
     expect(hostEntity2.getHostId()).andReturn(2L).atLeastOnce();
 
     Capture<Cluster> clusterCapture = newCapture();
+    Capture<String> serviceName = newCapture();
     Capture<String> captureName = newCapture();
     Capture<String> captureDesc = newCapture();
     Capture<String> captureTag = newCapture();
-    Capture<String> captureServiceName = newCapture();
     Capture<Map<String, Config>> captureConfigs = newCapture();
     Capture<Map<Long, Host>> captureHosts = newCapture();
 
-    expect(configGroupFactory.createNew(capture(clusterCapture),
-        capture(captureName), capture(captureTag), capture(captureServiceName),
-        capture(captureDesc), capture(captureConfigs), capture(captureHosts))).andReturn(configGroup);
+    expect(configGroupFactory.createNew(capture(clusterCapture), capture(serviceName),
+        capture(captureName), capture(captureTag), capture(captureDesc),
+        capture(captureConfigs), capture(captureHosts))).andReturn(configGroup);
 
     replay(managementController, clusters, cluster, configGroupFactory,
         configGroup, response, hostDAO, hostEntity1, hostEntity2);
@@ -185,20 +200,20 @@ public class ConfigGroupResourceProviderTest {
     ResourceProvider provider = getConfigGroupResourceProvider
         (managementController);
 
-    Set<Map<String, Object>> propertySet = new LinkedHashSet<Map<String, Object>>();
-    Map<String, Object> properties = new LinkedHashMap<String, Object>();
+    Set<Map<String, Object>> propertySet = new LinkedHashSet<>();
+    Map<String, Object> properties = new LinkedHashMap<>();
 
-    Set<Map<String, Object>> hostSet = new HashSet<Map<String, Object>>();
-    Map<String, Object> host1 = new HashMap<String, Object>();
-    host1.put(ConfigGroupResourceProvider.CONFIGGROUP_HOSTNAME_PROPERTY_ID, "h1");
+    Set<Map<String, Object>> hostSet = new HashSet<>();
+    Map<String, Object> host1 = new HashMap<>();
+    host1.put(ConfigGroupResourceProvider.HOST_NAME, "h1");
     hostSet.add(host1);
-    Map<String, Object> host2 = new HashMap<String, Object>();
-    host2.put(ConfigGroupResourceProvider.CONFIGGROUP_HOSTNAME_PROPERTY_ID, "h2");
+    Map<String, Object> host2 = new HashMap<>();
+    host2.put(ConfigGroupResourceProvider.HOST_NAME, "h2");
     hostSet.add(host2);
 
-    Set<Map<String, Object>> configSet = new HashSet<Map<String, Object>>();
-    Map<String, String> configMap = new HashMap<String, String>();
-    Map<String, Object> configs = new HashMap<String, Object>();
+    Set<Map<String, Object>> configSet = new HashSet<>();
+    Map<String, String> configMap = new HashMap<>();
+    Map<String, Object> configs = new HashMap<>();
     configs.put("type", "core-site");
     configs.put("tag", "version100");
     configMap.put("key1", "value1");
@@ -206,14 +221,14 @@ public class ConfigGroupResourceProviderTest {
     configSet.add(configs);
 
     properties.put(ConfigGroupResourceProvider
-        .CONFIGGROUP_CLUSTER_NAME_PROPERTY_ID, "Cluster100");
-    properties.put(ConfigGroupResourceProvider.CONFIGGROUP_NAME_PROPERTY_ID,
+        .CLUSTER_NAME, "Cluster100");
+    properties.put(ConfigGroupResourceProvider.GROUP_NAME,
         "test-1");
-    properties.put(ConfigGroupResourceProvider.CONFIGGROUP_TAG_PROPERTY_ID,
+    properties.put(ConfigGroupResourceProvider.TAG,
         "tag-1");
-    properties.put(ConfigGroupResourceProvider.CONFIGGROUP_HOSTS_PROPERTY_ID,
+    properties.put(ConfigGroupResourceProvider.HOSTS,
         hostSet);
-    properties.put(ConfigGroupResourceProvider.CONFIGGROUP_CONFIGS_PROPERTY_ID,
+    properties.put(ConfigGroupResourceProvider.DESIRED_CONFIGS,
         configSet);
 
     propertySet.add(properties);
@@ -270,7 +285,7 @@ public class ConfigGroupResourceProviderTest {
     Cluster cluster = createNiceMock(Cluster.class);
     ConfigGroupFactory configGroupFactory = createNiceMock(ConfigGroupFactory.class);
     ConfigGroup configGroup = createNiceMock(ConfigGroup.class);
-    Map<Long, ConfigGroup> configGroupMap = new HashMap<Long, ConfigGroup>();
+    Map<Long, ConfigGroup> configGroupMap = new HashMap<>();
     configGroupMap.put(1L, configGroup);
 
     expect(managementController.getClusters()).andReturn(clusters).anyTimes();
@@ -280,9 +295,9 @@ public class ConfigGroupResourceProviderTest {
     expect(managementController.getAuthName()).andReturn("admin").anyTimes();
     expect(cluster.getConfigGroups()).andReturn(configGroupMap);
 
-    expect(configGroupFactory.createNew((Cluster) anyObject(), (String) anyObject(),
-        (String) anyObject(), (String) anyObject(), (String) anyObject(),
-        (HashMap) anyObject(), (HashMap) anyObject())).andReturn(configGroup).anyTimes();
+    expect(configGroupFactory.createNew((Cluster) anyObject(), (String) anyObject(), (String) anyObject(),
+        (String) anyObject(), (String) anyObject(), EasyMock.anyObject(),
+        EasyMock.anyObject())).andReturn(configGroup).anyTimes();
 
     expect(configGroup.getClusterName()).andReturn("Cluster100").anyTimes();
     expect(configGroup.getName()).andReturn("test-1").anyTimes();
@@ -294,14 +309,14 @@ public class ConfigGroupResourceProviderTest {
     ResourceProvider provider = getConfigGroupResourceProvider
         (managementController);
 
-    Map<String, Object> properties = new LinkedHashMap<String, Object>();
-    Set<Map<String, Object>> propertySet = new LinkedHashSet<Map<String, Object>>();
+    Map<String, Object> properties = new LinkedHashMap<>();
+    Set<Map<String, Object>> propertySet = new LinkedHashSet<>();
 
     properties.put(ConfigGroupResourceProvider
-        .CONFIGGROUP_CLUSTER_NAME_PROPERTY_ID, "Cluster100");
-    properties.put(ConfigGroupResourceProvider.CONFIGGROUP_NAME_PROPERTY_ID,
+        .CLUSTER_NAME, "Cluster100");
+    properties.put(ConfigGroupResourceProvider.GROUP_NAME,
         "test-1");
-    properties.put(ConfigGroupResourceProvider.CONFIGGROUP_TAG_PROPERTY_ID,
+    properties.put(ConfigGroupResourceProvider.TAG,
         "tag-1");
 
     propertySet.add(properties);
@@ -367,7 +382,7 @@ public class ConfigGroupResourceProviderTest {
     expect(cluster.getConfigGroups()).andStubAnswer(new IAnswer<Map<Long, ConfigGroup>>() {
       @Override
       public Map<Long, ConfigGroup> answer() throws Throwable {
-        Map<Long, ConfigGroup> configGroupMap = new HashMap<Long, ConfigGroup>();
+        Map<Long, ConfigGroup> configGroupMap = new HashMap<>();
         configGroupMap.put(configGroup.getId(), configGroup);
         return configGroupMap;
       }
@@ -379,19 +394,19 @@ public class ConfigGroupResourceProviderTest {
     ResourceProvider provider = getConfigGroupResourceProvider
         (managementController);
 
-    Map<String, Object> properties = new LinkedHashMap<String, Object>();
+    Map<String, Object> properties = new LinkedHashMap<>();
 
-    Set<Map<String, Object>> hostSet = new HashSet<Map<String, Object>>();
-    Map<String, Object> host1 = new HashMap<String, Object>();
-    host1.put(ConfigGroupResourceProvider.CONFIGGROUP_HOSTNAME_PROPERTY_ID, "h1");
+    Set<Map<String, Object>> hostSet = new HashSet<>();
+    Map<String, Object> host1 = new HashMap<>();
+    host1.put(ConfigGroupResourceProvider.HOST_NAME, "h1");
     hostSet.add(host1);
-    Map<String, Object> host2 = new HashMap<String, Object>();
-    host2.put(ConfigGroupResourceProvider.CONFIGGROUP_HOSTNAME_PROPERTY_ID, "h2");
+    Map<String, Object> host2 = new HashMap<>();
+    host2.put(ConfigGroupResourceProvider.HOST_NAME, "h2");
     hostSet.add(host2);
 
-    Set<Map<String, Object>> configSet = new HashSet<Map<String, Object>>();
-    Map<String, String> configMap = new HashMap<String, String>();
-    Map<String, Object> configs = new HashMap<String, Object>();
+    Set<Map<String, Object>> configSet = new HashSet<>();
+    Map<String, String> configMap = new HashMap<>();
+    Map<String, Object> configs = new HashMap<>();
     configs.put("type", "core-site");
     configs.put("tag", "version100");
     configMap.put("key1", "value1");
@@ -399,25 +414,25 @@ public class ConfigGroupResourceProviderTest {
     configSet.add(configs);
 
     properties.put(ConfigGroupResourceProvider
-        .CONFIGGROUP_CLUSTER_NAME_PROPERTY_ID, "Cluster100");
-    properties.put(ConfigGroupResourceProvider.CONFIGGROUP_NAME_PROPERTY_ID,
+        .CLUSTER_NAME, "Cluster100");
+    properties.put(ConfigGroupResourceProvider.GROUP_NAME,
         "test-1");
-    properties.put(ConfigGroupResourceProvider.CONFIGGROUP_TAG_PROPERTY_ID,
+    properties.put(ConfigGroupResourceProvider.TAG,
         "tag-1");
-    properties.put(ConfigGroupResourceProvider.CONFIGGROUP_HOSTS_PROPERTY_ID,
+    properties.put(ConfigGroupResourceProvider.HOSTS,
         hostSet);
-    properties.put(ConfigGroupResourceProvider.CONFIGGROUP_CONFIGS_PROPERTY_ID,
+    properties.put(ConfigGroupResourceProvider.DESIRED_CONFIGS,
         configSet);
 
-    Map<String, String> mapRequestProps = new HashMap<String, String>();
+    Map<String, String> mapRequestProps = new HashMap<>();
     mapRequestProps.put("context", "Called from a test");
 
     Request request = PropertyHelper.getUpdateRequest(properties, mapRequestProps);
 
     Predicate predicate = new PredicateBuilder().property
-        (ConfigGroupResourceProvider.CONFIGGROUP_CLUSTER_NAME_PROPERTY_ID).equals
+        (ConfigGroupResourceProvider.CLUSTER_NAME).equals
         ("Cluster100").and().
-        property(ConfigGroupResourceProvider.CONFIGGROUP_ID_PROPERTY_ID).equals
+        property(ConfigGroupResourceProvider.ID).equals
         (25L).toPredicate();
 
     SecurityContextHolder.getContext().setAuthentication(TestAuthenticationFactory.createAdministrator());
@@ -492,6 +507,8 @@ public class ConfigGroupResourceProviderTest {
     expect(hostEntity2.getHostId()).andReturn(2L).atLeastOnce();
     expect(h1.getHostId()).andReturn(1L).anyTimes();
     expect(h2.getHostId()).andReturn(2L).anyTimes();
+    expect(managementController.getConfigGroupUpdateResults((ConfigGroupRequest)anyObject())).
+            andReturn(new ConfigGroupResponse(1L, "", "", "", "", new HashSet<>(), new HashSet<>())).atLeastOnce();
 
     expect(configGroup.getName()).andReturn("test-1").anyTimes();
     expect(configGroup.getId()).andReturn(25L).anyTimes();
@@ -504,7 +521,7 @@ public class ConfigGroupResourceProviderTest {
     expect(cluster.getConfigGroups()).andStubAnswer(new IAnswer<Map<Long, ConfigGroup>>() {
       @Override
       public Map<Long, ConfigGroup> answer() throws Throwable {
-        Map<Long, ConfigGroup> configGroupMap = new HashMap<Long, ConfigGroup>();
+        Map<Long, ConfigGroup> configGroupMap = new HashMap<>();
         configGroupMap.put(configGroup.getId(), configGroup);
         return configGroupMap;
       }
@@ -516,19 +533,19 @@ public class ConfigGroupResourceProviderTest {
     ResourceProvider provider = getConfigGroupResourceProvider
         (managementController);
 
-    Map<String, Object> properties = new LinkedHashMap<String, Object>();
+    Map<String, Object> properties = new LinkedHashMap<>();
 
-    Set<Map<String, Object>> hostSet = new HashSet<Map<String, Object>>();
-    Map<String, Object> host1 = new HashMap<String, Object>();
-    host1.put(ConfigGroupResourceProvider.CONFIGGROUP_HOSTNAME_PROPERTY_ID, "h1");
+    Set<Map<String, Object>> hostSet = new HashSet<>();
+    Map<String, Object> host1 = new HashMap<>();
+    host1.put(ConfigGroupResourceProvider.HOST_NAME, "h1");
     hostSet.add(host1);
-    Map<String, Object> host2 = new HashMap<String, Object>();
-    host2.put(ConfigGroupResourceProvider.CONFIGGROUP_HOSTNAME_PROPERTY_ID, "h2");
+    Map<String, Object> host2 = new HashMap<>();
+    host2.put(ConfigGroupResourceProvider.HOST_NAME, "h2");
     hostSet.add(host2);
 
-    Set<Map<String, Object>> configSet = new HashSet<Map<String, Object>>();
-    Map<String, String> configMap = new HashMap<String, String>();
-    Map<String, Object> configs = new HashMap<String, Object>();
+    Set<Map<String, Object>> configSet = new HashSet<>();
+    Map<String, String> configMap = new HashMap<>();
+    Map<String, Object> configs = new HashMap<>();
     configs.put("type", "core-site");
     configs.put("tag", "version100");
     configMap.put("key1", "value1");
@@ -536,25 +553,25 @@ public class ConfigGroupResourceProviderTest {
     configSet.add(configs);
 
     properties.put(ConfigGroupResourceProvider
-        .CONFIGGROUP_CLUSTER_NAME_PROPERTY_ID, "Cluster100");
-    properties.put(ConfigGroupResourceProvider.CONFIGGROUP_NAME_PROPERTY_ID,
+        .CLUSTER_NAME, "Cluster100");
+    properties.put(ConfigGroupResourceProvider.GROUP_NAME,
         "test-1");
-    properties.put(ConfigGroupResourceProvider.CONFIGGROUP_TAG_PROPERTY_ID,
+    properties.put(ConfigGroupResourceProvider.TAG,
         "tag-1");
-    properties.put(ConfigGroupResourceProvider.CONFIGGROUP_HOSTS_PROPERTY_ID,
+    properties.put(ConfigGroupResourceProvider.HOSTS,
         hostSet);
-    properties.put(ConfigGroupResourceProvider.CONFIGGROUP_CONFIGS_PROPERTY_ID,
+    properties.put(ConfigGroupResourceProvider.DESIRED_CONFIGS,
         configSet);
 
-    Map<String, String> mapRequestProps = new HashMap<String, String>();
+    Map<String, String> mapRequestProps = new HashMap<>();
     mapRequestProps.put("context", "Called from a test");
 
     Request request = PropertyHelper.getUpdateRequest(properties, mapRequestProps);
 
     Predicate predicate = new PredicateBuilder().property
-        (ConfigGroupResourceProvider.CONFIGGROUP_CLUSTER_NAME_PROPERTY_ID).equals
+        (ConfigGroupResourceProvider.CLUSTER_NAME).equals
         ("Cluster100").and().
-        property(ConfigGroupResourceProvider.CONFIGGROUP_ID_PROPERTY_ID).equals
+        property(ConfigGroupResourceProvider.ID).equals
         (25L).toPredicate();
 
     SecurityContextHolder.getContext().setAuthentication(authentication);
@@ -623,13 +640,13 @@ public class ConfigGroupResourceProviderTest {
     ConfigGroupResponse response3 = createNiceMock(ConfigGroupResponse.class);
     ConfigGroupResponse response4 = createNiceMock(ConfigGroupResponse.class);
 
-    Map<Long, ConfigGroup> configGroupMap = new HashMap<Long, ConfigGroup>();
+    Map<Long, ConfigGroup> configGroupMap = new HashMap<>();
     configGroupMap.put(1L, configGroup1);
     configGroupMap.put(2L, configGroup2);
     configGroupMap.put(3L, configGroup3);
     configGroupMap.put(4L, configGroup4);
 
-    Map<Long, ConfigGroup> configGroupByHostname = new HashMap<Long, ConfigGroup>();
+    Map<Long, ConfigGroup> configGroupByHostname = new HashMap<>();
     configGroupByHostname.put(4L, configGroup4);
 
     expect(configGroup1.convertToResponse()).andReturn(response1).anyTimes();
@@ -651,7 +668,7 @@ public class ConfigGroupResourceProviderTest {
     expect(configGroup3.getTag()).andReturn("t3").anyTimes();
     expect(configGroup4.getTag()).andReturn("t4").anyTimes();
 
-    Map<Long, Host> hostMap = new HashMap<Long, Host>();
+    Map<Long, Host> hostMap = new HashMap<>();
     hostMap.put(host1Id, h1);
     expect(configGroup4.getHosts()).andReturn(hostMap).anyTimes();
 
@@ -668,8 +685,8 @@ public class ConfigGroupResourceProviderTest {
     expect(response3.getTag()).andReturn("t3").anyTimes();
     expect(cluster.getConfigGroupsByHostname("h1")).andReturn(configGroupByHostname).anyTimes();
 
-    Set<Map<String, Object>> hostObj = new HashSet<Map<String, Object>>();
-    Map<String, Object> hostnames = new HashMap<String, Object>();
+    Set<Map<String, Object>> hostObj = new HashSet<>();
+    Map<String, Object> hostnames = new HashMap<>();
     hostnames.put("host_name", "h1");
     hostObj.add(hostnames);
     expect(response4.getHosts()).andReturn(hostObj).anyTimes();
@@ -681,14 +698,14 @@ public class ConfigGroupResourceProviderTest {
 
     ResourceProvider resourceProvider = getConfigGroupResourceProvider(managementController);
 
-    Set<String> propertyIds = new HashSet<String>();
+    Set<String> propertyIds = new HashSet<>();
 
-    propertyIds.add(ConfigGroupResourceProvider.CONFIGGROUP_CLUSTER_NAME_PROPERTY_ID);
-    propertyIds.add(ConfigGroupResourceProvider.CONFIGGROUP_ID_PROPERTY_ID);
+    propertyIds.add(ConfigGroupResourceProvider.CLUSTER_NAME);
+    propertyIds.add(ConfigGroupResourceProvider.ID);
 
     // Read all
     Predicate predicate = new PredicateBuilder().property
-        (ConfigGroupResourceProvider.CONFIGGROUP_CLUSTER_NAME_PROPERTY_ID)
+        (ConfigGroupResourceProvider.CLUSTER_NAME)
         .equals("Cluster100").toPredicate();
     Request request = PropertyHelper.getReadRequest(propertyIds);
 
@@ -698,44 +715,44 @@ public class ConfigGroupResourceProviderTest {
 
     // Read by id
     predicate = new PredicateBuilder().property(ConfigGroupResourceProvider
-        .CONFIGGROUP_ID_PROPERTY_ID).equals(1L).and().property
-        (ConfigGroupResourceProvider.CONFIGGROUP_CLUSTER_NAME_PROPERTY_ID)
+        .ID).equals(1L).and().property
+        (ConfigGroupResourceProvider.CLUSTER_NAME)
         .equals("Cluster100").toPredicate();
 
     resources = resourceProvider.getResources(request, predicate);
 
     assertEquals(1, resources.size());
     assertEquals(1L, resources.iterator().next().getPropertyValue
-        (ConfigGroupResourceProvider.CONFIGGROUP_ID_PROPERTY_ID));
+        (ConfigGroupResourceProvider.ID));
 
     // Read by Name
     predicate = new PredicateBuilder().property(ConfigGroupResourceProvider
-        .CONFIGGROUP_CLUSTER_NAME_PROPERTY_ID).equals("Cluster100").and()
-        .property(ConfigGroupResourceProvider.CONFIGGROUP_NAME_PROPERTY_ID)
+        .CLUSTER_NAME).equals("Cluster100").and()
+        .property(ConfigGroupResourceProvider.GROUP_NAME)
         .equals("g2").toPredicate();
 
     resources = resourceProvider.getResources(request, predicate);
 
     assertEquals(1, resources.size());
     assertEquals("g2", resources.iterator().next().getPropertyValue
-        (ConfigGroupResourceProvider.CONFIGGROUP_NAME_PROPERTY_ID));
+        (ConfigGroupResourceProvider.GROUP_NAME));
 
     // Read by tag
     predicate = new PredicateBuilder().property(ConfigGroupResourceProvider
-        .CONFIGGROUP_CLUSTER_NAME_PROPERTY_ID).equals("Cluster100").and()
-        .property(ConfigGroupResourceProvider.CONFIGGROUP_TAG_PROPERTY_ID)
+        .CLUSTER_NAME).equals("Cluster100").and()
+        .property(ConfigGroupResourceProvider.TAG)
         .equals("t3").toPredicate();
 
     resources = resourceProvider.getResources(request, predicate);
 
     assertEquals(1, resources.size());
     assertEquals("t3", resources.iterator().next().getPropertyValue
-        (ConfigGroupResourceProvider.CONFIGGROUP_TAG_PROPERTY_ID));
+        (ConfigGroupResourceProvider.TAG));
 
     // Read by hostname (hosts=h1)
     predicate = new PredicateBuilder().property(ConfigGroupResourceProvider
-        .CONFIGGROUP_CLUSTER_NAME_PROPERTY_ID).equals("Cluster100").and()
-        .property(ConfigGroupResourceProvider.CONFIGGROUP_HOSTS_PROPERTY_ID)
+        .CLUSTER_NAME).equals("Cluster100").and()
+        .property(ConfigGroupResourceProvider.HOSTS)
         .equals("h1").toPredicate();
 
     resources = resourceProvider.getResources(request, predicate);
@@ -744,14 +761,14 @@ public class ConfigGroupResourceProviderTest {
     Set<Map<String, Object>> hostSet = (Set<Map<String, Object>>)
         resources.iterator().next()
             .getPropertyValue(ConfigGroupResourceProvider
-                .CONFIGGROUP_HOSTS_PROPERTY_ID);
+                .HOSTS);
     assertEquals("h1", hostSet.iterator().next().get
-        (ConfigGroupResourceProvider.CONFIGGROUP_HOSTNAME_PROPERTY_ID));
+        (ConfigGroupResourceProvider.HOST_NAME));
 
     // Read by hostname (hosts/host_name=h1)
     predicate = new PredicateBuilder().property(ConfigGroupResourceProvider
-        .CONFIGGROUP_CLUSTER_NAME_PROPERTY_ID).equals("Cluster100").and()
-        .property(ConfigGroupResourceProvider.CONFIGGROUP_HOSTS_HOSTNAME_PROPERTY_ID)
+        .CLUSTER_NAME).equals("Cluster100").and()
+        .property(ConfigGroupResourceProvider.HOSTS_HOST_NAME)
         .equals("h1").toPredicate();
 
     resources = resourceProvider.getResources(request, predicate);
@@ -760,17 +777,17 @@ public class ConfigGroupResourceProviderTest {
     hostSet = (Set<Map<String, Object>>)
         resources.iterator().next()
             .getPropertyValue(ConfigGroupResourceProvider
-                .CONFIGGROUP_HOSTS_PROPERTY_ID);
+                .HOSTS);
     assertEquals("h1", hostSet.iterator().next().get
-        (ConfigGroupResourceProvider.CONFIGGROUP_HOSTNAME_PROPERTY_ID));
+        (ConfigGroupResourceProvider.HOST_NAME));
 
 
     // Read by tag and hostname (hosts=h1) - Positive
     predicate = new PredicateBuilder().property(ConfigGroupResourceProvider
-        .CONFIGGROUP_CLUSTER_NAME_PROPERTY_ID).equals("Cluster100").and()
-        .property(ConfigGroupResourceProvider.CONFIGGROUP_TAG_PROPERTY_ID)
+        .CLUSTER_NAME).equals("Cluster100").and()
+        .property(ConfigGroupResourceProvider.TAG)
         .equals("t4").and().property(ConfigGroupResourceProvider
-            .CONFIGGROUP_HOSTS_PROPERTY_ID).equals(host1Id).toPredicate();
+            .HOSTS).equals(host1Id).toPredicate();
 
     resources = resourceProvider.getResources(request, predicate);
 
@@ -778,16 +795,16 @@ public class ConfigGroupResourceProviderTest {
     hostSet = (Set<Map<String, Object>>)
         resources.iterator().next()
             .getPropertyValue(ConfigGroupResourceProvider
-                .CONFIGGROUP_HOSTS_PROPERTY_ID);
+                .HOSTS);
     assertEquals("h1", hostSet.iterator().next().get
-        (ConfigGroupResourceProvider.CONFIGGROUP_HOSTNAME_PROPERTY_ID));
+        (ConfigGroupResourceProvider.HOST_NAME));
 
     // Read by tag and hostname (hosts/host_name=h1) - Positive
     predicate = new PredicateBuilder().property(ConfigGroupResourceProvider
-        .CONFIGGROUP_CLUSTER_NAME_PROPERTY_ID).equals("Cluster100").and()
-        .property(ConfigGroupResourceProvider.CONFIGGROUP_TAG_PROPERTY_ID)
+        .CLUSTER_NAME).equals("Cluster100").and()
+        .property(ConfigGroupResourceProvider.TAG)
         .equals("t4").and().property(ConfigGroupResourceProvider
-            .CONFIGGROUP_HOSTS_HOSTNAME_PROPERTY_ID).equals("h1").toPredicate();
+            .HOSTS_HOST_NAME).equals("h1").toPredicate();
 
     resources = resourceProvider.getResources(request, predicate);
 
@@ -795,14 +812,14 @@ public class ConfigGroupResourceProviderTest {
     hostSet = (Set<Map<String, Object>>)
         resources.iterator().next()
             .getPropertyValue(ConfigGroupResourceProvider
-                .CONFIGGROUP_HOSTS_PROPERTY_ID);
+                .HOSTS);
     assertEquals("h1", hostSet.iterator().next().get
-        (ConfigGroupResourceProvider.CONFIGGROUP_HOSTNAME_PROPERTY_ID));
+        (ConfigGroupResourceProvider.HOST_NAME));
 
     // Read by id
     predicate = new PredicateBuilder().property(ConfigGroupResourceProvider
-        .CONFIGGROUP_ID_PROPERTY_ID).equals(11L).and().property
-        (ConfigGroupResourceProvider.CONFIGGROUP_CLUSTER_NAME_PROPERTY_ID)
+        .ID).equals(11L).and().property
+        (ConfigGroupResourceProvider.CLUSTER_NAME)
         .equals("Cluster100").toPredicate();
 
     NoSuchResourceException resourceException = null;
@@ -870,9 +887,9 @@ public class ConfigGroupResourceProviderTest {
     ((ObservableResourceProvider) resourceProvider).addObserver(observer);
 
     Predicate predicate = new PredicateBuilder().property
-        (ConfigGroupResourceProvider.CONFIGGROUP_CLUSTER_NAME_PROPERTY_ID)
+        (ConfigGroupResourceProvider.CLUSTER_NAME)
         .equals("Cluster100").and().property(ConfigGroupResourceProvider
-            .CONFIGGROUP_ID_PROPERTY_ID).equals(1L).toPredicate();
+            .ID).equals(1L).toPredicate();
 
     SecurityContextHolder.getContext().setAuthentication(authentication);
 
@@ -894,8 +911,8 @@ public class ConfigGroupResourceProviderTest {
     ConfigGroupResourceProvider resourceProvider = getConfigGroupResourceProvider
         (managementController);
 
-    Set<Map<String, String>> desiredConfigProperties = new HashSet<Map<String, String>>();
-    Map<String, String> desiredConfig1 = new HashMap<String, String>();
+    Set<Map<String, String>> desiredConfigProperties = new HashSet<>();
+    Map<String, String> desiredConfig1 = new HashMap<>();
     desiredConfig1.put("tag", "version2");
     desiredConfig1.put("type", "type1");
     desiredConfig1.put("properties/key1", "value1");
@@ -905,7 +922,7 @@ public class ConfigGroupResourceProviderTest {
     desiredConfig1.put("properties_attributes/attr2/key1", "15");
     desiredConfigProperties.add(desiredConfig1);
 
-    Map<String, Object> properties = new HashMap<String, Object>();
+    Map<String, Object> properties = new HashMap<>();
     properties.put("ConfigGroup/hosts", new HashMap<String, String>() {{
       put("host_name", "ambari1");
     }});
