@@ -20,6 +20,8 @@ package org.apache.ambari.server.controller.internal;
 import static org.easymock.EasyMock.eq;
 import static org.easymock.EasyMock.expect;
 import static org.easymock.EasyMock.expectLastCall;
+import static org.easymock.EasyMock.replay;
+import static org.easymock.EasyMock.reset;
 import static org.junit.Assert.assertEquals;
 
 import java.util.HashMap;
@@ -28,27 +30,37 @@ import java.util.Map;
 
 import javax.persistence.EntityManager;
 
+import org.apache.ambari.server.actionmanager.ActionDBAccessor;
+import org.apache.ambari.server.actionmanager.ActionDBAccessorImpl;
 import org.apache.ambari.server.actionmanager.ActionManager;
 import org.apache.ambari.server.actionmanager.HostRoleCommandFactory;
 import org.apache.ambari.server.actionmanager.HostRoleCommandFactoryImpl;
 import org.apache.ambari.server.actionmanager.RequestFactory;
 import org.apache.ambari.server.actionmanager.StageFactory;
+import org.apache.ambari.server.agent.stomp.AgentConfigsHolder;
+import org.apache.ambari.server.agent.stomp.MetadataHolder;
 import org.apache.ambari.server.api.services.AmbariMetaInfo;
+import org.apache.ambari.server.audit.AuditLogger;
+import org.apache.ambari.server.audit.AuditLoggerDefaultImpl;
 import org.apache.ambari.server.controller.AbstractRootServiceResponseFactory;
 import org.apache.ambari.server.controller.AmbariManagementController;
 import org.apache.ambari.server.controller.KerberosHelper;
 import org.apache.ambari.server.controller.spi.ClusterController;
 import org.apache.ambari.server.hooks.HookContextFactory;
 import org.apache.ambari.server.hooks.HookService;
+import org.apache.ambari.server.metadata.CachedRoleCommandOrderProvider;
+import org.apache.ambari.server.metadata.RoleCommandOrderProvider;
 import org.apache.ambari.server.orm.DBAccessor;
 import org.apache.ambari.server.orm.dao.HostRoleCommandDAO;
 import org.apache.ambari.server.orm.dao.RepositoryVersionDAO;
 import org.apache.ambari.server.orm.dao.ServiceConfigDAO;
+import org.apache.ambari.server.orm.dao.StageDAO;
 import org.apache.ambari.server.orm.entities.ClusterConfigEntity;
 import org.apache.ambari.server.orm.entities.RepositoryVersionEntity;
 import org.apache.ambari.server.orm.entities.ServiceConfigEntity;
 import org.apache.ambari.server.scheduler.ExecutionScheduler;
 import org.apache.ambari.server.security.authorization.Users;
+import org.apache.ambari.server.security.encryption.CredentialStoreService;
 import org.apache.ambari.server.stack.StackManagerFactory;
 import org.apache.ambari.server.stageplanner.RoleGraphFactory;
 import org.apache.ambari.server.state.Cluster;
@@ -74,10 +86,13 @@ import org.apache.ambari.server.state.scheduler.RequestExecutionFactory;
 import org.apache.ambari.server.state.stack.OsFamily;
 import org.apache.ambari.server.state.stack.upgrade.Direction;
 import org.apache.ambari.server.state.stack.upgrade.UpgradeType;
+import org.apache.ambari.server.testutils.PartialNiceMockBinder;
+import org.apache.ambari.server.topology.PersistedState;
+import org.apache.ambari.server.topology.tasks.ConfigureClusterTaskFactory;
 import org.easymock.Capture;
 import org.easymock.EasyMock;
 import org.easymock.EasyMockSupport;
-import org.eclipse.jetty.server.SessionManager;
+import org.eclipse.jetty.server.session.SessionHandler;
 import org.junit.After;
 import org.junit.Before;
 import org.junit.Test;
@@ -112,6 +127,7 @@ public class StackUpgradeConfigurationMergeTest extends EasyMockSupport {
 
     // create an injector which will inject the mocks
     m_injector = Guice.createInjector(mockModule);
+    reset(m_injector.getInstance(StageDAO.class));
   }
 
   /**
@@ -221,7 +237,7 @@ public class StackUpgradeConfigurationMergeTest extends EasyMockSupport {
     Service zookeeper = createNiceMock(Service.class);
     expect(zookeeper.getName()).andReturn("ZOOKEEPER").atLeastOnce();
     expect(zookeeper.getServiceComponents()).andReturn(
-        new HashMap<String, ServiceComponent>()).once();
+      new HashMap<>()).once();
     zookeeper.setDesiredRepositoryVersion(repoVersion220);
     expectLastCall().once();
 
@@ -245,12 +261,10 @@ public class StackUpgradeConfigurationMergeTest extends EasyMockSupport {
 
     Capture<Map<String, Map<String, String>>> expectedConfigurationsCapture = EasyMock.newCapture();
 
-    configHelper.createConfigTypes(EasyMock.anyObject(Cluster.class),
+    expect(configHelper.createConfigTypes(EasyMock.anyObject(Cluster.class),
         EasyMock.anyObject(StackId.class), EasyMock.anyObject(AmbariManagementController.class),
         EasyMock.capture(expectedConfigurationsCapture), EasyMock.anyObject(String.class),
-        EasyMock.anyObject(String.class));
-
-    expectLastCall().once();
+        EasyMock.anyObject(String.class))).andReturn(true);
 
     // mock the service config DAO and replay it
     ServiceConfigEntity zookeeperServiceConfig = createNiceMock(ServiceConfigEntity.class);
@@ -359,8 +373,7 @@ public class StackUpgradeConfigurationMergeTest extends EasyMockSupport {
 
     Service zookeeper = createNiceMock(Service.class);
     expect(zookeeper.getName()).andReturn(serviceName).atLeastOnce();
-    expect(zookeeper.getServiceComponents()).andReturn(
-        new HashMap<String, ServiceComponent>()).once();
+    expect(zookeeper.getServiceComponents()).andReturn(new HashMap<String, ServiceComponent>()).once();
     zookeeper.setDesiredRepositoryVersion(repoVersion220);
     expectLastCall().once();
 
@@ -378,12 +391,10 @@ public class StackUpgradeConfigurationMergeTest extends EasyMockSupport {
 
     Capture<Map<String, Map<String, String>>> expectedConfigurationsCapture = EasyMock.newCapture();
 
-    configHelper.createConfigTypes(EasyMock.anyObject(Cluster.class),
+    expect(configHelper.createConfigTypes(EasyMock.anyObject(Cluster.class),
         EasyMock.anyObject(StackId.class), EasyMock.anyObject(AmbariManagementController.class),
         EasyMock.capture(expectedConfigurationsCapture), EasyMock.anyObject(String.class),
-        EasyMock.anyObject(String.class));
-
-    expectLastCall().once();
+        EasyMock.anyObject(String.class))).andReturn(true);
 
     // mock the service config DAO and replay it
     ServiceConfigEntity zookeeperServiceConfig = createNiceMock(ServiceConfigEntity.class);
@@ -430,7 +441,12 @@ public class StackUpgradeConfigurationMergeTest extends EasyMockSupport {
      */
     @Override
     public void configure(Binder binder) {
+      StageDAO stageDAO = createNiceMock(StageDAO.class);
+      PartialNiceMockBinder.newBuilder(StackUpgradeConfigurationMergeTest.this)
+          .addActionDBAccessorConfigsBindings().addLdapBindings().build().configure(binder);
+
       binder.bind(Clusters.class).toInstance(createNiceMock(Clusters.class));
+      binder.bind(StageDAO.class).toInstance(stageDAO);
       binder.bind(OsFamily.class).toInstance(createNiceMock(OsFamily.class));
       binder.bind(DBAccessor.class).toInstance(createNiceMock(DBAccessor.class));
       binder.bind(EntityManager.class).toInstance(createNiceMock(EntityManager.class));
@@ -439,7 +455,7 @@ public class StackUpgradeConfigurationMergeTest extends EasyMockSupport {
       binder.bind(AmbariManagementController.class).toInstance(createNiceMock(AmbariManagementController.class));
       binder.bind(ClusterController.class).toInstance(createNiceMock(ClusterController.class));
       binder.bind(StackManagerFactory.class).toInstance(createNiceMock(StackManagerFactory.class));
-      binder.bind(SessionManager.class).toInstance(createNiceMock(SessionManager.class));
+      binder.bind(SessionHandler.class).toInstance(createNiceMock(SessionHandler.class));
       binder.bind(RequestExecutionFactory.class).toInstance(createNiceMock(RequestExecutionFactory.class));
       binder.bind(ExecutionScheduler.class).toInstance(createNiceMock(ExecutionScheduler.class));
       binder.bind(RequestFactory.class).toInstance(createNiceMock(RequestFactory.class));
@@ -462,8 +478,20 @@ public class StackUpgradeConfigurationMergeTest extends EasyMockSupport {
       binder.install(new FactoryModuleBuilder().build(UpgradeContextFactory.class));
       binder.bind(HostRoleCommandFactory.class).to(HostRoleCommandFactoryImpl.class);
       binder.bind(AmbariMetaInfo.class).toInstance(m_metainfo);
+      binder.bind(PersistedState.class).toInstance(createNiceMock(PersistedState.class));
+      binder.bind(RoleCommandOrderProvider.class).to(CachedRoleCommandOrderProvider.class);
+      binder.bind(CredentialStoreService.class).toInstance(createNiceMock(CredentialStoreService.class));
+      binder.bind(ActionDBAccessor.class).to(ActionDBAccessorImpl.class);
+      binder.bind(AuditLogger.class).toInstance(createNiceMock(AuditLoggerDefaultImpl.class));
+      binder.bind(MetadataHolder.class).toInstance(createNiceMock(MetadataHolder.class));
+      binder.bind(AgentConfigsHolder.class).toInstance(createNiceMock(AgentConfigsHolder.class));
 
       binder.requestStaticInjection(UpgradeResourceProvider.class);
+
+      binder.install(new FactoryModuleBuilder().build(ConfigureClusterTaskFactory.class));
+
+      expect(stageDAO.getLastRequestId()).andReturn(1L).anyTimes();
+      replay(stageDAO);
     }
   }
-}
\ No newline at end of file
+}
