@@ -19,12 +19,17 @@
 package org.apache.ambari.server.serveraction.kerberos;
 
 import static org.easymock.EasyMock.anyObject;
+import static org.easymock.EasyMock.anyString;
 import static org.easymock.EasyMock.capture;
 import static org.easymock.EasyMock.expect;
+import static org.easymock.EasyMock.expectLastCall;
+import static org.easymock.EasyMock.isNull;
 import static org.easymock.EasyMock.newCapture;
 import static org.easymock.EasyMock.replay;
 
+import java.lang.reflect.Method;
 import java.nio.charset.Charset;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
@@ -50,6 +55,8 @@ import org.apache.ambari.server.state.stack.OsFamily;
 import org.easymock.Capture;
 import org.easymock.CaptureType;
 import org.easymock.IAnswer;
+import org.junit.Before;
+import org.junit.BeforeClass;
 import org.junit.Ignore;
 import org.junit.Test;
 
@@ -65,6 +72,38 @@ public class ADKerberosOperationHandlerTest extends KerberosOperationHandlerTest
   private static final String DEFAULT_LDAP_URL = "ldaps://10.0.100.4";
   private static final String DEFAULT_PRINCIPAL_CONTAINER_DN = "ou=HDP,DC=HDP01,DC=LOCAL";
   private static final String DEFAULT_REALM = "HDP01.LOCAL";
+  private static final Map<String, String> KERBEROS_ENV_MAP;
+
+  static {
+    Map<String, String> map = new HashMap<>(DEFAULT_KERBEROS_ENV_MAP);
+    map.put(ADKerberosOperationHandler.KERBEROS_ENV_PRINCIPAL_CONTAINER_DN, DEFAULT_PRINCIPAL_CONTAINER_DN);
+    map.put(ADKerberosOperationHandler.KERBEROS_ENV_LDAP_URL, DEFAULT_LDAP_URL);
+    KERBEROS_ENV_MAP = Collections.unmodifiableMap(map);
+  }
+
+  private static Method methodCreateInitialLdapContext;
+
+  private Injector injector;
+  private LdapContext ldapContext;
+
+  @BeforeClass
+  public static void beforeMITKerberosOperationHandlerTest() throws Exception {
+    methodCreateInitialLdapContext = ADKerberosOperationHandler.class.getDeclaredMethod("createInitialLdapContext", Properties.class, Control[].class);
+  }
+
+  @Before
+  public void setup() {
+    injector = Guice.createInjector(new AbstractModule() {
+      @Override
+      protected void configure() {
+        bind(Clusters.class).toInstance(createNiceMock(Clusters.class));
+        bind(Configuration.class).toInstance(createNiceMock(Configuration.class));
+        bind(OsFamily.class).toInstance(createNiceMock(OsFamily.class));
+      }
+    });
+
+    ldapContext = createMock(LdapContext.class);
+  }
 
   @Test(expected = KerberosKDCConnectionException.class)
   public void testOpenExceptionLdapUrlNotProvided() throws Exception {
@@ -95,13 +134,8 @@ public class ADKerberosOperationHandlerTest extends KerberosOperationHandlerTest
   @Test(expected = KerberosAdminAuthenticationException.class)
   public void testOpenExceptionAdminCredentialsNotProvided() throws Exception {
     KerberosOperationHandler handler = new ADKerberosOperationHandler();
-    Map<String, String> kerberosEnvMap = new HashMap<String, String>() {
-      {
-        put(ADKerberosOperationHandler.KERBEROS_ENV_LDAP_URL, DEFAULT_LDAP_URL);
-        put(ADKerberosOperationHandler.KERBEROS_ENV_PRINCIPAL_CONTAINER_DN, DEFAULT_PRINCIPAL_CONTAINER_DN);
-      }
-    };
-    handler.open(null, DEFAULT_REALM, kerberosEnvMap);
+
+    handler.open(null, DEFAULT_REALM, getKerberosEnv());
     handler.close();
   }
 
@@ -124,13 +158,6 @@ public class ADKerberosOperationHandlerTest extends KerberosOperationHandlerTest
     Injector injector = getInjector();
 
     PrincipalKeyCredential kc = new PrincipalKeyCredential(DEFAULT_ADMIN_PRINCIPAL, "wrong");
-    Map<String, String> kerberosEnvMap = new HashMap<String, String>() {
-      {
-        put(ADKerberosOperationHandler.KERBEROS_ENV_LDAP_URL, DEFAULT_LDAP_URL);
-        put(ADKerberosOperationHandler.KERBEROS_ENV_PRINCIPAL_CONTAINER_DN, DEFAULT_PRINCIPAL_CONTAINER_DN);
-      }
-    };
-
     ADKerberosOperationHandler handler = createMockBuilder(ADKerberosOperationHandler.class)
         .addMockedMethod(ADKerberosOperationHandler.class.getDeclaredMethod("createInitialLdapContext", Properties.class, Control[].class))
         .createNiceMock();
@@ -145,7 +172,7 @@ public class ADKerberosOperationHandlerTest extends KerberosOperationHandlerTest
 
     replayAll();
 
-    handler.open(kc, DEFAULT_REALM, kerberosEnvMap);
+    handler.open(kc, DEFAULT_REALM, getKerberosEnv());
     handler.testAdministratorCredentials();
     handler.close();
   }
@@ -155,12 +182,6 @@ public class ADKerberosOperationHandlerTest extends KerberosOperationHandlerTest
     Injector injector = getInjector();
 
     PrincipalKeyCredential kc = new PrincipalKeyCredential("wrong", DEFAULT_ADMIN_PASSWORD);
-    Map<String, String> kerberosEnvMap = new HashMap<String, String>() {
-      {
-        put(ADKerberosOperationHandler.KERBEROS_ENV_LDAP_URL, DEFAULT_LDAP_URL);
-        put(ADKerberosOperationHandler.KERBEROS_ENV_PRINCIPAL_CONTAINER_DN, DEFAULT_PRINCIPAL_CONTAINER_DN);
-      }
-    };
 
     ADKerberosOperationHandler handler = createMockBuilder(ADKerberosOperationHandler.class)
         .addMockedMethod(ADKerberosOperationHandler.class.getDeclaredMethod("createInitialLdapContext", Properties.class, Control[].class))
@@ -176,7 +197,7 @@ public class ADKerberosOperationHandlerTest extends KerberosOperationHandlerTest
 
     replayAll();
 
-    handler.open(kc, DEFAULT_REALM, kerberosEnvMap);
+    handler.open(kc, DEFAULT_REALM, getKerberosEnv());
     handler.testAdministratorCredentials();
     handler.close();
   }
@@ -184,17 +205,8 @@ public class ADKerberosOperationHandlerTest extends KerberosOperationHandlerTest
   @Test(expected = KerberosKDCConnectionException.class)
   public void testTestAdministratorCredentialsKDCConnectionException() throws Exception {
     PrincipalKeyCredential kc = new PrincipalKeyCredential(DEFAULT_ADMIN_PRINCIPAL, DEFAULT_ADMIN_PASSWORD);
-    Map<String, String> kerberosEnvMap = new HashMap<String, String>() {
-      {
-        put(ADKerberosOperationHandler.KERBEROS_ENV_LDAP_URL, "invalid");
-        put(ADKerberosOperationHandler.KERBEROS_ENV_PRINCIPAL_CONTAINER_DN, DEFAULT_PRINCIPAL_CONTAINER_DN);
-      }
-    };
-
-    ADKerberosOperationHandler handler = createMockBuilder(ADKerberosOperationHandler.class)
-        .addMockedMethod(ADKerberosOperationHandler.class.getDeclaredMethod("createInitialLdapContext", Properties.class, Control[].class))
-        .createNiceMock();
 
+    ADKerberosOperationHandler handler = createMockedHandler(methodCreateInitialLdapContext);
     expect(handler.createInitialLdapContext(anyObject(Properties.class), anyObject(Control[].class))).andAnswer(new IAnswer<LdapContext>() {
       @Override
       public LdapContext answer() throws Throwable {
@@ -204,7 +216,7 @@ public class ADKerberosOperationHandlerTest extends KerberosOperationHandlerTest
 
     replayAll();
 
-    handler.open(kc, DEFAULT_REALM, kerberosEnvMap);
+    handler.open(kc, DEFAULT_REALM, getKerberosEnv());
     handler.testAdministratorCredentials();
     handler.close();
   }
@@ -212,21 +224,8 @@ public class ADKerberosOperationHandlerTest extends KerberosOperationHandlerTest
 
   @Test
   public void testTestAdministratorCredentialsSuccess() throws Exception {
-    Injector injector = getInjector();
-
     PrincipalKeyCredential kc = new PrincipalKeyCredential(DEFAULT_ADMIN_PRINCIPAL, DEFAULT_ADMIN_PASSWORD);
-    Map<String, String> kerberosEnvMap = new HashMap<String, String>() {
-      {
-        put(ADKerberosOperationHandler.KERBEROS_ENV_LDAP_URL, DEFAULT_LDAP_URL);
-        put(ADKerberosOperationHandler.KERBEROS_ENV_PRINCIPAL_CONTAINER_DN, DEFAULT_PRINCIPAL_CONTAINER_DN);
-      }
-    };
-
-    ADKerberosOperationHandler handler = createMockBuilder(ADKerberosOperationHandler.class)
-        .addMockedMethod(ADKerberosOperationHandler.class.getDeclaredMethod("createInitialLdapContext", Properties.class, Control[].class))
-        .addMockedMethod(ADKerberosOperationHandler.class.getDeclaredMethod("createSearchControls"))
-        .createNiceMock();
-    injector.injectMembers(handler);
+    ADKerberosOperationHandler handler = createMockedHandler(methodCreateInitialLdapContext);
 
     expect(handler.createInitialLdapContext(anyObject(Properties.class), anyObject(Control[].class)))
         .andAnswer(new IAnswer<LdapContext>() {
@@ -245,23 +244,14 @@ public class ADKerberosOperationHandlerTest extends KerberosOperationHandlerTest
                   }
                 })
                 .once();
-            replay(ldapContext);
             return ldapContext;
           }
         })
         .once();
-    expect(handler.createSearchControls()).andAnswer(new IAnswer<SearchControls>() {
-      @Override
-      public SearchControls answer() throws Throwable {
-        SearchControls searchControls = createNiceMock(SearchControls.class);
-        replay(searchControls);
-        return searchControls;
-      }
-    }).once();
 
     replayAll();
 
-    handler.open(kc, DEFAULT_REALM, kerberosEnvMap);
+    handler.open(kc, DEFAULT_REALM, getKerberosEnv());
     handler.testAdministratorCredentials();
     handler.close();
   }
@@ -271,12 +261,6 @@ public class ADKerberosOperationHandlerTest extends KerberosOperationHandlerTest
     Injector injector = getInjector();
 
     PrincipalKeyCredential kc = new PrincipalKeyCredential(DEFAULT_ADMIN_PRINCIPAL, DEFAULT_ADMIN_PASSWORD);
-    Map<String, String> kerberosEnvMap = new HashMap<String, String>() {
-      {
-        put(ADKerberosOperationHandler.KERBEROS_ENV_LDAP_URL, DEFAULT_LDAP_URL);
-        put(ADKerberosOperationHandler.KERBEROS_ENV_PRINCIPAL_CONTAINER_DN, DEFAULT_PRINCIPAL_CONTAINER_DN);
-      }
-    };
 
     Capture<Name> capturedName = newCapture(CaptureType.ALL);
     Capture<Attributes> capturedAttributes = newCapture(CaptureType.ALL);
@@ -315,7 +299,7 @@ public class ADKerberosOperationHandlerTest extends KerberosOperationHandlerTest
 
     replayAll();
 
-    handler.open(kc, DEFAULT_REALM, kerberosEnvMap);
+    handler.open(kc, DEFAULT_REALM, getKerberosEnv());
     handler.createPrincipal("nn/c6501.ambari.apache.org", "secret", true);
     handler.createPrincipal("hdfs@" + DEFAULT_REALM, "secret", false);
     handler.close();
@@ -384,31 +368,26 @@ public class ADKerberosOperationHandlerTest extends KerberosOperationHandlerTest
     Injector injector = getInjector();
 
     PrincipalKeyCredential kc = new PrincipalKeyCredential(DEFAULT_ADMIN_PRINCIPAL, DEFAULT_ADMIN_PASSWORD);
-    Map<String, String> kerberosEnvMap = new HashMap<String, String>() {
-      {
-        put(ADKerberosOperationHandler.KERBEROS_ENV_LDAP_URL, DEFAULT_LDAP_URL);
-        put(ADKerberosOperationHandler.KERBEROS_ENV_PRINCIPAL_CONTAINER_DN, DEFAULT_PRINCIPAL_CONTAINER_DN);
-        put(ADKerberosOperationHandler.KERBEROS_ENV_AD_CREATE_ATTRIBUTES_TEMPLATE, "" +
-            "#set( $user = \"${principal_primary}-${principal_digest}\" )" +
-            "{" +
-            "  \"objectClass\": [" +
-            "    \"top\"," +
-            "    \"person\"," +
-            "    \"organizationalPerson\"," +
-            "    \"user\"" +
-            "  ]," +
-            "  \"cn\": \"$user\"," +
-            "  \"sAMAccountName\": \"$user.substring(0,20)\"," +
-            "  #if( $is_service )" +
-            "  \"servicePrincipalName\": \"$principal_name\"," +
-            "  #end" +
-            "  \"userPrincipalName\": \"$normalized_principal\"," +
-            "  \"unicodePwd\": \"$password\"," +
-            "  \"accountExpires\": \"0\"," +
-            "  \"userAccountControl\": \"66048\"" +
-            "}");
-      }
-    };
+    Map<String, String> kerberosEnvMap = new HashMap<>(getKerberosEnv());
+    kerberosEnvMap.put(ADKerberosOperationHandler.KERBEROS_ENV_AD_CREATE_ATTRIBUTES_TEMPLATE, "" +
+        "#set( $user = \"${principal_primary}-${principal_digest}\" )" +
+        "{" +
+        "  \"objectClass\": [" +
+        "    \"top\"," +
+        "    \"person\"," +
+        "    \"organizationalPerson\"," +
+        "    \"user\"" +
+        "  ]," +
+        "  \"cn\": \"$user\"," +
+        "  \"sAMAccountName\": \"$user.substring(0,20)\"," +
+        "  #if( $is_service )" +
+        "  \"servicePrincipalName\": \"$principal_name\"," +
+        "  #end" +
+        "  \"userPrincipalName\": \"$normalized_principal\"," +
+        "  \"unicodePwd\": \"$password\"," +
+        "  \"accountExpires\": \"0\"," +
+        "  \"userAccountControl\": \"66048\"" +
+        "}");
 
     Capture<Name> capturedName = newCapture();
     Capture<Attributes> capturedAttributes = newCapture();
@@ -491,9 +470,7 @@ public class ADKerberosOperationHandlerTest extends KerberosOperationHandlerTest
     Injector injector = getInjector();
 
     PrincipalKeyCredential kc = new PrincipalKeyCredential(DEFAULT_ADMIN_PRINCIPAL, DEFAULT_ADMIN_PASSWORD);
-    Map<String, String> kerberosEnvMap = new HashMap<String, String>();
-    kerberosEnvMap.put(ADKerberosOperationHandler.KERBEROS_ENV_LDAP_URL, DEFAULT_LDAP_URL);
-    kerberosEnvMap.put(ADKerberosOperationHandler.KERBEROS_ENV_PRINCIPAL_CONTAINER_DN, DEFAULT_PRINCIPAL_CONTAINER_DN);
+    Map<String, String> kerberosEnvMap = new HashMap<>(getKerberosEnv());
     kerberosEnvMap.put(ADKerberosOperationHandler.KERBEROS_ENV_AD_CREATE_ATTRIBUTES_TEMPLATE, "" +
         "{" +
         "\"principal_digest\": \"$principal_digest\"," +
@@ -587,7 +564,7 @@ public class ADKerberosOperationHandlerTest extends KerberosOperationHandlerTest
     }
 
     PrincipalKeyCredential credentials = new PrincipalKeyCredential(principal, password);
-    Map<String, String> kerberosEnvMap = new HashMap<String, String>();
+    Map<String, String> kerberosEnvMap = new HashMap<>();
 
     kerberosEnvMap.put(ADKerberosOperationHandler.KERBEROS_ENV_LDAP_URL, ldapUrl);
     kerberosEnvMap.put(ADKerberosOperationHandler.KERBEROS_ENV_PRINCIPAL_CONTAINER_DN, containerDN);
@@ -596,7 +573,7 @@ public class ADKerberosOperationHandlerTest extends KerberosOperationHandlerTest
 
     System.out.println("Test Admin Credentials: " + handler.testAdministratorCredentials());
     // does the principal already exist?
-    System.out.println("Principal exists: " + handler.principalExists("nn/c1508.ambari.apache.org"));
+    System.out.println("Principal exists: " + handler.principalExists("nn/c1508.ambari.apache.org", true));
 
     handler.close();
 
@@ -605,15 +582,15 @@ public class ADKerberosOperationHandlerTest extends KerberosOperationHandlerTest
     String evaluatedPrincipal;
 
     evaluatedPrincipal = "nn/c6501.ambari.apache.org@" + DEFAULT_REALM;
-    if (handler.principalExists(evaluatedPrincipal)) {
-      handler.setPrincipalPassword(evaluatedPrincipal, "some password");
+    if (handler.principalExists(evaluatedPrincipal, true)) {
+      handler.setPrincipalPassword(evaluatedPrincipal, "some password", true);
     } else {
       handler.createPrincipal(evaluatedPrincipal, "some password", true);
     }
 
     evaluatedPrincipal = "hdfs@" + DEFAULT_REALM;
-    if (handler.principalExists(evaluatedPrincipal)) {
-      handler.setPrincipalPassword(evaluatedPrincipal, "some password");
+    if (handler.principalExists(evaluatedPrincipal, false)) {
+      handler.setPrincipalPassword(evaluatedPrincipal, "some password", false);
     } else {
       handler.createPrincipal(evaluatedPrincipal, "some password", true);
     }
@@ -644,14 +621,14 @@ public class ADKerberosOperationHandlerTest extends KerberosOperationHandlerTest
     handler.open(credentials, realm, kerberosEnvMap);
 
     // remove the principal
-    handler.removePrincipal("abcdefg");
-    handler.removePrincipal("abcdefg/c1509.ambari.apache.org@" + DEFAULT_REALM);
+    handler.removePrincipal("abcdefg", false);
+    handler.removePrincipal("abcdefg/c1509.ambari.apache.org@" + DEFAULT_REALM, true);
 
     handler.createPrincipal("abcdefg/c1509.ambari.apache.org@" + DEFAULT_REALM, "some password", true);
     handler.createPrincipal("abcdefg@" + DEFAULT_REALM, "some password", false);
 
     //update the password
-    handler.setPrincipalPassword("abcdefg/c1509.ambari.apache.org@" + DEFAULT_REALM, "some password");
+    handler.setPrincipalPassword("abcdefg/c1509.ambari.apache.org@" + DEFAULT_REALM, "some password", true);
 
     handler.close();
   }
@@ -687,11 +664,7 @@ public class ADKerberosOperationHandlerTest extends KerberosOperationHandlerTest
 
     replayAll();
 
-    Map<String, String> kerberosConfiguration = new HashMap<String, String>();
-    kerberosConfiguration.put(ADKerberosOperationHandler.KERBEROS_ENV_LDAP_URL, DEFAULT_LDAP_URL);
-    kerberosConfiguration.put(ADKerberosOperationHandler.KERBEROS_ENV_PRINCIPAL_CONTAINER_DN, DEFAULT_PRINCIPAL_CONTAINER_DN);
-
-    handler.open(new PrincipalKeyCredential("principal", "key"), "EXAMPLE.COM", kerberosConfiguration);
+    handler.open(new PrincipalKeyCredential("principal", "key"), "EXAMPLE.COM", getKerberosEnv());
 
     Properties properties = capturedProperties.getValue();
     Assert.assertNotNull(properties);
@@ -705,13 +678,78 @@ public class ADKerberosOperationHandlerTest extends KerberosOperationHandlerTest
   }
 
   private Injector getInjector() {
-    return Guice.createInjector(new AbstractModule() {
-      @Override
-      protected void configure() {
-        bind(Clusters.class).toInstance(createNiceMock(Clusters.class));
-        bind(Configuration.class).toInstance(createNiceMock(Configuration.class));
-        bind(OsFamily.class).toInstance(createNiceMock(OsFamily.class));
-      }
-    });
+    return injector;
+  }
+
+  @Override
+  protected KerberosOperationHandler createMockedHandler() throws KerberosOperationException {
+    return createMockedHandler(methodCreateInitialLdapContext);
+  }
+
+
+  private ADKerberosOperationHandler createMockedHandler(Method... mockedMethods) {
+    ADKerberosOperationHandler handler = createMockBuilder(ADKerberosOperationHandler.class)
+        .addMockedMethods(mockedMethods)
+        .createMock();
+    injector.injectMembers(handler);
+    return handler;
+  }
+
+
+  @Override
+  protected void setupOpenSuccess(KerberosOperationHandler handler) throws Exception {
+
+    ADKerberosOperationHandler adHandler = (ADKerberosOperationHandler) handler;
+
+    expect(adHandler.createInitialLdapContext(anyObject(Properties.class), isNull())).andReturn(ldapContext).anyTimes();
+  }
+
+  @Override
+  protected void setupOpenFailure(KerberosOperationHandler handler) throws Exception {
+    ADKerberosOperationHandler adHandler = (ADKerberosOperationHandler) handler;
+    expect(adHandler.createInitialLdapContext(anyObject(Properties.class), isNull())).andThrow(new AuthenticationException("Bogus error!")).anyTimes();
+  }
+
+  @Override
+  protected void setupPrincipalAlreadyExists(KerberosOperationHandler handler, boolean service) throws Exception {
+    setupPrincipalExists(handler, service);
+  }
+
+  @Override
+  protected void setupPrincipalDoesNotExist(KerberosOperationHandler handler, boolean service) throws Exception {
+    NamingEnumeration<SearchResult> results = createMock(NamingEnumeration.class);
+    results.close();
+    expectLastCall().once();
+    expect(results.hasMore()).andReturn(false).anyTimes();
+
+    expect(ldapContext.search(anyObject(Name.class), anyString(), anyObject(SearchControls.class)))
+        .andReturn(results)
+        .anyTimes();
+    ldapContext.close();
+    expectLastCall().once();
+  }
+
+  @Override
+  protected void setupPrincipalExists(KerberosOperationHandler handler, boolean service) throws Exception {
+    SearchResult result = createMock(SearchResult.class);
+    expect(result.getNameInNamespace()).andReturn("user/service dn").anyTimes();
+
+    NamingEnumeration<SearchResult> results = createMock(NamingEnumeration.class);
+    results.close();
+    expectLastCall().anyTimes();
+    expect(results.hasMore()).andReturn(true).once();
+    expect(results.next()).andReturn(result).once();
+    expect(results.hasMore()).andReturn(false).anyTimes();
+
+    expect(ldapContext.search(anyObject(Name.class), anyString(), anyObject(SearchControls.class)))
+        .andReturn(results)
+        .anyTimes();
+    ldapContext.close();
+    expectLastCall().once();
+  }
+
+  @Override
+  protected Map<String, String> getKerberosEnv() {
+    return KERBEROS_ENV_MAP;
   }
 }
\ No newline at end of file
