@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -18,6 +18,17 @@
 
 package org.apache.ambari.server.stack;
 
+import static org.easymock.EasyMock.createNiceMock;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertSame;
+import static org.junit.Assert.assertTrue;
+
+import java.lang.reflect.Field;
+import java.util.ArrayList;
+import java.util.Collections;
+import java.util.List;
+
 import org.apache.ambari.server.state.AutoDeployInfo;
 import org.apache.ambari.server.state.BulkCommandDefinition;
 import org.apache.ambari.server.state.ClientConfigFileDefinition;
@@ -28,17 +39,6 @@ import org.apache.ambari.server.state.DependencyInfo;
 import org.apache.ambari.server.state.UnlimitedKeyJCERequirement;
 import org.junit.Test;
 
-import java.lang.reflect.Field;
-import java.util.ArrayList;
-import java.util.Collections;
-import java.util.List;
-
-import static org.easymock.EasyMock.createNiceMock;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertSame;
-import static org.junit.Assert.assertTrue;
-
 /**
  * ComponentModule unit test case.
  */
@@ -91,7 +91,7 @@ public class ComponentModuleTest {
 
   @Test
   public void testResolve_ClientConfigFiles() {
-    List<ClientConfigFileDefinition> clientConfigs = new ArrayList<ClientConfigFileDefinition>();
+    List<ClientConfigFileDefinition> clientConfigs = new ArrayList<>();
     ClientConfigFileDefinition clientConfig1 = new ClientConfigFileDefinition();
     clientConfig1.setType("type1");
     clientConfig1.setDictionaryName("dictName1");
@@ -116,7 +116,7 @@ public class ComponentModuleTest {
     assertEquals(clientConfigs, resolveComponent(info, parentInfo).getModuleInfo().getClientConfigFiles());
 
     // value set in both parent and child; child overwrites with no merge
-    List<ClientConfigFileDefinition> clientConfigs2 = new ArrayList<ClientConfigFileDefinition>();
+    List<ClientConfigFileDefinition> clientConfigs2 = new ArrayList<>();
     ClientConfigFileDefinition clientConfig3 = new ClientConfigFileDefinition();
     clientConfig3.setType("type1");
     clientConfig3.setDictionaryName("dictName1");
@@ -229,7 +229,7 @@ public class ComponentModuleTest {
 
   @Test
   public void testResolve_Dependencies() {
-    List<DependencyInfo> dependencies = new ArrayList<DependencyInfo>();
+    List<DependencyInfo> dependencies = new ArrayList<>();
     DependencyInfo dependency1 = new DependencyInfo();
     dependency1.setName("service/one");
     DependencyInfo dependency2 = new DependencyInfo();
@@ -251,7 +251,7 @@ public class ComponentModuleTest {
 
     // value set in both parent and child; merge parent and child
     //todo: currently there is no way to remove an inherited dependency
-    List<DependencyInfo> dependencies2 = new ArrayList<DependencyInfo>();
+    List<DependencyInfo> dependencies2 = new ArrayList<>();
     DependencyInfo dependency3 = new DependencyInfo();
     dependency3.setName("service/two");
     DependencyInfo dependency4 = new DependencyInfo();
@@ -271,7 +271,7 @@ public class ComponentModuleTest {
 
   @Test
   public void testResolve_CustomCommands() throws Exception {
-    List<CustomCommandDefinition> commands = new ArrayList<CustomCommandDefinition>();
+    List<CustomCommandDefinition> commands = new ArrayList<>();
     CustomCommandDefinition command1 = new CustomCommandDefinition();
     setPrivateField(command1, "name", "one");
     CustomCommandDefinition command2 = new CustomCommandDefinition();
@@ -293,7 +293,7 @@ public class ComponentModuleTest {
 
     // value set in both parent and child; merge parent and child
     //todo: currently there is no way to remove an inherited command
-    List<CustomCommandDefinition> commands2 = new ArrayList<CustomCommandDefinition>();
+    List<CustomCommandDefinition> commands2 = new ArrayList<>();
     CustomCommandDefinition command3 = new CustomCommandDefinition();
     // override command 2
     setPrivateField(command3, "name", "two");
@@ -317,7 +317,7 @@ public class ComponentModuleTest {
   // merged if any config dependency is specified in the child.  So, the merged result is either the child
   // dependencies or if null, the parent dependencies.
   public void testResolve_ConfigDependencies() {
-    List<String> dependencies = new ArrayList<String>();
+    List<String> dependencies = new ArrayList<>();
     String dependency1 = "one";
     String dependency2 = "two";
     dependencies.add(dependency1);
@@ -336,7 +336,7 @@ public class ComponentModuleTest {
     assertEquals(dependencies, resolveComponent(info, parentInfo).getModuleInfo().getConfigDependencies());
 
     // value set in both parent and child; merge parent and child
-    List<String> dependencies2 = new ArrayList<String>();
+    List<String> dependencies2 = new ArrayList<>();
     String dependency3 = "two";
     String dependency4 = "four";
     dependencies2.add(dependency3);
@@ -356,7 +356,7 @@ public class ComponentModuleTest {
   // in that the collections aren't merged if any "client to update configs" is specified in the child.
   // So, the merged result is either the child collection or if null, the parent collection.
   public void testResolve_ClientToUpdateConfigs() {
-    List<String> clientsToUpdate = new ArrayList<String>();
+    List<String> clientsToUpdate = new ArrayList<>();
     String client1 = "one";
     String client2 = "two";
     clientsToUpdate.add(client1);
@@ -375,7 +375,7 @@ public class ComponentModuleTest {
     assertEquals(clientsToUpdate, resolveComponent(info, parentInfo).getModuleInfo().getClientsToUpdateConfigs());
 
     // value set in both parent and child; merge parent and child
-    List<String> clientsToUpdate2 = new ArrayList<String>();
+    List<String> clientsToUpdate2 = new ArrayList<>();
     String client3 = "two";
     String client4 = "four";
     clientsToUpdate2.add(client3);
@@ -604,7 +604,7 @@ public class ComponentModuleTest {
   }
 
   private List<ComponentInfo> createComponentInfo(int count){
-    List<ComponentInfo> result = new ArrayList<ComponentInfo>();
+    List<ComponentInfo> result = new ArrayList<>();
     if(count > 0) {
       for(int i = 0; i < count; i++){
         result.add(new ComponentInfo());
@@ -622,7 +622,7 @@ public class ComponentModuleTest {
       parentComponent = new ComponentModule(parentInfo);
     }
 
-    component.resolve(parentComponent, Collections.<String, StackModule>emptyMap(), Collections.<String, ServiceModule>emptyMap(), Collections.<String, ExtensionModule>emptyMap());
+    component.resolve(parentComponent, Collections.emptyMap(), Collections.emptyMap(), Collections.emptyMap());
 
     return component;
   }
