@@ -50,12 +50,10 @@ import org.apache.ambari.server.orm.GuiceJpaInitializer;
 import org.apache.ambari.server.orm.InMemoryDefaultTestModule;
 import org.apache.ambari.server.orm.OrmTestHelper;
 import org.apache.ambari.server.orm.dao.ClusterServiceDAO;
-import org.apache.ambari.server.orm.dao.ClusterStateDAO;
 import org.apache.ambari.server.orm.dao.HostComponentDesiredStateDAO;
 import org.apache.ambari.server.orm.dao.HostComponentStateDAO;
 import org.apache.ambari.server.orm.dao.HostDAO;
 import org.apache.ambari.server.orm.dao.TopologyRequestDAO;
-import org.apache.ambari.server.orm.entities.ClusterStateEntity;
 import org.apache.ambari.server.orm.entities.HostEntity;
 import org.apache.ambari.server.orm.entities.RepositoryVersionEntity;
 import org.apache.ambari.server.state.AgentVersion;
@@ -79,7 +77,6 @@ import org.apache.ambari.server.topology.LogicalRequest;
 import org.apache.ambari.server.topology.PersistedState;
 import org.apache.ambari.server.topology.TopologyManager;
 import org.apache.ambari.server.topology.TopologyRequest;
-import org.apache.ambari.server.topology.tasks.TopologyHostTask;
 import org.apache.ambari.server.utils.EventBusSynchronizer;
 import org.junit.After;
 import org.junit.Before;
@@ -125,11 +122,11 @@ public class ClustersTest {
   }
 
   private void setOsFamily(Host host, String osFamily, String osVersion) {
-    Map<String, String> hostAttributes = new HashMap<>();
-    hostAttributes.put("os_family", osFamily);
-    hostAttributes.put("os_release_version", osVersion);
+	  Map<String, String> hostAttributes = new HashMap<>();
+	  hostAttributes.put("os_family", osFamily);
+	  hostAttributes.put("os_release_version", osVersion);
 
-    host.setHostAttributes(hostAttributes);
+	  host.setHostAttributes(hostAttributes);
   }
 
   @Test
@@ -403,12 +400,12 @@ public class ClustersTest {
     final Config config1 = injector.getInstance(ConfigFactory.class).createNew(cluster, "t1", "1",
         new HashMap<String, String>() {{
           put("prop1", "val1");
-        }}, new HashMap<String, Map<String,String>>());
+        }}, new HashMap<>());
 
     Config config2 = injector.getInstance(ConfigFactory.class).createNew(cluster, "t1", "2",
         new HashMap<String, String>() {{
           put("prop2", "val2");
-        }}, new HashMap<String, Map<String,String>>());
+        }}, new HashMap<>());
 
     // cluster desired config
     cluster.addDesiredConfig("_test", Collections.singleton(config1));
@@ -416,16 +413,20 @@ public class ClustersTest {
     clusters.addHost(h1);
     clusters.addHost(h2);
 
-    Host host1 = clusters.getHost(h1);
 
-    setOsFamily(clusters.getHost(h1), "centos", "5.9");
-    setOsFamily(clusters.getHost(h2), "centos", "5.9");
+    Host host1 = clusters.getHost(h1);
+    Host host2 = clusters.getHost(h2);
+
+    setOsFamily(host1, "centos", "5.9");
+    setOsFamily(host2, "centos", "5.9");
 
     clusters.mapAndPublishHostsToCluster(new HashSet<String>() {
       {
         addAll(Arrays.asList(h1, h2));
       }
     }, c1);
+    clusters.updateHostMappings(host1);
+    clusters.updateHostMappings(host2);
 
     // host config override
     host1.addDesiredConfig(cluster.getClusterId(), true, "_test", config2);
@@ -467,8 +468,8 @@ public class ClustersTest {
     expect(bp.getName()).andReturn("TestBluePrint").anyTimes();
 
     Configuration clusterConfig = new Configuration(
-      Maps.<String, Map<String, String>>newHashMap(),
-      Maps.<String, Map<String, Map<String, String>>>newHashMap()
+      Maps.newHashMap(),
+      Maps.newHashMap()
       );
 
     Map<String, HostGroupInfo> hostGroups = Maps.newHashMap();
@@ -504,58 +505,6 @@ public class ClustersTest {
     Assert.assertEquals(0, topologyRequestDAO.findByClusterId(cluster.getClusterId()).size());
   }
 
-  @Test
-  public void testSetCurrentStackVersion() throws AmbariException {
-    String c1 = "foo3";
-
-    try
-    {
-      clusters.setCurrentStackVersion("", null);
-      fail("Exception should be thrown on invalid set");
-    }
-      catch (AmbariException e) {
-      // Expected
-    }
-
-    try
-    {
-      clusters.setCurrentStackVersion(c1, null);
-      fail("Exception should be thrown on invalid set");
-    }
-    catch (AmbariException e) {
-      // Expected
-    }
-
-    StackId stackId = new StackId("HDP-0.1");
-
-    try
-    {
-      clusters.setCurrentStackVersion(c1, stackId);
-      fail("Exception should be thrown on invalid set");
-    }
-    catch (AmbariException e) {
-      // Expected
-      Assert.assertTrue(e.getMessage().contains("Cluster not found"));
-    }
-
-    clusters.addCluster(c1, stackId);
-    clusters.setCurrentStackVersion(c1, stackId);
-
-    Assert.assertNotNull(clusters.getCluster(c1));
-    ClusterStateEntity entity = injector.getInstance(ClusterStateDAO.class).findByPK(clusters.getCluster(c1).getClusterId());
-    Assert.assertNotNull(entity);
-
-    Assert.assertTrue(entity.getCurrentStack().getStackName().equals(
-        stackId.getStackName())
-        && entity.getCurrentStack().getStackVersion().equals(
-            stackId.getStackVersion()));
-
-    Assert.assertTrue(clusters.getCluster(c1).getCurrentStackVersion().getStackName().equals(stackId.getStackName()));
-    Assert.assertTrue(
-        clusters.getCluster(c1).getCurrentStackVersion().getStackVersion().equals(stackId.getStackVersion()));
-  }
-
-
   @Test
   public void testNullHostNamesInTopologyRequests() throws AmbariException {
     final String hostName = "myhost";
@@ -595,10 +544,11 @@ public class ClustersTest {
     addHostToCluster(hostName, clusterName);
     Host host = clusters.getHost(hostName);
     Assert.assertNotNull(host);
+    long currentTime = System.currentTimeMillis();
 
     HostRegistrationRequestEvent registrationEvent = new HostRegistrationRequestEvent(
         host.getHostName(),
-        new AgentVersion(""), System.currentTimeMillis(), new HostInfo(), new AgentEnv());
+        new AgentVersion(""), currentTime, new HostInfo(), new AgentEnv(), currentTime);
 
     host.handleEvent(registrationEvent);
 
@@ -617,8 +567,8 @@ public class ClustersTest {
     expect(bp.getName()).andReturn("TestBluePrint").anyTimes();
 
     Configuration clusterConfig = new Configuration(
-      Maps.<String, Map<String, String>>newHashMap(),
-      Maps.<String, Map<String, Map<String, String>>>newHashMap()
+      Maps.newHashMap(),
+      Maps.newHashMap()
     );
 
     Map<String, HostGroupInfo> hostGroups = new HashMap<>();
@@ -650,7 +600,7 @@ public class ClustersTest {
     expect(hr.getHostgroupName()).andReturn("MyHostGroup").anyTimes();
     expect(hr.getHostName()).andReturn(hostName).anyTimes();
     expect(hr.getStageId()).andReturn(1L);
-    expect(hr.getTopologyTasks()).andReturn(Collections.<TopologyHostTask>emptyList());
+    expect(hr.getTopologyTasks()).andReturn(Collections.emptyList());
 
     replay(hr);
     return hr;
@@ -702,4 +652,4 @@ public class ClustersTest {
       binder.bind(TopologyManager.class).toInstance(createNiceMock(TopologyManager.class));
     }
   }
-}
\ No newline at end of file
+}
