@@ -30,6 +30,7 @@ from resource_management.libraries.script.config_dictionary import UnknownConfig
 from hive_server_interactive import HiveServerInteractiveDefault
 from resource_management.libraries.script.script import Script
 from resource_management.core import shell
+from resource_management.core.utils import PasswordString
 
 @patch("resource_management.libraries.Script.get_tmp_dir", new=MagicMock(return_value=('/var/lib/ambari-agent/tmp')))
 @patch.object(functions, "get_stack_version", new=MagicMock(return_value="2.0.0.0-1234"))
@@ -57,11 +58,9 @@ class TestHiveServerInteractive(RMFTestCase):
       data = json.load(f)
     return data
 
-  @patch("os.path.isfile")
   @patch("resource_management.libraries.functions.copy_tarball.copy_to_hdfs")
-  def test_configure_default(self, copy_to_hdfs_mock, is_file_mock):
+  def test_configure_default(self, copy_to_hdfs_mock):
     self.maxDiff = None
-    is_file_mock.return_value = True
     copy_to_hdfs_mock.return_value = False
     self.executeScript(self.COMMON_SERVICES_PACKAGE_DIR + "/scripts/hive_server_interactive.py",
                        classname="HiveServerInteractive",
@@ -259,6 +258,7 @@ class TestHiveServerInteractive(RMFTestCase):
                        config_file=self.get_src_folder() + "/test/python/stacks/2.5/configs/hsi_default_for_restart.json",
                        stack_version=self.STACK_VERSION,
                        target=RMFTestCase.TARGET_COMMON_SERVICES,
+                       call_mocks = [(0, "OK.", ""), (0, "OK."), (0, "OK."), (0, "OK."), (0, "OK.")],
                        checked_call_mocks=[(0, "OK.", ""),
                                            #(0, "OK.", ""),
                                            (0, "UNWANTED_STRING \n "
@@ -290,7 +290,12 @@ class TestHiveServerInteractive(RMFTestCase):
     self.assertResourceCalled('File', '/var/run/hive/hive-interactive.pid',
                               action=['delete'],
                               )
-
+    self.assertResourceCalled('Execute', ('slider', 'destroy', u'llap0', '--force'),
+        ignore_failures = True,
+        user = 'hive',
+        timeout = 30,
+    )
+    
     self.assert_configure_default(with_cs_enabled=True)
 
     self.assertResourceCalled('Execute',
@@ -414,7 +419,6 @@ class TestHiveServerInteractive(RMFTestCase):
 
 
   def assert_configure_default(self, no_tmp=False, default_fs_default=u'hdfs://c6401.ambari.apache.org:8020', with_cs_enabled=False):
-
     self.assertResourceCalled('HdfsResource', '/apps/hive/warehouse',
                               immutable_paths = self.DEFAULT_IMMUTABLE_PATHS,
                               security_enabled = False,
@@ -711,16 +715,10 @@ class TestHiveServerInteractive(RMFTestCase):
                               group='root',
                               mode=0644,
     )
-    self.assertResourceCalled('File', '/usr/hdp/current/hive-server2-hive2/lib/None',
-                              action=['delete'],
-                              )
-    self.assertResourceCalled('Execute', ('rm', '-f',
-                                          '/usr/hdp/current/hive-server2-hive2/lib/ojdbc6.jar'),
-                              path=["/bin", "/usr/bin/"],
-                              sudo = True,
-                              )
-    self.assertResourceCalled('File', '/tmp/mysql-connector-java.jar',
-                              content = DownloadSource('http://c6401.ambari.apache.org:8080/resources/mysql-connector-java.jar'))
+    self.assertResourceCalled('File',
+                              '/tmp/mysql-connector-java.jar',
+                              content=DownloadSource('http://c6401.ambari.apache.org:8080/resources/mysql-connector-java.jar'),
+    )
     self.assertResourceCalled('Execute', ('cp',
                                           '--remove-destination',
                                           '/tmp/mysql-connector-java.jar',
@@ -1405,4 +1403,4 @@ class TestHiveServerInteractive(RMFTestCase):
     mock_get_llap_app_status_data.return_value = llap_app_json
 
     status = self.hsi.check_llap_app_status_in_llap_ga(self.llap_app_name, 2)
-    self.assertEqual(status, False)
+    self.assertEqual(status, False)
\ No newline at end of file
