@@ -41,16 +41,15 @@ App.serviceMetricsMapper = App.QuickDataMapper.create({
   },
   hdfsConfig: {
     version: 'nameNodeComponent.host_components[0].metrics.dfs.namenode.Version',
-    active_name_node_id: 'active_name_node_id',
-    standby_name_node_id: 'standby_name_node_id',
-    standby_name_node2_id: 'standby_name_node2_id',
+    active_name_nodes: 'active_name_nodes',
+    standby_name_nodes: 'standby_name_nodes',
     journal_nodes: 'journal_nodes',
     name_node_id: 'name_node_id',
     sname_node_id: 'sname_node_id',
     metrics_not_available: 'metrics_not_available',
-    name_node_start_time: 'nameNodeComponent.host_components[0].metrics.runtime.StartTime',
-    jvm_memory_heap_used: 'nameNodeComponent.host_components[0].metrics.jvm.HeapMemoryUsed',
-    jvm_memory_heap_max: 'nameNodeComponent.host_components[0].metrics.jvm.HeapMemoryMax',
+    name_node_start_time_values: 'name_node_start_time_values',
+    jvm_memory_heap_used_values: 'jvm_memory_heap_used_values',
+    jvm_memory_heap_max_values: 'jvm_memory_heap_max_values',
     live_data_nodes: 'live_data_nodes',
     dead_data_nodes: 'dead_data_nodes',
     decommission_data_nodes: 'decommission_data_nodes',
@@ -58,15 +57,15 @@ App.serviceMetricsMapper = App.QuickDataMapper.create({
     capacity_total: 'nameNodeComponent.host_components[0].metrics.dfs.FSNamesystem.CapacityTotal',
     capacity_remaining: 'nameNodeComponent.host_components[0].metrics.dfs.FSNamesystem.CapacityRemaining',
     capacity_non_dfs_used: 'nameNodeComponent.host_components[0].metrics.dfs.FSNamesystem.CapacityNonDFSUsed',
-    dfs_total_blocks: 'nameNodeComponent.host_components[0].metrics.dfs.FSNamesystem.BlocksTotal',
-    dfs_corrupt_blocks: 'nameNodeComponent.host_components[0].metrics.dfs.FSNamesystem.CorruptBlocks',
-    dfs_missing_blocks: 'nameNodeComponent.host_components[0].metrics.dfs.FSNamesystem.MissingBlocks',
-    dfs_under_replicated_blocks: 'nameNodeComponent.host_components[0].metrics.dfs.FSNamesystem.UnderReplicatedBlocks',
-    dfs_total_files: 'nameNodeComponent.host_components[0].metrics.dfs.namenode.TotalFiles',
-    upgrade_status: 'nameNodeComponent.host_components[0].metrics.dfs.namenode.UpgradeFinalized',
-    safe_mode_status: 'nameNodeComponent.host_components[0].metrics.dfs.namenode.Safemode',
-    name_node_cpu: 'nameNodeComponent.host_components[0].metrics.cpu.cpu_wio',
-    name_node_rpc: 'nameNodeComponent.host_components[0].metrics.rpc.client.RpcQueueTime_avg_time',
+    dfs_total_blocks_values: 'dfs_total_blocks_values',
+    dfs_corrupt_blocks_values: 'dfs_corrupt_blocks_values',
+    dfs_missing_blocks_values: 'dfs_missing_blocks_values',
+    dfs_under_replicated_blocks_values: 'dfs_under_replicated_blocks_values',
+    dfs_total_files_values: 'dfs_total_files_values',
+    work_status_values: 'work_status_values',
+    upgrade_status_values: 'upgrade_status_values',
+    safe_mode_status_values: 'safe_mode_status_values',
+    name_node_rpc_values: 'name_node_rpc_values',
     data_nodes_started: 'data_nodes_started',
     data_nodes_installed: 'data_nodes_installed',
     data_nodes_total: 'data_nodes_total',
@@ -74,6 +73,37 @@ App.serviceMetricsMapper = App.QuickDataMapper.create({
     nfs_gateways_installed: 'nfs_gateways_installed',
     nfs_gateways_total: 'nfs_gateways_total'
   },
+  activeNameNodeConfig: {
+    name_node_start_time_values: 'metrics.runtime.StartTime',
+    jvm_memory_heap_used_values: 'metrics.jvm.HeapMemoryUsed',
+    jvm_memory_heap_max_values: 'metrics.jvm.HeapMemoryMax',
+    dfs_total_blocks_values: 'metrics.dfs.FSNamesystem.BlocksTotal',
+    dfs_corrupt_blocks_values: 'metrics.dfs.FSNamesystem.CorruptBlocks',
+    dfs_missing_blocks_values: 'metrics.dfs.FSNamesystem.MissingBlocks',
+    dfs_under_replicated_blocks_values: 'metrics.dfs.FSNamesystem.UnderReplicatedBlocks',
+    dfs_total_files_values: 'metrics.dfs.FSNamesystem.FilesTotal',
+    work_status_values: 'HostRoles.state',
+    upgrade_status_values: 'metrics.dfs.namenode.UpgradeFinalized',
+    safe_mode_status_values: 'metrics.dfs.namenode.Safemode',
+    name_node_rpc_values: 'metrics.rpc.client.RpcQueueTime_avg_time',
+  },
+  onefsConfig: {
+    metrics_not_available: 'metrics_not_available',
+    name_node_start_time: 'metrics.runtime.StartTime',
+    capacity_used: 'metrics.dfs.FSNamesystem.CapacityUsed',
+    capacity_total: 'metrics.dfs.FSNamesystem.CapacityTotal',
+    capacity_remaining: 'metrics.dfs.FSNamesystem.CapacityRemaining',
+    dfs_corrupt_blocks: 'metrics.dfs.FSNamesystem.CorruptBlocks',
+    dfs_under_replicated_blocks: 'metrics.dfs.FSNamesystem.UnderReplicatedBlocks',
+    dfs_missing_blocks: 'metrics.dfs.FSNamesystem.MissingBlocks',
+    live_data_nodes: 'live_data_nodes',
+    dead_data_nodes: 'dead_data_nodes',
+    decommission_data_nodes: 'decommission_data_nodes',
+    dfs_total_files: 'metrics.dfs.namenode.TotalFiles',
+    jvm_memory_heap_used: 'metrics.jvm.memHeapUsedM',
+    jvm_memory_heap_max: 'metrics.jvm.memHeapCommittedM',
+    upgrade_status: 'metrics.dfs.namenode.UpgradeFinalized'
+  },
   yarnConfig: {
     resource_manager_start_time: 'resourceManagerComponent.host_components[0].metrics.runtime.StartTime',
     jvm_memory_heap_used: 'resourceManagerComponent.host_components[0].metrics.jvm.HeapMemoryUsed',
@@ -118,9 +148,6 @@ App.serviceMetricsMapper = App.QuickDataMapper.create({
     region_servers_started: 'region_servers_started',
     region_servers_installed: 'region_servers_installed',
     region_servers_total: 'region_servers_total',
-    rest_servers_started: 'rest_servers_started',
-    rest_servers_installed: 'rest_servers_installed',
-    rest_servers_total: 'rest_servers_total',
     phoenix_servers_started: 'phoenix_servers_started',
     phoenix_servers_installed: 'phoenix_servers_installed',
     phoenix_servers_total: 'phoenix_servers_total'
@@ -167,7 +194,8 @@ App.serviceMetricsMapper = App.QuickDataMapper.create({
     stale_configs: 'HostRoles.stale_configs',
     ha_status: 'HostRoles.ha_state',
     display_name_advanced: 'display_name_advanced',
-    admin_state: 'HostRoles.desired_admin_state'
+    admin_state: 'HostRoles.desired_admin_state',
+    cluster_id_value: 'metrics.dfs.namenode.ClusterId'
   },
 
   /**
@@ -175,7 +203,9 @@ App.serviceMetricsMapper = App.QuickDataMapper.create({
    * @type {Array}
    * @const
    */
-  ADVANCED_COMPONENTS: ['SECONDARY_NAMENODE', 'RESOURCEMANAGER', 'NAMENODE', 'HBASE_MASTER', 'RESOURCEMANAGER'],
+  ADVANCED_COMPONENTS: ['SECONDARY_NAMENODE', 'RESOURCEMANAGER', 'NAMENODE', 'HBASE_MASTER', 'RESOURCEMANAGER', 'HIVE_SERVER_INTERACTIVE'],
+
+  hostNameIpMap: {},
 
   map: function (json) {
     console.time('App.serviceMetricsMapper execution time');
@@ -190,6 +220,7 @@ App.serviceMetricsMapper = App.QuickDataMapper.create({
       var result = [];
       var advancedHostComponents = [];
       var hostComponentIdsMap = {};
+      var hiveInteractiveServers = [];
 
       /**
        * services contains constructed service-components structure from components array
@@ -212,6 +243,9 @@ App.serviceMetricsMapper = App.QuickDataMapper.create({
           var comp = this.parseIt(host_component, this.config3);
           comp.id = id;
           comp.service_id = serviceName;
+          if (comp.component_name === 'HIVE_SERVER_INTERACTIVE') {
+            hiveInteractiveServers.push(comp);
+          }
           hostComponents.push(comp);
           if (this.get('ADVANCED_COMPONENTS').contains(comp.component_name)) {
             advancedHostComponents.push(comp);
@@ -231,12 +265,21 @@ App.serviceMetricsMapper = App.QuickDataMapper.create({
           if (serviceCache) {
             serviceCache.host_components = serviceCache.host_components.without(hostComponent.get('id'));
           }
+        } else if (id.startsWith('NAMENODE')) {
+          var component = App.HostComponent.find(id),
+            haNameSpace = component.get('haNameSpace');
+          if (component.get('isLoaded') && haNameSpace) {
+            hostComponents.findProperty('id', id).ha_name_space = haNameSpace;
+          }
         }
       }, this);
       previousMasterComponentIds = hostComponents.mapProperty('id');
 
       App.store.safeLoadMany(this.get('model3'), hostComponents);
 
+      if (hiveInteractiveServers.length > 1) {
+        this.loadInteractiveServerStatuses(hiveInteractiveServers);
+      }
       //parse service metrics from components
       services.forEach(function (item) {
         hostComponents.filterProperty('service_id', item.ServiceInfo.service_name).mapProperty('id').forEach(function (hostComponent) {
@@ -269,6 +312,68 @@ App.serviceMetricsMapper = App.QuickDataMapper.create({
     console.timeEnd('App.serviceMetricsMapper execution time');
   },
 
+  loadInteractiveServerStatuses: function (hiveInteractiveServers) {
+    var self = this;
+    App.router.get('configurationController').getCurrentConfigsBySites(['hive-site', 'hive-interactive-site']).done(function (configs) {
+      var hiveWebUiPort = configs.findProperty('type', 'hive-interactive-site').properties['hive.server2.webui.port'];
+      var hiveWebUiProtoFlag = configs.findProperty('type', 'hive-interactive-site').properties['hive.server2.webui.use.ssl'] === 'true';
+      var hiveWebUiProto = hiveWebUiProtoFlag ? 'https' : 'http';
+      var hostNames = hiveInteractiveServers.mapProperty('host_name');
+      var useIps = configs.findProperty('type', 'hive-interactive-site').properties['hive.server2.leadertest.use.ip'];
+      var notDefinedHostIp = hostNames.find(function (hostName) {
+        return !self.get('hostNameIpMap')[hostName];
+      });
+      if (useIps && notDefinedHostIp) {
+        self.getHostNameIpMap(hostNames).done(function () {
+          self.getHiveServersInteractiveStatus(hiveInteractiveServers, hiveWebUiPort, hiveWebUiProto, useIps);
+        });
+      } else {
+        self.getHiveServersInteractiveStatus(hiveInteractiveServers, hiveWebUiPort, hiveWebUiProto, useIps);
+      }
+    });
+  },
+
+  getHostNameIpMap: function (hostNames) {
+    var self = this;
+    return App.ajax.send({
+      name: 'hosts.ips',
+      data: {
+        hostNames: hostNames
+      },
+      sender: self
+    }).success(function (data) {
+      data.items.forEach(function(hostData) {
+        var ip = hostData.Hosts.ip;
+        var hostName = hostData.Hosts.host_name;
+        self.get('hostNameIpMap')[hostName] = ip;
+      })
+    });
+  },
+
+  getHiveServersInteractiveStatus: function(hiveInteractiveServers, hiveWebUiPort, hiveWebUiProto, useIps) {
+    var self = this;
+    hiveInteractiveServers.forEach(function (hiveInteractiveServer) {
+      App.ajax.send({
+        name: 'hiveServerInteractive.getStatus',
+        data: {
+          hsiHost: useIps ? self.hostNameIpMap[hiveInteractiveServer.host_name] : hiveInteractiveServer.host_name,
+          port: hiveWebUiPort,
+          proto: hiveWebUiProto
+        },
+        sender: self
+      }).success(function (isActive) {
+
+        var advancedName = Em.I18n.t('quick.links.label.' +  (isActive ? 'active': 'standby')) + ' ' + hiveInteractiveServer.display_name;
+        var hiveInteractiveServerComponent = App.HostComponent.find().find(function (component) {
+          return component.get('hostName') === hiveInteractiveServer.host_name && component.get('componentName') === 'HIVE_SERVER_INTERACTIVE';
+        });
+        if (hiveInteractiveServerComponent){
+          hiveInteractiveServerComponent.set('displayNameAdvanced', advancedName);
+        }
+      });
+    });
+  },
+
   /**
    * verify that service component has host components
    * @param {object} component
@@ -295,6 +400,10 @@ App.serviceMetricsMapper = App.QuickDataMapper.create({
       finalJson = this.hdfsMapper(item);
       finalJson.rand = Math.random();
       App.store.safeLoad(App.HDFSService, finalJson);
+    } else if (item && item.ServiceInfo && item.ServiceInfo.service_name == "ONEFS") {
+      finalJson = this.onefsMapper(item);
+      finalJson.rand = Math.random();
+      App.store.safeLoad(App.ONEFSService, finalJson);
     } else if (item && item.ServiceInfo && item.ServiceInfo.service_name == "HBASE") {
       finalJson = this.hbaseMapper(item);
       finalJson.rand = Math.random();
@@ -350,7 +459,7 @@ App.serviceMetricsMapper = App.QuickDataMapper.create({
     hostComponents.forEach(function (hostComponent) {
       var service = services.findProperty('ServiceInfo.service_name', hostComponent.service_id);
       if (hostComponent) {
-        // set advanced nameNode display name for HA, Active NameNode or Standby NameNode
+        // set advanced nameNode display name for HA and Federation, Active NameNodes or Standby NameNodes
         // this is useful on three places: 1) HDFS health status hover tooltip, 2) HDFS service summary 3) NameNode component on host detail page
         if (hostComponent.component_name === 'NAMENODE' && !isSecondaryNamenode) {
           var hdfs = this.hdfsMapper(service);
@@ -359,9 +468,9 @@ App.serviceMetricsMapper = App.QuickDataMapper.create({
           var standbyNNText = Em.I18n.t('services.service.summary.nameNode.standby');
           if (hdfs) {
             // active_name_node_id format : NAMENODE_c6401.ambari.apache.org
-            if (hdfs.active_name_node_id && hdfs.active_name_node_id.contains(hostName)) {
+            if (hdfs.active_name_nodes && hdfs.active_name_nodes.contains(`NAMENODE_${hostName}`)) {
               hostComponent.display_name_advanced = activeNNText;
-            } else if ((hdfs.standby_name_node_id && hdfs.standby_name_node_id.contains(hostName)) || ( hdfs.standby_name_node2_id && hdfs.standby_name_node2_id.contains(hostName))) {
+            } else if (hdfs.standby_name_nodes && hdfs.standby_name_nodes.contains(`NAMENODE_${hostName}`)) {
               hostComponent.display_name_advanced = standbyNNText;
             } else {
               hostComponent.display_name_advanced = null;
@@ -384,6 +493,13 @@ App.serviceMetricsMapper = App.QuickDataMapper.create({
               hostComponent.display_name_advanced = Em.I18n.t('dashboard.services.yarn.resourceManager.standby');
               break;
           }
+        } else if (hostComponent.component_name === 'HIVE_SERVER_INTERACTIVE') {
+          var hiveInteractiveServerComponent = App.HostComponent.find().find(function (component) {
+            return component.get('hostName') === hostComponent.host_name && component.get('componentName') === 'HIVE_SERVER_INTERACTIVE';
+          });
+          if (hiveInteractiveServerComponent) {
+            hostComponent.display_name_advanced = hiveInteractiveServerComponent.get('displayNameAdvanced');
+          }
         }
         if (service) {
           if (hostComponent.display_name_advanced) {
@@ -395,6 +511,15 @@ App.serviceMetricsMapper = App.QuickDataMapper.create({
       }
     }, this)
   },
+
+  setNameNodeMetricsProperties: function (item, hostComponent) {
+    const activeNameNodeConfig = this.activeNameNodeConfig,
+      activeNameNodeConfigKeys = Object.keys(activeNameNodeConfig);
+    activeNameNodeConfigKeys.forEach(key => {
+      item[key][Em.get(hostComponent, 'HostRoles.host_name')] = Em.get(hostComponent, activeNameNodeConfig[key]);
+    });
+  },
+
   /**
    * Map quick links to services:OOZIE,GANGLIA
    * @param finalJson
@@ -418,101 +543,117 @@ App.serviceMetricsMapper = App.QuickDataMapper.create({
       finalJson.quick_links = quickLinks[item.ServiceInfo.service_name];
   },
 
-  hdfsMapper: function (item) {
+  onefsMapper: function (item) {
     var finalConfig = jQuery.extend({}, this.config);
-    // Change the JSON so that it is easy to map
-    var hdfsConfig = this.hdfsConfig;
-    var self = this;
     item.components.forEach(function (component) {
+      if (this.isHostComponentPresent(component, 'ONEFS_CLIENT')) {
+        item.metrics = component.metrics;
+        item.decommission_data_nodes = [];
+        item.dead_data_nodes = [];
+        item.live_data_nodes = [];
+        if (component.metrics && component.metrics.dfs && component.metrics.dfs.namenode) {
+          item.metrics_not_available = false;
+          for (var host in App.parseJSON(component.metrics.dfs.namenode.DecomNodes)) {
+            item.decommission_data_nodes.push('DATANODE' + '_' + host);
+          }
+          for (var host in App.parseJSON(component.metrics.dfs.namenode.DeadNodes)) {
+            item.dead_data_nodes.push('DATANODE' + '_' + host);
+          }
+          for (var host in App.parseJSON(component.metrics.dfs.namenode.LiveNodes)) {
+            item.live_data_nodes.push('DATANODE' + '_' + host);
+          }
+        } else {
+          item.metrics_not_available = true;
+        }
+        finalConfig = jQuery.extend(finalConfig, this.onefsConfig);
+      }
+    }, this);
+    return this.parseIt(item, finalConfig);
+  },
+
+  hdfsMapper: function (item) {
+    let finalConfig = jQuery.extend({}, this.config);
+    // Change the JSON so that it is easy to map
+    const hdfsConfig = this.hdfsConfig,
+      activeNameNodeConfigInitial = Object.keys(this.activeNameNodeConfig).reduce((obj, key) => Object.assign({}, obj, {
+        [key]: {}
+      }), {});
+    Object.assign(item, activeNameNodeConfigInitial);
+    item.components.forEach(component => {
+      const hostComponents = component.host_components,
+        firstHostComponent = hostComponents[0];
       if (this.isHostComponentPresent(component, 'NAMENODE')) {
         //enabled HA
-        if (component.host_components.length == 2) {
-          var haState1 = Em.get(component.host_components[0], 'metrics.dfs.FSNamesystem.HAState');
-          var haState2 = Em.get(component.host_components[1], 'metrics.dfs.FSNamesystem.HAState');
-          var active_name_node = [];
-          var standby_name_nodes = [];
-          var namenodeName1 = component.host_components[0].HostRoles.host_name;
-          var namenodeName2 = component.host_components[1].HostRoles.host_name;
-
-          switch (haState1) {
-            case "active":
-              active_name_node.push(namenodeName1);
-              break;
-            case "standby":
-              standby_name_nodes.push(namenodeName1);
-              break;
-          }
-          switch (haState2) {
-            case "active":
-              active_name_node.push(namenodeName2);
-              break;
-            case "standby":
-              standby_name_nodes.push(namenodeName2);
-              break;
-          }
-          item.active_name_node_id = null;
-          item.standby_name_node_id = null;
-          item.standby_name_node2_id = null;
-          switch (active_name_node.length) {
-            case 1:
-              item.active_name_node_id = 'NAMENODE' + '_' + active_name_node[0];
-              break;
-          }
-          switch (standby_name_nodes.length) {
-            case 0:
-              if (active_name_node.length === 1) {
-                var standbyNameNode =  (active_name_node[0] === namenodeName1) ? namenodeName2 : namenodeName1;
-                item.standby_name_node_id = 'NAMENODE' + '_' + standbyNameNode;
-              }
-              break;
-            case 1:
-              item.standby_name_node_id = 'NAMENODE' + '_' + standby_name_nodes[0];
-              break;
-            case 2:
-              item.standby_name_node_id = 'NAMENODE' + '_' + standby_name_nodes[0];
-              item.standby_name_node2_id = 'NAMENODE' + '_' + standby_name_nodes[1];
-              break;
-          }
-          var activeHostComponentIndex = haState2 == "active" ? 1 : 0;
-          self.setActiveAsFirstHostComponent(component, activeHostComponentIndex);
+        if (hostComponents.length > 1) {
+          let nameSpacesWithActiveNameNodes = [],
+            unknownNameNodes = [];
+          item.active_name_nodes = [];
+          item.standby_name_nodes = [];
+          hostComponents.forEach(hc => {
+            const haState = Em.get(hc, 'metrics.dfs.FSNamesystem.HAState'),
+              hostName = Em.get(hc, 'HostRoles.host_name'),
+              clusterIdValue = Em.get(hc, 'metrics.dfs.namenode.ClusterId'),
+              id = `NAMENODE_${hostName}`;
+            switch (haState) {
+              case 'active':
+                nameSpacesWithActiveNameNodes.push(clusterIdValue);
+                item.active_name_nodes.push(id);
+                break;
+              case 'standby':
+                item.standby_name_nodes.push(id);
+                break;
+              default:
+                unknownNameNodes.push({
+                  hostName,
+                  clusterIdValue
+                });
+                break;
+            }
+            this.setNameNodeMetricsProperties(item, hc);
+          });
+          unknownNameNodes.forEach(nameNode => {
+            if (nameSpacesWithActiveNameNodes.contains(nameNode.clusterIdValue)) {
+              item.standby_name_nodes.push(`NAMENODE_${nameNode.hostName}`);
+            }
+          });
+        } else {
+          this.setNameNodeMetricsProperties(item, firstHostComponent);
         }
+
         item.nameNodeComponent = component;
         finalConfig = jQuery.extend(finalConfig, hdfsConfig);
         // Get the live, dead & decommission nodes from string json
-        if (component.host_components[0].metrics && component.host_components[0].metrics.dfs && component.host_components[0].metrics.dfs.namenode) {
+        if (firstHostComponent.metrics && firstHostComponent.metrics.dfs && firstHostComponent.metrics.dfs.namenode) {
           item.metrics_not_available = false;
-          var decommissionNodesJson = App.parseJSON(component.host_components[0].metrics.dfs.namenode.DecomNodes);
-          var deadNodesJson = App.parseJSON(component.host_components[0].metrics.dfs.namenode.DeadNodes);
-          var liveNodesJson = App.parseJSON(component.host_components[0].metrics.dfs.namenode.LiveNodes);
+          var decommissionNodesJson = App.parseJSON(firstHostComponent.metrics.dfs.namenode.DecomNodes);
+          var deadNodesJson = App.parseJSON(firstHostComponent.metrics.dfs.namenode.DeadNodes);
+          var liveNodesJson = App.parseJSON(firstHostComponent.metrics.dfs.namenode.LiveNodes);
         } else {
           item.metrics_not_available = true;
         }
         item.decommission_data_nodes = [];
         item.dead_data_nodes = [];
         item.live_data_nodes = [];
-        for (var host in decommissionNodesJson) {
-          item.decommission_data_nodes.push('DATANODE' + '_' + host);
+        for (let host in decommissionNodesJson) {
+          item.decommission_data_nodes.push(`DATANODE_${host}`);
         }
-        for (var host in deadNodesJson) {
-          item.dead_data_nodes.push('DATANODE' + '_' + host);
+        for (let host in deadNodesJson) {
+          item.dead_data_nodes.push(`DATANODE_${host}`);
         }
-        for (var host in liveNodesJson) {
-          item.live_data_nodes.push('DATANODE' + '_' + host);
+        for (let host in liveNodesJson) {
+          item.live_data_nodes.push(`DATANODE_${host}`);
         }
-        item.name_node_id = "NAMENODE" + "_" + component.host_components[0].HostRoles.host_name;
+        item.name_node_id = `NAMENODE_${firstHostComponent.HostRoles.host_name}`;
       }
-      if (this.isHostComponentPresent(component, "JOURNALNODE")) {
-        item.journal_nodes = [];
-          component.host_components.forEach(function (hc) {
-            item.journal_nodes.push("JOURNALNODE" + "_" + hc.HostRoles.host_name);
-          });
+      if (this.isHostComponentPresent(component, 'JOURNALNODE')) {
+        item.journal_nodes = hostComponents.map(hc => `JOURNALNODE_${hc.HostRoles.host_name}`);
       }
-      if (this.isHostComponentPresent(component, "SECONDARY_NAMENODE")) {
-        item.sname_node_id = "SECONDARY_NAMENODE" + "_" + component.host_components[0].HostRoles.host_name;
+      if (this.isHostComponentPresent(component, 'SECONDARY_NAMENODE')) {
+        item.sname_node_id = `SECONDARY_NAMENODE_${firstHostComponent.HostRoles.host_name}`;
       }
-    }, this);
+    });
     // Map
-    var finalJson = this.parseIt(item, finalConfig);
+    let finalJson = this.parseIt(item, finalConfig);
     finalJson.quick_links = [1, 2, 3, 4];
 
     return finalJson;
@@ -600,8 +741,8 @@ App.serviceMetricsMapper = App.QuickDataMapper.create({
           var activeHostComponentIndex = component.host_components.indexOf(activeMaster);
           self.setActiveAsFirstHostComponent(component, activeHostComponentIndex);
           var regionsArray = null;
-          if (!Em.none(Em.get(component.host_components[0], 'metrics.master.AssignmentManger.ritCount'))) {
-            regionsArray = App.parseJSON(component.host_components[0].metrics.master.AssignmentManger.ritCount);
+          if (!Em.none(Em.get(component.host_components[0], 'metrics.master.AssignmentManager.ritCount'))) {
+            regionsArray = App.parseJSON(component.host_components[0].metrics.master.AssignmentManager.ritCount);
           }
           //regions_in_transition can have various type of value: null, array or int
           if (Array.isArray(regionsArray)) {
