@@ -42,7 +42,7 @@ App.WidgetMixin = Ember.Mixin.create({
    * @type {RegExp}
    * @const
    */
-  VALUE_NAME_REGEX: /(\w+\s+\w+)?[\w\.\,\-\:\=\[\]]+/g,
+  VALUE_NAME_REGEX: /[^(\s+\-\*\/\\+\s+)+](\w+\s+\w+)?[\w\.\,\-\:\=\[\]]*/g,
 
   /**
    * @type {string}
@@ -84,7 +84,6 @@ App.WidgetMixin = Ember.Mixin.create({
   contentColor: Em.computed.ifThenElse('value', 'green', 'grey'),
 
   beforeRender: function () {
-    this.get('metrics').clear();
     this.loadMetrics();
   },
 
@@ -98,6 +97,8 @@ App.WidgetMixin = Ember.Mixin.create({
       requestCounter = 0,
       self = this;
 
+    this.set('metrics', []);
+
     for (var i in requestData) {
       request = requestData[i];
       requestCounter++;
@@ -166,7 +167,7 @@ App.WidgetMixin = Ember.Mixin.create({
   getRequestData: function (metrics) {
     var requestsData = {};
     if (metrics) {
-      metrics.forEach(function (metric, index) {
+      metrics.forEach(function (metric) {
         var key;
         if (metric.host_component_criteria) {
           key = metric.service_name + '_' + metric.component_name + '_' + metric.host_component_criteria;
@@ -189,6 +190,7 @@ App.WidgetMixin = Ember.Mixin.create({
             id: requestMetric["metric_path"] + "_" + this.get('metricType'),
             context: this}];
           delete requestMetric["metric_path"];
+          requestMetric.tag = this.get('content.tag');
           requestsData[key] = requestMetric;
         }
       }, this);
@@ -254,16 +256,21 @@ App.WidgetMixin = Ember.Mixin.create({
    */
   getHostComponentMetrics: function (request) {
     var metricPaths = this.prepareMetricPaths(request.metric_paths);
+    var data = {
+      componentName: request.component_name,
+      metricPaths: this.prepareMetricPaths(request.metric_paths),
+      hostComponentCriteria: this.computeHostComponentCriteria(request)
+    };
+
+    if (request.tag) {
+      data.selectedHostsParam = '&HostRoles/host_name.in(' + App.HDFSService.find().objectAt(0).get('masterComponentGroups').findProperty('name', request.tag).hosts.join(',') + ')';
+    }
 
     if (metricPaths.length) {
       var xhr = App.ajax.send({
           name: 'widgets.hostComponent.metrics.get',
           sender: this,
-          data: {
-            componentName: request.component_name,
-            metricPaths: this.prepareMetricPaths(request.metric_paths),
-            hostComponentCriteria: this.computeHostComponentCriteria(request)
-          }
+          data: data
         }),
         graph = this.get('graphView') && this.get('childViews') && this.get('childViews').findProperty('runningRequests');
       if (graph) {
@@ -390,12 +397,12 @@ App.WidgetMixin = Ember.Mixin.create({
     var metrics = this.get('content.metrics');
     data.host_components.forEach(function (item) {
       metrics.forEach(function (_metric) {
+        const metric = $.extend({}, _metric, true);
+        metric.hostName = item.HostRoles.host_name;
         if (!Em.isNone(Em.get(item, _metric.metric_path.replace(/\//g, '.')))) {
-          var metric = $.extend({}, _metric, true);
           metric.data = Em.get(item, _metric.metric_path.replace(/\//g, '.'));
-          metric.hostName = item.HostRoles.host_name;
-          this.get('metrics').pushObject(metric);
         }
+        this.get('metrics').pushObject(metric);
       }, this);
     }, this);
   },
@@ -416,12 +423,12 @@ App.WidgetMixin = Ember.Mixin.create({
     var metrics = this.get('content.metrics');
     data.items.forEach(function (item) {
       metrics.forEach(function (_metric, index) {
+        const metric = $.extend({}, _metric, true);
+        metric.hostName = item.Hosts.host_name;
         if (!Em.isNone(Em.get(item, _metric.metric_path.replace(/\//g, '.')))) {
-          var metric = $.extend({}, _metric, true);
           metric.data = Em.get(item, _metric.metric_path.replace(/\//g, '.'));
-          metric.hostName = item.Hosts.host_name;
-          this.get('metrics').pushObject(metric);
         }
+        this.get('metrics').pushObject(metric);
       }, this);
     }, this);
   },
@@ -459,18 +466,18 @@ App.WidgetMixin = Ember.Mixin.create({
     if (this.get('isLoaded')) {
       Em.run.next(function(){
         if (self.get('state') === 'inDOM') {
-          App.tooltip(self.$(".corner-icon > .icon-copy"), {title: Em.I18n.t('common.clone')});
-          App.tooltip(self.$(".corner-icon > .icon-edit"), {title: Em.I18n.t('common.edit')});
-          App.tooltip(self.$(".corner-icon > .icon-save"), {title: Em.I18n.t('common.export')});
+          App.tooltip(self.$(".corner-icon > .glyphicon-copy"), {title: Em.I18n.t('common.clone')});
+          App.tooltip(self.$(".corner-icon > .glyphicon-edit"), {title: Em.I18n.t('common.edit')});
+          App.tooltip(self.$(".corner-icon > .glyphicon-save"), {title: Em.I18n.t('common.export')});
         }
       });
     }
   }.observes('isLoaded'),
 
   willDestroyElement: function() {
-    this.$(".corner-icon > .icon-copy").tooltip('destroy');
-    this.$(".corner-icon > .icon-edit").tooltip('destroy');
-    this.$(".corner-icon > .icon-save").tooltip('destroy');
+    this.$(".corner-icon > .glyphicon-copy").tooltip('destroy');
+    this.$(".corner-icon > .glyphicon-edit").tooltip('destroy');
+    this.$(".corner-icon > .glyphicon-save").tooltip('destroy');
   },
 
   /**
@@ -557,7 +564,8 @@ App.WidgetMixin = Ember.Mixin.create({
     this.get('controller').hideWidget(
       {
         context: Em.Object.create({
-          id: event.context
+          id: event.contexts[0],
+          nsLayout: event.contexts[1]
         })
       }
     );
@@ -584,7 +592,7 @@ App.WidgetMixin = Ember.Mixin.create({
    * @returns {{WidgetInfo: {widget_name: *, widget_type: *, description: *, scope: *, metrics: *, values: *, properties: *}}}
    */
   collectWidgetData: function () {
-    return {
+    var widgetData = {
       WidgetInfo: {
         widget_name: this.get('content.widgetName'),
         widget_type: this.get('content.widgetType'),
@@ -603,6 +611,12 @@ App.WidgetMixin = Ember.Mixin.create({
         properties: this.get('content.properties')
       }
     };
+
+    this.get('content.metrics').forEach(function (metric) {
+      if (metric.tag) widgetData.WidgetInfo.tag = metric.tag;
+    });
+
+    return widgetData;
   },
 
   /**
@@ -633,9 +647,9 @@ App.WidgetMixin = Ember.Mixin.create({
     widgets.pushObject(Em.Object.create({
       id: data.resources[0].WidgetInfo.id
     }));
-    var mainServiceInfoSummaryController =  App.router.get('mainServiceInfoSummaryController');
-    mainServiceInfoSummaryController.saveWidgetLayout(widgets).done(function(){
-      mainServiceInfoSummaryController.updateActiveLayout();
+    var mainServiceInfoMetricsController =  App.router.get('mainServiceInfoMetricsController');
+    mainServiceInfoMetricsController.saveWidgetLayout(widgets).done(function(){
+      mainServiceInfoMetricsController.updateActiveLayout();
     });
   },
 
@@ -649,9 +663,9 @@ App.WidgetMixin = Ember.Mixin.create({
     widgets.pushObject(Em.Object.create({
       id: id
     }));
-    var mainServiceInfoSummaryController =  App.router.get('mainServiceInfoSummaryController');
-    mainServiceInfoSummaryController.saveWidgetLayout(widgets).done(function() {
-      mainServiceInfoSummaryController.getActiveWidgetLayout().done(function() {
+    var mainServiceInfoMetricsController =  App.router.get('mainServiceInfoMetricsController');
+    mainServiceInfoMetricsController.saveWidgetLayout(widgets).done(function() {
+      mainServiceInfoMetricsController.getActiveWidgetLayout().done(function() {
         var newWidget = App.Widget.find().findProperty('id', id);
         controller.editWidget(newWidget);
       });
@@ -694,6 +708,7 @@ App.WidgetMixin = Ember.Mixin.create({
 App.WidgetPreviewMixin = Ember.Mixin.create({
   beforeRender: Em.K,
   isLoaded: true,
+  isPreview: true,
   metrics: [],
   content: Em.Object.create({
     id: 1,
@@ -783,7 +798,8 @@ App.WidgetLoadAggregator = Em.Object.create({
     requests.forEach(function (request) {
       //poll metrics for graph widgets separately
       var graphSuffix = request.context.get('content.widgetType') === "GRAPH" ? "_graph" : '';
-      var id = request.startCallName + "_" + request.data.component_name + graphSuffix;
+      var tagSuffix = request.context.get('content.tag') ? '_' + request.context.get('content.tag') : '';
+      var id = request.startCallName + "_" + request.data.component_name + graphSuffix + tagSuffix;
 
       if (Em.isNone(bulks[id])) {
         bulks[id] = {
