@@ -32,12 +32,14 @@ App.HostComponent = DS.Model.extend({
   publicHostName: DS.attr('string'),
   service: DS.belongsTo('App.Service'),
   adminState: DS.attr('string'),
+  haNameSpace: DS.attr('string'),
+  clusterIdValue: DS.attr('string'),
 
   serviceDisplayName: Em.computed.truncate('service.displayName', 14, 11),
 
-  getDisplayName: Em.computed.truncate('displayName', 19, 16),
+  getDisplayName: Em.computed.truncate('displayName', 30, 25),
 
-  getDisplayNameAdvanced:Em.computed.truncate('displayNameAdvanced', 19, 16),
+  getDisplayNameAdvanced:Em.computed.truncate('displayNameAdvanced', 30, 25),
 
   summaryLabelClassName:function(){
     return 'label_for_'+this.get('componentName').toLowerCase();
@@ -114,7 +116,17 @@ App.HostComponent = DS.Model.extend({
    * User friendly host component status
    * @returns {String}
    */
-  isActive: Em.computed.equal('passiveState', 'OFF'),
+  isActive: function() {
+    let passiveState = this.get('passiveState');
+    if (passiveState === 'IMPLIED_FROM_HOST') {
+      passiveState = this.get('host.passiveState');
+    } else if (passiveState === 'IMPLIED_FROM_SERVICE') {
+      passiveState = this.get('service.passiveState');
+    } else if (passiveState === 'IMPLIED_FROM_SERVICE_AND_HOST') {
+      return this.get('service.passiveState') === 'OFF' && this.get('host.passiveState') === 'OFF';
+    }
+    return passiveState === 'OFF';
+  }.property('passiveState', 'host.passiveState', 'service.passiveState'),
 
   /**
    * Determine if passiveState is implied from host or/and service
@@ -158,6 +170,9 @@ App.HostComponent = DS.Model.extend({
   },
 
   componentTextStatus: function () {
+    if (this.get('isClient') && this.get("workStatus") === 'INSTALLED') {
+      return Em.I18n.t('common.installed');
+    }
     return App.HostComponentStatus.getTextStatus(this.get("workStatus"));
   }.property('workStatus', 'isDecommissioning')
 });
@@ -195,6 +210,15 @@ App.HostComponent.getCount = function (componentName, type) {
   }
 };
 
+/**
+ * @param {string} componentName
+ * @param {string} hostName
+ * @returns {string}
+ */
+App.HostComponent.getId = function(componentName, hostName) {
+  return componentName + '_' + hostName;
+};
+
 App.HostComponentStatus = {
   started: "STARTED",
   starting: "STARTING",
@@ -282,48 +306,87 @@ App.HostComponentStatus = {
 };
 
 App.HostComponentActionMap = {
-  getMap: function(ctx) {
-    var NN = ctx.get('controller.content.hostComponents').findProperty('componentName', 'NAMENODE');
-    var RM = ctx.get('controller.content.hostComponents').findProperty('componentName', 'RESOURCEMANAGER');
-    var RA = ctx.get('controller.content.hostComponents').findProperty('componentName', 'RANGER_ADMIN');
-    var HM = ctx.get('controller.content.hostComponents').findProperty('componentName', 'HAWQMASTER');
-    var HS = ctx.get('controller.content.hostComponents').findProperty('componentName', 'HAWQSTANDBY');
-    var HMComponent = App.MasterComponent.find('HAWQMASTER');
-    var HSComponent = App.MasterComponent.find('HAWQSTANDBY');
+  getMap: function (ctx) {
+    const NN = ctx.get('controller.content.hostComponents').findProperty('componentName', 'NAMENODE'),
+      RM = ctx.get('controller.content.hostComponents').findProperty('componentName', 'RESOURCEMANAGER'),
+      RA = ctx.get('controller.content.hostComponents').findProperty('componentName', 'RANGER_ADMIN'),
+      HM = ctx.get('controller.content.hostComponents').findProperty('componentName', 'HAWQMASTER'),
+      HS = ctx.get('controller.content.hostComponents').findProperty('componentName', 'HAWQSTANDBY'),
+      HMComponent = App.MasterComponent.find('HAWQMASTER'),
+      HSComponent = App.MasterComponent.find('HAWQSTANDBY'),
+      hasMultipleMasterComponentGroups = ctx.get('service.hasMultipleMasterComponentGroups'),
+      isClientsOnlyService = ctx.get('controller.isClientsOnlyService'),
+      isStartDisabled = ctx.get('controller.isStartDisabled'),
+      isStopDisabled = ctx.get('controller.isStopDisabled');
 
     return {
+      START_ALL: {
+        action: hasMultipleMasterComponentGroups ? '' : 'startService',
+        label: Em.I18n.t('services.service.start'),
+        cssClass: `glyphicon glyphicon-play ${isStartDisabled ? 'disabled' : 'enabled'}`,
+        isHidden: isClientsOnlyService,
+        disabled: isStartDisabled,
+        hasSubmenu: !isStartDisabled && hasMultipleMasterComponentGroups,
+        submenuOptions: !isStartDisabled && hasMultipleMasterComponentGroups ? this.getMastersSubmenu(ctx, 'startCertainHostComponents') : []
+      },
+      STOP_ALL: {
+        action: hasMultipleMasterComponentGroups ? '' : 'stopService',
+        label: Em.I18n.t('services.service.stop'),
+        cssClass: `glyphicon glyphicon-stop ${isStopDisabled ? 'disabled' : 'enabled'}`,
+        isHidden: isClientsOnlyService,
+        disabled: isStopDisabled,
+        hasSubmenu: !isStopDisabled && hasMultipleMasterComponentGroups,
+        submenuOptions: !isStopDisabled && hasMultipleMasterComponentGroups ? this.getMastersSubmenu(ctx, 'stopCertainHostComponents') : []
+      },
       RESTART_ALL: {
-        action: 'restartAllHostComponents',
+        action: hasMultipleMasterComponentGroups ? '' : 'restartAllHostComponents',
         context: ctx.get('serviceName'),
-        label: Em.I18n.t('restart.service.all'),
-        cssClass: 'icon-repeat',
-        disabled: false
+        label: hasMultipleMasterComponentGroups ? Em.I18n.t('common.restart') : Em.I18n.t('restart.service.all'),
+        cssClass: 'glyphicon glyphicon-time',
+        disabled: false,
+        hasSubmenu: hasMultipleMasterComponentGroups,
+        submenuOptions: hasMultipleMasterComponentGroups ? this.getMastersSubmenu(ctx, 'restartCertainHostComponents') : []
+      },
+      RESTART_NAMENODES: {
+        action: '',
+        label: Em.I18n.t('rollingrestart.dialog.title').format(pluralize(App.format.role('NAMENODE', false))),
+        cssClass: 'glyphicon glyphicon-time',
+        isHidden: !hasMultipleMasterComponentGroups,
+        disabled: false,
+        hasSubmenu: true,
+        submenuOptions: this.getMastersSubmenu(ctx, 'restartCertainHostComponents', ['NAMENODE'])
       },
       RUN_SMOKE_TEST: {
         action: 'runSmokeTest',
         label: Em.I18n.t('services.service.actions.run.smoke'),
-        cssClass: 'icon-thumbs-up-alt',
+        cssClass: 'glyphicon glyphicon-thumbs-up',
         disabled: ctx.get('controller.isSmokeTestDisabled')
       },
       REFRESH_CONFIGS: {
         action: 'refreshConfigs',
         label: Em.I18n.t('hosts.host.details.refreshConfigs'),
-        cssClass: 'icon-refresh',
+        cssClass: 'glyphicon glyphicon-refresh',
         disabled: false
       },
+      REGENERATE_KEYTAB_FILE_OPERATIONS: {
+        action: 'regenerateKeytabFileOperations',
+        label: Em.I18n.t('admin.kerberos.button.regenerateKeytabs'),
+        cssClass: 'glyphicon glyphicon-repeat',
+        isHidden: !App.get('isKerberosEnabled') || App.get('router.mainAdminKerberosController.isManualKerberos')
+      },
       REFRESHQUEUES: {
         action: 'refreshYarnQueues',
         customCommand: 'REFRESHQUEUES',
         context : Em.I18n.t('services.service.actions.run.yarnRefreshQueues.context'),
         label: Em.I18n.t('services.service.actions.run.yarnRefreshQueues.menu'),
-        cssClass: 'icon-refresh',
+        cssClass: 'glyphicon glyphicon-refresh',
         disabled: false
       },
       ROLLING_RESTART: {
         action: 'rollingRestart',
         context: ctx.get('rollingRestartComponent'),
         label: Em.I18n.t('rollingrestart.dialog.title'),
-        cssClass: 'icon-time',
+        cssClass: 'glyphicon glyphicon-time',
         disabled: false
       },
       TOGGLE_PASSIVE: {
@@ -343,21 +406,21 @@ App.HostComponentActionMap = {
       TOGGLE_NN_HA: {
         action: App.get('isHaEnabled') ? 'disableHighAvailability' : 'enableHighAvailability',
         label: App.get('isHaEnabled') ? Em.I18n.t('admin.highAvailability.button.disable') : Em.I18n.t('admin.highAvailability.button.enable'),
-        cssClass: App.get('isHaEnabled') ? 'icon-arrow-down' : 'icon-arrow-up',
+        cssClass: App.get('isHaEnabled') ? 'glyphicon glyphicon-arrow-down' : 'glyphicon glyphicon-arrow-up',
         isHidden: App.get('isHaEnabled'),
         disabled: App.get('isSingleNode') || !NN || NN.get('isNotInstalled')
       },
       TOGGLE_RM_HA: {
         action: 'enableRMHighAvailability',
-        label: Em.I18n.t('admin.rm_highAvailability.button.enable'),
-        cssClass: 'icon-arrow-up',
+        label: App.get('isRMHaEnabled') ? Em.I18n.t('admin.rm_highAvailability.button.disable') : Em.I18n.t('admin.rm_highAvailability.button.enable'),
+        cssClass: App.get('isRMHaEnabled') ? 'glyphicon glyphicon-arrow-down' : 'glyphicon glyphicon-arrow-up',
         isHidden: App.get('isRMHaEnabled'),
         disabled: App.get('isSingleNode') || !RM || RM.get('isNotInstalled')
       },
       TOGGLE_RA_HA: {
         action: 'enableRAHighAvailability',
         label: Em.I18n.t('admin.ra_highAvailability.button.enable'),
-        cssClass: 'icon-arrow-up',
+        cssClass: 'glyphicon glyphicon-arrow-up',
         isHidden: App.get('isRAHaEnabled'),
         disabled: App.get('isSingleNode') || !RA || RA.get('isNotInstalled')
       },
@@ -366,14 +429,14 @@ App.HostComponentActionMap = {
         context: '',
         isHidden: !App.isAuthorized('SERVICE.MOVE'),
         label: Em.I18n.t('services.service.actions.reassign.master'),
-        cssClass: 'icon-share-alt'
+        cssClass: 'glyphicon glyphicon-share-alt'
       },
       STARTDEMOLDAP: {
         action: 'startLdapKnox',
         customCommand: 'STARTDEMOLDAP',
         context: Em.I18n.t('services.service.actions.run.startLdapKnox.context'),
         label: Em.I18n.t('services.service.actions.run.startLdapKnox.context'),
-        cssClass: 'icon-play-sign',
+        cssClass: 'icon icon-play-sign',
         disabled: false
       },
       STOPDEMOLDAP: {
@@ -381,7 +444,7 @@ App.HostComponentActionMap = {
         customCommand: 'STOPDEMOLDAP',
         context: Em.I18n.t('services.service.actions.run.stopLdapKnox.context'),
         label: Em.I18n.t('services.service.actions.run.stopLdapKnox.context'),
-        cssClass: 'icon-stop',
+        cssClass: 'glyphicon glyphicon-stop',
         disabled: false
       },
       RESTART_LLAP: {
@@ -389,20 +452,20 @@ App.HostComponentActionMap = {
         customCommand: 'RESTART_LLAP',
         context: Em.I18n.t('services.service.actions.run.restartLLAP'),
         label: Em.I18n.t('services.service.actions.run.restartLLAP') + ' ∞',
-        cssClass: 'icon-refresh'
+        cssClass: 'glyphicon glyphicon-refresh'
       },
       REBALANCEHDFS: {
         action: 'rebalanceHdfsNodes',
         customCommand: 'REBALANCEHDFS',
         context: Em.I18n.t('services.service.actions.run.rebalanceHdfsNodes.context'),
         label: Em.I18n.t('services.service.actions.run.rebalanceHdfsNodes'),
-        cssClass: 'icon-refresh',
+        cssClass: 'glyphicon glyphicon-refresh',
         disabled: false
       },
       DOWNLOAD_CLIENT_CONFIGS: {
         action: ctx.get('controller.isSeveralClients') ? '' : 'downloadClientConfigs',
         label: Em.I18n.t('services.service.actions.downloadClientConfigs'),
-        cssClass: 'icon-download-alt',
+        cssClass: 'glyphicon glyphicon-download-alt',
         isHidden: !!ctx.get('controller.content.clientComponents') ? ctx.get('controller.content.clientComponents').rejectProperty('totalCount', 0).length == 0 : false,
         disabled: false,
         hasSubmenu: ctx.get('controller.isSeveralClients'),
@@ -412,35 +475,36 @@ App.HostComponentActionMap = {
         action: 'deleteService',
         context: ctx.get('serviceName'),
         label: Em.I18n.t('services.service.actions.deleteService'),
-        cssClass: 'icon-remove'
+        cssClass: 'glyphicon glyphicon-remove',
+        isHidden: !App.get('services.supportsDeleteViaUI').contains(ctx.get('serviceName')) //hide the menu item when the service has a custom behavior setting in its metainfo.xml to disallow Delete Services via UI
       },
       IMMEDIATE_STOP_HAWQ_SERVICE: {
         action: 'executeHawqCustomCommand',
         customCommand: 'IMMEDIATE_STOP_HAWQ_SERVICE',
         context: Em.I18n.t('services.service.actions.run.immediateStopHawqService.context'),
         label: Em.I18n.t('services.service.actions.run.immediateStopHawqService.label'),
-        cssClass: 'icon-stop',
+        cssClass: 'glyphicon glyphicon-stop',
         disabled: !HM || HM.get('workStatus') != App.HostComponentStatus.started
       },
       IMMEDIATE_STOP_HAWQ_SEGMENT: {
         customCommand: 'IMMEDIATE_STOP_HAWQ_SEGMENT',
         context: Em.I18n.t('services.service.actions.run.immediateStopHawqSegment.context'),
         label: Em.I18n.t('services.service.actions.run.immediateStopHawqSegment.label'),
-        cssClass: 'icon-stop'
+        cssClass: 'glyphicon glyphicon-stop'
       },
       RESYNC_HAWQ_STANDBY: {
         action: 'executeHawqCustomCommand',
         customCommand: 'RESYNC_HAWQ_STANDBY',
         context: Em.I18n.t('services.service.actions.run.resyncHawqStandby.context'),
         label: Em.I18n.t('services.service.actions.run.resyncHawqStandby.label'),
-        cssClass: 'icon-refresh',
+        cssClass: 'glyphicon glyphicon-refresh',
         isHidden : App.get('isSingleNode') || !HS ,
         disabled: !((!!HMComponent && HMComponent.get('startedCount') === 1) && (!!HSComponent && HSComponent.get('startedCount') === 1))
       },
       TOGGLE_ADD_HAWQ_STANDBY: {
         action: 'addHawqStandby',
         label: Em.I18n.t('admin.addHawqStandby.button.enable'),
-        cssClass: 'icon-plus',
+        cssClass: 'glyphicon glyphicon-plus',
         isHidden: App.get('isSingleNode') || HS,
         disabled: false
       },
@@ -448,7 +512,7 @@ App.HostComponentActionMap = {
         action: 'removeHawqStandby',
         context: Em.I18n.t('admin.removeHawqStandby.button.enable'),
         label: Em.I18n.t('admin.removeHawqStandby.button.enable'),
-        cssClass: 'icon-minus',
+        cssClass: 'glyphicon glyphicon-minus',
         isHidden: App.get('isSingleNode') || !HS,
         disabled: !HM || HM.get('workStatus') != App.HostComponentStatus.started,
         hideFromComponentView: true
@@ -457,7 +521,7 @@ App.HostComponentActionMap = {
         action: 'activateHawqStandby',
         label: Em.I18n.t('admin.activateHawqStandby.button.enable'),
         context: Em.I18n.t('admin.activateHawqStandby.button.enable'),
-        cssClass: 'icon-arrow-up',
+        cssClass: 'glyphicon glyphicon-arrow-up',
         isHidden: App.get('isSingleNode') || !HS,
         disabled: false,
         hideFromComponentView: true
@@ -467,7 +531,7 @@ App.HostComponentActionMap = {
         customCommand: 'HAWQ_CLEAR_CACHE',
         context: Em.I18n.t('services.service.actions.run.clearHawqCache.label'),
         label: Em.I18n.t('services.service.actions.run.clearHawqCache.label'),
-        cssClass: 'icon-refresh',
+        cssClass: 'glyphicon glyphicon-refresh',
         isHidden : false,
         disabled: !HM || HM.get('workStatus') != App.HostComponentStatus.started
       },
@@ -476,16 +540,69 @@ App.HostComponentActionMap = {
         customCommand: 'RUN_HAWQ_CHECK',
         context: Em.I18n.t('services.service.actions.run.runHawqCheck.label'),
         label: Em.I18n.t('services.service.actions.run.runHawqCheck.label'),
-        cssClass: 'icon-thumbs-up-alt',
+        cssClass: 'glyphicon glyphicon-thumbs-up',
         isHidden : false,
         disabled: false
       },
       MASTER_CUSTOM_COMMAND: {
         action: 'executeCustomCommand',
-        cssClass: 'icon-play-circle',
+        cssClass: 'glyphicon glyphicon-play-circle',
         isHidden: false,
         disabled: false
+      },
+      TOGGLE_NN_FEDERATION: {
+        action: 'openNameNodeFederationWizard',
+        label: Em.I18n.t('admin.nameNodeFederation.button.enable'),
+        cssClass: 'icon icon-sitemap',
+        disabled: !App.get('isHaEnabled')
+      },
+      UPDATE_REPLICATION: {
+        action: 'updateHBaseReplication',
+        customCommand: 'UPDATE_REPLICATION',
+        context: Em.I18n.t('services.service.actions.run.updateHBaseReplication.context'),
+        label: Em.I18n.t('services.service.actions.run.updateHBaseReplication.label'),
+        cssClass: 'glyphicon glyphicon-refresh',
+        disabled: false
+      },
+      STOP_REPLICATION: {
+        action: 'stopHBaseReplication',
+        customCommand: 'STOP_REPLICATION',
+        context: Em.I18n.t('services.service.actions.run.stopHBaseReplication.context'),
+        label: Em.I18n.t('services.service.actions.run.stopHBaseReplication.label'),
+        cssClass: 'glyphicon glyphicon-refresh',
+        disabled: false
       }
     };
+  },
+
+  getMastersSubmenu: function (context, action, components) {
+    const serviceName = context.get('service.serviceName'),
+      groups = context.get('service.masterComponentGroups') || [],
+      allItem = {
+        action,
+        context: Object.assign({
+          label: Em.I18n.t('services.service.allComponents')
+        }, components ? {
+          components,
+          hosts: groups.mapProperty('hosts').reduce((acc, groupHosts) => [...acc, ...groupHosts], []).uniq()
+        } : {
+          serviceName
+        }),
+        disabled: false
+      },
+      groupItems = groups.map(group => {
+        return {
+          action,
+          context: {
+            label: group.title,
+            hosts: group.hosts,
+            components: components || group.components,
+            serviceName
+          },
+          disabled: false,
+          tooltip: group.title
+        };
+      });
+    return [allItem, ...groupItems];
   }
 };
