@@ -152,7 +152,7 @@ App.WizardStep3HostWarningPopupBody = Em.View.extend({
         title: Em.I18n.t('installer.step3.hostWarningsPopup.thp'),
         message: Em.I18n.t('installer.step3.hostWarningsPopup.thp.message'),
         type: Em.I18n.t('common.issues'),
-        emptyName: Em.I18n.t('installer.step3.hostWarningsPopup.empty.thp'),
+        emptyName: Em.I18n.t('installer.step3.hostWarningsPopup.emptyMessage').format(Em.I18n.t('installer.step3.hostWarningsPopup.empty.thp')),
         action: Em.I18n.t('installer.step3.hostWarningsPopup.action.enabled'),
         category: 'thp'
       }),
@@ -161,7 +161,7 @@ App.WizardStep3HostWarningPopupBody = Em.View.extend({
         title: Em.I18n.t('installer.step3.hostWarningsPopup.jdk'),
         message: Em.I18n.t('installer.step3.hostWarningsPopup.jdk.message'),
         type: Em.I18n.t('common.issues'),
-        emptyName: Em.I18n.t('installer.step3.hostWarningsPopup.empty.jdk'),
+        emptyName: Em.I18n.t('installer.step3.hostWarningsPopup.emptyMessage').format(Em.I18n.t('installer.step3.hostWarningsPopup.empty.jdk')),
         action: Em.I18n.t('installer.step3.hostWarningsPopup.action.exists'),
         category: 'jdk'
       }),
@@ -170,7 +170,7 @@ App.WizardStep3HostWarningPopupBody = Em.View.extend({
         title: Em.I18n.t('installer.step3.hostWarningsPopup.disk'),
         message: Em.I18n.t('installer.step3.hostWarningsPopup.disk.message'),
         type: Em.I18n.t('common.issues'),
-        emptyName: Em.I18n.t('installer.step3.hostWarningsPopup.empty.disk'),
+        emptyName: Em.I18n.t('installer.step3.hostWarningsPopup.emptyMessage').format(Em.I18n.t('installer.step3.hostWarningsPopup.empty.disk')),
         action: Em.I18n.t('installer.step3.hostWarningsPopup.action.exists'),
         category: 'disk'
       }),
@@ -179,7 +179,7 @@ App.WizardStep3HostWarningPopupBody = Em.View.extend({
         title: Em.I18n.t('installer.step3.hostWarningsPopup.repositories'),
         message: Em.I18n.t('installer.step3.hostWarningsPopup.repositories.message'),
         type: Em.I18n.t('common.issues'),
-        emptyName: Em.I18n.t('installer.step3.hostWarningsPopup.empty.repositories'),
+        emptyName: Em.I18n.t('installer.step3.hostWarningsPopup.emptyMessage').format(Em.I18n.t('installer.step3.hostWarningsPopup.empty.repositories')),
         action: Em.I18n.t('installer.step3.hostWarningsPopup.action.invalid'),
         category: 'repositories'
       }),
@@ -188,7 +188,7 @@ App.WizardStep3HostWarningPopupBody = Em.View.extend({
         title: Em.I18n.t('installer.step3.hostWarningsPopup.firewall'),
         message: Em.I18n.t('installer.step3.hostWarningsPopup.firewall.message'),
         type: Em.I18n.t('common.issues'),
-        emptyName: Em.I18n.t('installer.step3.hostWarningsPopup.empty.firewall'),
+        emptyName: Em.I18n.t('installer.step3.hostWarningsPopup.emptyMessage').format(Em.I18n.t('installer.step3.hostWarningsPopup.empty.firewall')),
         action: Em.I18n.t('installer.step3.hostWarningsPopup.action.running'),
         category: 'firewall'
       }),
@@ -197,7 +197,7 @@ App.WizardStep3HostWarningPopupBody = Em.View.extend({
         title: Em.I18n.t('installer.step3.hostWarningsPopup.process'),
         message: Em.I18n.t('installer.step3.hostWarningsPopup.processes.message'),
         type: Em.I18n.t('common.process'),
-        emptyName: Em.I18n.t('installer.step3.hostWarningsPopup.empty.processes'),
+        emptyName: Em.I18n.t('installer.step3.hostWarningsPopup.emptyMessage').format(Em.I18n.t('installer.step3.hostWarningsPopup.empty.processes')),
         action: Em.I18n.t('installer.step3.hostWarningsPopup.action.running'),
         category: 'process'
       }),
@@ -206,7 +206,7 @@ App.WizardStep3HostWarningPopupBody = Em.View.extend({
         title: Em.I18n.t('installer.step3.hostWarningsPopup.package'),
         message: Em.I18n.t('installer.step3.hostWarningsPopup.packages.message'),
         type: Em.I18n.t('common.package'),
-        emptyName: Em.I18n.t('installer.step3.hostWarningsPopup.empty.packages'),
+        emptyName: Em.I18n.t('installer.step3.hostWarningsPopup.emptyMessage').format(Em.I18n.t('installer.step3.hostWarningsPopup.empty.packages')),
         action: Em.I18n.t('installer.step3.hostWarningsPopup.action.installed'),
         category: 'package'
       }),
@@ -215,7 +215,7 @@ App.WizardStep3HostWarningPopupBody = Em.View.extend({
         title: Em.I18n.t('installer.step3.hostWarningsPopup.fileAndFolder'),
         message: Em.I18n.t('installer.step3.hostWarningsPopup.fileFolders.message'),
         type: Em.I18n.t('common.path'),
-        emptyName: Em.I18n.t('installer.step3.hostWarningsPopup.empty.filesAndFolders'),
+        emptyName: Em.I18n.t('installer.step3.hostWarningsPopup.emptyMessage').format(Em.I18n.t('installer.step3.hostWarningsPopup.empty.filesAndFolders')),
         action: Em.I18n.t('installer.step3.hostWarningsPopup.action.exists'),
         category: 'fileFolders'
       }),
@@ -224,7 +224,7 @@ App.WizardStep3HostWarningPopupBody = Em.View.extend({
         title: Em.I18n.t('installer.step3.hostWarningsPopup.service'),
         message: Em.I18n.t('installer.step3.hostWarningsPopup.services.message'),
         type: Em.I18n.t('common.service'),
-        emptyName: Em.I18n.t('installer.step3.hostWarningsPopup.empty.services'),
+        emptyName: Em.I18n.t('installer.step3.hostWarningsPopup.emptyMessage').format(Em.I18n.t('installer.step3.hostWarningsPopup.empty.services')),
         action: Em.I18n.t('installer.step3.hostWarningsPopup.action.notRunning'),
         category: 'service'
       }),
@@ -233,7 +233,7 @@ App.WizardStep3HostWarningPopupBody = Em.View.extend({
         title: Em.I18n.t('installer.step3.hostWarningsPopup.user'),
         message: Em.I18n.t('installer.step3.hostWarningsPopup.users.message'),
         type: Em.I18n.t('common.user'),
-        emptyName: Em.I18n.t('installer.step3.hostWarningsPopup.empty.users'),
+        emptyName: Em.I18n.t('installer.step3.hostWarningsPopup.emptyMessage').format(Em.I18n.t('installer.step3.hostWarningsPopup.empty.users')),
         action: Em.I18n.t('installer.step3.hostWarningsPopup.action.exists'),
         category: 'user'
       }),
@@ -242,7 +242,7 @@ App.WizardStep3HostWarningPopupBody = Em.View.extend({
         title: Em.I18n.t('installer.step3.hostWarningsPopup.misc'),
         message: Em.I18n.t('installer.step3.hostWarningsPopup.misc.message'),
         type: Em.I18n.t('installer.step3.hostWarningsPopup.misc.umask'),
-        emptyName: Em.I18n.t('installer.step3.hostWarningsPopup.empty.misc'),
+        emptyName: Em.I18n.t('installer.step3.hostWarningsPopup.emptyMessage').format(Em.I18n.t('installer.step3.hostWarningsPopup.empty.misc')),
         action: Em.I18n.t('installer.step3.hostWarningsPopup.action.exists'),
         category: 'misc'
       }),
@@ -251,7 +251,7 @@ App.WizardStep3HostWarningPopupBody = Em.View.extend({
         title: Em.I18n.t('installer.step3.hostWarningsPopup.alternatives'),
         message: Em.I18n.t('installer.step3.hostWarningsPopup.alternatives.message'),
         type: Em.I18n.t('installer.step3.hostWarningsPopup.alternatives.umask'),
-        emptyName: Em.I18n.t('installer.step3.hostWarningsPopup.alternatives.empty'),
+        emptyName: Em.I18n.t('installer.step3.hostWarningsPopup.emptyMessage').format(Em.I18n.t('installer.step3.hostWarningsPopup.alternatives.empty')),
         action: Em.I18n.t('installer.step3.hostWarningsPopup.action.exists'),
         category: 'alternatives'
       }),
@@ -259,7 +259,7 @@ App.WizardStep3HostWarningPopupBody = Em.View.extend({
         warnings: categoryWarnings.filterProperty('category', 'reverseLookup'),
         title: Em.I18n.t('installer.step3.hostWarningsPopup.reverseLookup'),
         message: Em.I18n.t('installer.step3.hostWarningsPopup.reverseLookup.message'),
-        emptyName: Em.I18n.t('installer.step3.hostWarningsPopup.reverseLookup.empty'),
+        emptyName: Em.I18n.t('installer.step3.hostWarningsPopup.emptyMessage').format(Em.I18n.t('installer.step3.hostWarningsPopup.reverseLookup.empty')),
         category: 'reverseLookup'
       }),
       Em.Object.create({
@@ -267,7 +267,7 @@ App.WizardStep3HostWarningPopupBody = Em.View.extend({
         title: Em.I18n.t('installer.step3.hostWarningsPopup.resolution.validation.name'),
         message: Em.I18n.t('installer.step3.hostWarningsPopup.resolution.validation.message'),
         type: Em.I18n.t('common.issues'),
-        emptyName: Em.I18n.t('installer.step3.hostWarningsPopup.resolution.validation.empty'),
+        emptyName: Em.I18n.t('installer.step3.hostWarningsPopup.emptyMessage').format(Em.I18n.t('installer.step3.hostWarningsPopup.resolution.validation.empty')),
         action: Em.I18n.t('installer.step3.hostWarningsPopup.action.failed'),
         category: 'hostNameResolution'
       })
@@ -284,6 +284,9 @@ App.WizardStep3HostWarningPopupBody = Em.View.extend({
         }
       });
     });
+    warningsArray.sort((a, b) => {
+      return b.warnings.length - a.warnings.length;
+    });
     return warningsArray;
   }.property('category', 'warningsByHost', 'bodyController.jdkCategoryWarnings', 'bodyController.repoCategoryWarnings', 'bodyController.diskCategoryWarnings', 'bodyController.hostCheckWarnings',  'bodyController.thpCategoryWarnings'),
 
@@ -386,10 +389,11 @@ App.WizardStep3HostWarningPopupBody = Em.View.extend({
   showHostsPopup: function (hosts) {
     $('.tooltip').hide();
     return App.ModalPopup.show({
+      'data-qa': 'hosts-with-warnings-modal',
       header: Em.I18n.t('installer.step3.hostWarningsPopup.allHosts'),
       bodyClass: Em.View.extend({
         hosts: hosts.context,
-        template: Em.Handlebars.compile('<ul>{{#each host in view.hosts}}<li>{{host}}</li>{{/each}}</ul>')
+        template: Em.Handlebars.compile('<ul>{{#each host in view.hosts}}<li {{QAAttr "host-with-warning-name"}}>{{host}}</li>{{/each}}</ul>')
       }),
       secondary: null
     });
