@@ -102,7 +102,7 @@ describe('App.Router', function () {
           }
         }, {
           'RootServiceComponents': {
-            'component_version': '2.0.0'
+            'component_version': '2.0.0_MyBuild'
           }
         }]
       },
@@ -128,7 +128,7 @@ describe('App.Router', function () {
       mockData: {
         components: [{
           'RootServiceComponents': {
-            component_version: '2.1.0'
+            component_version: '2.1.0_MyBuild'
           }
         }]
       },
@@ -462,6 +462,26 @@ describe('App.Router', function () {
         },
         redirectCalled: false,
         m: 'jwtProviderUrl is present, current location is local login url, no redirect'
+      },
+      {
+        lastSetURL: '/main/dashboard',
+        isResolved: false,
+        responseData: {
+          responseText: JSON.stringify({jwtProviderUrl: 'http://some.com?originalUrl='}),
+          status: 401
+        },
+        redirectCalled: true,
+        m: 'jwtProviderUrl is present, current location not local login url, redirect according to jwtProviderUrl value'
+      },
+      {
+        lastSetURL: '/login/local',
+        isResolved: false,
+        responseData: {
+          responseText: JSON.stringify({jwtProviderUrl: 'http://some.com?originalUrl='}),
+          status: 401
+        },
+        redirectCalled: false,
+        m: 'jwtProviderUrl is present, current location is local login url, no redirect'
       }
     ].forEach(function (test) {
       describe(test.m, function () {
@@ -669,4 +689,4 @@ describe('App.StepRoute', function () {
     });
   });
 
-});
\ No newline at end of file
+});
