@@ -242,7 +242,7 @@ describe('utils/helper', function() {
       afterEach(removeDiv);
       it('should add tooltip', function() {
         App.tooltip($('#tooltip-test'));
-        expect($('#tooltip-test').data('tooltip').enabled).to.be.true;
+        expect($('#tooltip-test').data('bs.tooltip').enabled).to.be.true;
       });
     });
     describe('#popover()', function() {
@@ -250,7 +250,7 @@ describe('utils/helper', function() {
       afterEach(removeDiv);
       it('should add popover', function() {
         App.popover($('#tooltip-test'));
-        expect($('#tooltip-test').data('popover').enabled).to.be.true;
+        expect($('#tooltip-test').data('bs.popover').enabled).to.be.true;
       });
     });
     describe('#App.format', function(){
@@ -266,7 +266,7 @@ describe('utils/helper', function() {
           expect(App.format.commandDetail(command)).to.be.equal(' Ganglia Monitor Stop');
         });
         it('should use display name for operations if specified', function() {
-          expect(App.format.commandDetail(customCommandDetail, null, opsDisplayName)).to.be.equal(' Remove Logical Mycomponent Mycomponent');
+          expect(App.format.commandDetail(customCommandDetail, null, opsDisplayName)).to.be.equal(' Remove Logical Mycomponent');
         });
         it('should ignore decommission command', function(){
           expect(App.format.commandDetail(ignored)).to.be.equal('  NameNode');
@@ -308,6 +308,8 @@ describe('utils/helper', function() {
           'app-timeline-server': 'App Timeline Server',
           'APP TIMELINE SERVER': 'App Timeline Server',
           'app timeline server': 'App Timeline Server',
+          'run-hcat-sync': 'Run HCat Client Sync',
+          'rUN_hCAt_syNc': 'Run HCat Client Sync',
           'FALCON': 'Falcon',
           'falcon': 'Falcon'
         };
